# 25 "src/kernel_internals/parsing/logic_lexer.mll"
 

  open Logic_parser
  open Lexing
  open Logic_ptree

  type state = Normal | Test

  let state_stack = Stack.create ()

  let () = Stack.push Normal state_stack

  let get_state () = try Stack.top state_stack with Stack.Empty -> Normal

  let pop_state () = try ignore (Stack.pop state_stack) with Stack.Empty -> ()

  exception Error of (int * int) * string

  let loc lexbuf = (lexeme_start lexbuf, lexeme_end lexbuf)

  let lex_error lexbuf s =
    raise (Error (loc lexbuf, "lexical error, " ^ s))

  let find_utf8 =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [ Utf8_logic.forall, FORALL;
        Utf8_logic.exists, EXISTS;
        Utf8_logic.eq, EQ;
        Utf8_logic.neq, NE;
        Utf8_logic.le, LE;
        Utf8_logic.ge, GE;
        Utf8_logic.implies,IMPLIES;
        Utf8_logic.iff, IFF;
        Utf8_logic.conj, AND;
        Utf8_logic.disj, OR;
        Utf8_logic.neg, NOT;
        Utf8_logic.x_or, HATHAT;
        Utf8_logic.minus, MINUS;
        Utf8_logic.boolean, BOOLEAN;
        Utf8_logic.integer, INTEGER;
        Utf8_logic.real, REAL;
        Utf8_logic.inset, IN;
        Utf8_logic.pi, PI;
      ];

    fun s -> try Hashtbl.find h s
    with Not_found -> IDENTIFIER s

  let identifier, is_acsl_keyword =
    let all_kw = Hashtbl.create 37 in
    let c_kw = Hashtbl.create 37 in
    let type_kw = Hashtbl.create 3 in
    List.iter
      (fun (i,t,flag) ->
         Hashtbl.add all_kw i t;
         if flag then Hashtbl.add c_kw i t
      )
      [
        "allocates", ALLOCATES, false;
        "assert", ASSERT, false;
        "assigns", ASSIGNS, false;
        "assumes", ASSUMES, false;
        "at", EXT_AT, false;(* ACSL extension for external spec file *)
        "axiom", AXIOM, false;
        "axiomatic", AXIOMATIC, false;
        "behavior", BEHAVIOR, false;
        "behaviors", BEHAVIORS, false;
        "_Bool", BOOL, true;
        "breaks", BREAKS, false;
	"case", CASE, true;
        "char", CHAR, true;
        "check", CHECK, false;
        "complete", COMPLETE, false;
        "const", CONST, true;
        "continues", CONTINUES, false;
        "contract", CONTRACT, false;(* ACSL extension for external spec file *)
	"custom", CUSTOM, false; (* ACSL extension for custom annotations *)
        "decreases", DECREASES, false;
        "disjoint", DISJOINT, false;
        "double", DOUBLE, true;
        "else", ELSE, true;
        "ensures", ENSURES, false ;
        "enum", ENUM, true;
        "exits", EXITS, false;
        "frees", FREES, false;
        "function", FUNCTION, false;(* ACSL extension for external spec file *)
        "float", FLOAT, true;
        "for", FOR, true;
        "global",    GLOBAL, false;
        "if", IF, true;
	"impact", IMPACT, false;
	"inductive", INDUCTIVE, false;
	"include", INCLUDE, false;(* ACSL extension for external spec file *)
        "int", INT, true;
        "invariant", INVARIANT, false;
        "label", LABEL, false;
        "lemma", LEMMA, false;
        "let", EXT_LET, false;(* ACSL extension for external spec file *)
        "logic", LOGIC, false;
        "long", LONG, true;
        "loop", LOOP, false;
        "model", MODEL, false;(* ACSL extension for model fields *)
        "module", MODULE, false;(* ACSL extension for external spec file *)
        "pragma", PRAGMA, false;
        "predicate", PREDICATE, false;
        "reads", READS, true; (* treated specifically in the parser to
                                 avoid issue in volatile clause. *)
        "requires", REQUIRES, false;
        "returns", RETURNS, false;
        "short", SHORT, true;
        "signed", SIGNED, true;
        "sizeof", SIZEOF, true;
        "slice", SLICE, false;
        "struct", STRUCT, true;
        "terminates", TERMINATES, false;
        "type", TYPE, false;
        "union", UNION, true;
        "unsigned", UNSIGNED, true;
        "variant", VARIANT, false;
        "void", VOID, true;
        "volatile", VOLATILE, true;
        "writes", WRITES, true; (* treated specifically in the parser to
                                   avoid issue in volatile clause. *)
      ];
    List.iter (fun (x, y) -> Hashtbl.add type_kw x y)
      ["integer", INTEGER; "real", REAL; "boolean", BOOLEAN; ];
    (fun s ->
      try
        Hashtbl.find (if Logic_utils.is_kw_c_mode () then c_kw else all_kw) s
      with Not_found ->
        let res =
          if not (Logic_utils.is_kw_c_mode ()) then begin
            match Logic_env.extension_category s with
            | None -> None
            | Some Cil_types.Ext_contract -> Some (EXT_CONTRACT s)
            | Some Cil_types.Ext_global -> Some (EXT_GLOBAL s)
            | Some Cil_types.Ext_code_annot _ -> Some (EXT_CODE_ANNOT s)
          end
          else None
        in
        match res with
        | None ->
        if Logic_env.typename_status s then TYPENAME s
        else
          (try
             Hashtbl.find type_kw s
           with Not_found ->
             if Logic_utils.is_rt_type_mode () then TYPENAME s
               else IDENTIFIER s)
        | Some lex -> lex
    ),
    (fun s -> Hashtbl.mem all_kw s || Hashtbl.mem type_kw s)

  let bs_identifier =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [
        "\\allocation", ALLOCATION;
        "\\allocable", ALLOCABLE;
        "\\automatic", AUTOMATIC;
        "\\at", AT;
        "\\base_addr", BASE_ADDR;
        "\\block_length", BLOCK_LENGTH;
        "\\dynamic", DYNAMIC;
        "\\empty", EMPTY;
        "\\exists", EXISTS;
        "\\false", FALSE;
        "\\forall", FORALL;
        "\\freeable", FREEABLE;
        "\\fresh", FRESH;
        "\\from", FROM;
        "\\initialized", INITIALIZED;
        "\\dangling", DANGLING;
        "\\in", IN;
        "\\inter", INTER;
        "\\lambda", LAMBDA;
        "\\let", LET;
        "\\nothing", NOTHING;
        "\\null", NULL;
        "\\offset", OFFSET;
        "\\old", OLD;
        "\\pi", PI;
        "\\register", REGISTER;
        "\\result", RESULT;
        "\\separated", SEPARATED;
        "\\static", STATIC;
        "\\true", TRUE;
        "\\type", BSTYPE;
        "\\typeof", TYPEOF;
        "\\unallocated", UNALLOCATED;
        "\\union", BSUNION;
        "\\valid", VALID;
        "\\valid_read", VALID_READ;
        "\\valid_index", VALID_INDEX;
        "\\valid_range", VALID_RANGE;
        "\\valid_function", VALID_FUNCTION;
        "\\with", WITH;
      ];
    fun lexbuf ->
      let s = lexeme lexbuf in
      try Hashtbl.find h s with Not_found ->         
	if Logic_env.typename_status s then TYPENAME s
        else
	  IDENTIFIER s


  let int_of_digit chr =
    match chr with
        '0'..'9' -> (Char.code chr) - (Char.code '0')
      | 'a'..'f' -> (Char.code chr) - (Char.code 'a') + 10
      | 'A'..'F' -> (Char.code chr) - (Char.code 'A') + 10
      | _ -> assert false

  (* Update lexer buffer. *)
  let update_line_loc lexbuf line =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <-
      { pos with
	Lexing.pos_lnum = line;
	Lexing.pos_bol = pos.Lexing.pos_cnum;
      }

  let update_newline_loc lexbuf =
    update_line_loc lexbuf (lexbuf.Lexing.lex_curr_p.Lexing.pos_lnum + 1)

  let update_file_loc lexbuf file =
   let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <- { pos with Lexing.pos_fname = file }

  let accept_c_comments_into_acsl_spec = ref false


# 236 "src/kernel_internals/parsing/logic_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\188\255\189\255\000\000\197\255\133\000\199\255\200\255\
    \201\255\202\255\197\000\210\255\212\255\166\000\219\255\203\000\
    \226\255\227\255\229\255\230\255\201\000\170\000\226\000\221\000\
    \224\000\206\000\238\255\002\001\224\000\005\001\253\000\035\001\
    \108\001\197\001\255\001\239\000\246\000\254\255\046\001\250\255\
    \032\001\252\255\253\255\217\255\251\255\074\002\187\002\126\002\
    \090\001\127\002\242\255\239\255\092\001\154\002\183\002\211\000\
    \195\002\241\000\009\003\032\003\091\003\233\002\161\003\247\000\
    \129\003\199\003\232\003\008\004\064\003\241\255\018\004\047\004\
    \079\004\089\004\108\004\141\004\173\004\183\004\031\001\027\001\
    \030\001\202\004\212\004\240\255\234\004\244\004\017\005\027\005\
    \056\005\066\005\095\005\245\000\107\005\136\005\146\005\175\005\
    \221\255\233\000\237\255\192\255\194\255\252\000\251\000\251\000\
    \236\255\254\000\234\255\228\255\255\000\235\255\233\255\195\255\
    \232\255\203\255\193\255\224\255\215\255\191\255\206\255\196\255\
    \232\000\251\255\252\255\208\005\253\255\076\001\025\006\048\006\
    \189\001\254\255\234\005\251\255\213\000\224\005\254\255\255\255\
    \210\000\220\000\252\255\035\003\252\255\133\001\254\255\255\255\
    \253\255\001\003\225\001\253\255\254\255\255\255\125\002\252\255\
    \253\255\022\001\255\255\254\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\065\000\255\255\057\000\255\255\255\255\
    \255\255\255\255\047\000\255\255\255\255\041\000\255\255\030\000\
    \255\255\255\255\255\255\255\255\024\000\042\000\039\000\035\000\
    \046\000\051\000\255\255\067\000\032\000\067\000\011\000\011\000\
    \007\000\007\000\067\000\037\000\044\000\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\006\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\014\000\255\255\012\000\
    \010\000\255\255\255\255\255\255\008\000\255\255\255\255\008\000\
    \255\255\255\255\255\255\014\000\255\255\255\255\014\000\255\255\
    \014\000\255\255\255\255\255\255\014\000\255\255\009\000\009\000\
    \010\000\014\000\255\255\255\255\255\255\014\000\255\255\014\000\
    \255\255\014\000\255\255\033\000\014\000\255\255\014\000\255\255\
    \255\255\050\000\255\255\255\255\255\255\255\255\048\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\004\000\255\255\001\000\255\255\000\000\
    \001\000\255\255\255\255\255\255\004\000\002\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\003\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\255\255\255\255";
  Lexing.lex_default =
   "\003\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\046\000\255\255\049\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \040\000\000\000\000\000\000\000\000\000\255\255\046\000\049\000\
    \049\000\049\000\000\000\000\000\046\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\000\000\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \121\000\000\000\000\000\255\255\000\000\255\255\255\255\255\255\
    \255\255\000\000\131\000\000\000\255\255\255\255\000\000\000\000\
    \255\255\255\255\000\000\140\000\000\000\145\000\000\000\000\000\
    \000\000\145\000\147\000\000\000\000\000\000\000\151\000\000\000\
    \000\000\255\255\000\000\000\000";
  Lexing.lex_trans =
   "\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\038\000\037\000\001\000\038\000\038\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \038\000\020\000\027\000\026\000\019\000\011\000\022\000\029\000\
    \009\000\008\000\035\000\014\000\018\000\023\000\028\000\036\000\
    \031\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\015\000\016\000\024\000\025\000\010\000\017\000\
    \038\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\033\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\005\000\034\000\004\000\013\000\032\000\
    \001\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\007\000\021\000\006\000\012\000\001\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\001\000\
    \002\000\119\000\118\000\117\000\116\000\115\000\113\000\111\000\
    \110\000\114\000\108\000\097\000\255\255\101\000\091\000\255\255\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\100\000\107\000\099\000\102\000\044\000\055\000\
    \039\000\078\000\078\000\096\000\051\000\040\000\112\000\098\000\
    \055\000\105\000\042\000\053\000\255\255\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\038\000\
    \103\000\104\000\038\000\038\000\106\000\109\000\136\000\055\000\
    \137\000\138\000\054\000\063\000\123\000\155\000\000\000\000\000\
    \055\000\055\000\000\000\000\000\063\000\043\000\038\000\078\000\
    \078\000\053\000\055\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\000\000\052\000\000\000\
    \000\000\048\000\054\000\063\000\255\255\057\000\255\255\079\000\
    \054\000\055\000\080\000\079\000\063\000\000\000\038\000\055\000\
    \079\000\000\000\055\000\080\000\079\000\000\000\000\000\000\000\
    \055\000\000\000\000\000\058\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\000\000\057\000\000\000\079\000\
    \054\000\000\000\080\000\079\000\000\000\000\000\255\255\055\000\
    \079\000\255\255\000\000\080\000\079\000\000\000\000\000\000\000\
    \055\000\000\000\000\000\058\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\144\000\
    \000\000\000\000\000\000\000\000\000\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\000\000\
    \000\000\000\000\000\000\032\000\000\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\046\000\
    \122\000\000\000\000\000\149\000\047\000\129\000\129\000\129\000\
    \129\000\129\000\129\000\129\000\129\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\255\255\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \041\000\000\000\000\000\000\000\032\000\000\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\255\255\000\000\255\255\000\000\045\000\000\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\000\000\255\255\000\000\154\000\
    \255\255\255\255\000\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\255\255\050\000\153\000\
    \000\000\045\000\000\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\255\255\000\000\000\000\
    \083\000\000\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\048\000\048\000\000\000\051\000\069\000\084\000\
    \069\000\148\000\082\000\000\000\082\000\000\000\069\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\053\000\000\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\000\000\069\000\084\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
    \054\000\000\000\255\255\000\000\000\000\255\255\000\000\080\000\
    \000\000\000\000\000\000\000\000\073\000\000\000\073\000\052\000\
    \080\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\144\000\000\000\000\000\000\000\000\000\
    \054\000\000\000\000\000\000\000\142\000\143\000\000\000\080\000\
    \142\000\000\000\000\000\000\000\000\000\000\000\000\000\059\000\
    \080\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\142\000\000\000\141\000\000\000\000\000\
    \000\000\000\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\074\000\074\000\074\000\074\000\074\000\074\000\000\000\
    \000\000\000\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\000\000\000\000\000\000\152\000\255\255\255\255\
    \000\000\074\000\074\000\074\000\074\000\074\000\074\000\000\000\
    \000\000\062\000\000\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\000\000\000\000\000\000\000\000\000\000\063\000\
    \000\000\000\000\000\000\061\000\071\000\000\000\071\000\000\000\
    \063\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\255\255\060\000\060\000\060\000\060\000\
    \060\000\060\000\000\000\000\000\000\000\000\000\000\000\063\000\
    \000\000\000\000\000\000\061\000\000\000\000\000\000\000\000\000\
    \063\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\064\000\000\000\000\000\000\000\000\000\000\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\000\000\000\000\
    \000\000\064\000\000\000\068\000\000\000\068\000\000\000\066\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\066\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\069\000\000\000\069\000\000\000\
    \000\000\000\000\000\000\000\000\069\000\000\000\069\000\000\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\000\000\000\000\000\000\069\000\000\000\069\000\000\000\
    \000\000\000\000\000\000\000\000\069\000\000\000\069\000\000\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\069\000\000\000\069\000\000\000\000\000\
    \000\000\000\000\000\000\069\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\069\000\000\000\069\000\000\000\000\000\
    \077\000\000\000\077\000\069\000\075\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\075\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\069\000\000\000\069\000\000\000\000\000\000\000\000\000\
    \000\000\069\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\069\000\000\000\
    \069\000\069\000\000\000\069\000\000\000\090\000\069\000\090\000\
    \000\000\069\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\085\000\069\000\000\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
    \069\000\086\000\069\000\000\000\088\000\000\000\088\000\000\000\
    \069\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\000\000\000\000\000\000\
    \069\000\086\000\069\000\000\000\000\000\000\000\000\000\069\000\
    \069\000\069\000\000\000\000\000\000\000\000\000\000\000\069\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\000\000\000\000\000\000\069\000\
    \000\000\069\000\000\000\000\000\000\000\000\000\069\000\069\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\000\000\000\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\000\000\069\000\000\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\069\000\
    \093\000\069\000\000\000\095\000\000\000\095\000\000\000\069\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\000\000\000\000\000\000\069\000\
    \093\000\069\000\000\000\000\000\000\000\000\000\069\000\069\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\124\000\134\000\135\000\000\000\069\000\124\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \000\000\000\000\134\000\000\000\000\000\000\000\000\000\124\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\000\000\000\000\000\000\000\000\
    \126\000\000\000\000\000\000\000\124\000\000\000\000\000\000\000\
    \000\000\124\000\124\000\000\000\000\000\000\000\124\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\124\000\000\000\
    \000\000\000\000\124\000\000\000\124\000\000\000\124\000\000\000\
    \126\000\127\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \127\000\127\000\127\000\000\000\000\000\000\000\132\000\000\000\
    \000\000\000\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \127\000\127\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \127\000\127\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\127\000\127\000\127\000\127\000\127\000\127\000\000\000\
    \000\000\000\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\127\000\127\000\127\000\127\000\127\000\127\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\005\000\010\000\010\000\013\000\015\000\020\000\021\000\
    \022\000\015\000\023\000\025\000\027\000\024\000\028\000\029\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\024\000\023\000\024\000\024\000\035\000\055\000\
    \036\000\057\000\057\000\091\000\027\000\036\000\021\000\097\000\
    \055\000\101\000\040\000\030\000\029\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\038\000\
    \102\000\103\000\038\000\038\000\105\000\108\000\132\000\055\000\
    \136\000\137\000\030\000\063\000\120\000\153\000\255\255\255\255\
    \055\000\030\000\255\255\255\255\063\000\035\000\038\000\078\000\
    \078\000\031\000\030\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\255\255\027\000\255\255\
    \255\255\029\000\030\000\063\000\048\000\031\000\052\000\079\000\
    \031\000\030\000\080\000\078\000\063\000\255\255\038\000\031\000\
    \079\000\255\255\030\000\080\000\078\000\255\255\255\255\255\255\
    \031\000\255\255\255\255\031\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\125\000\125\000\255\255\031\000\255\255\079\000\
    \031\000\255\255\080\000\078\000\255\255\255\255\141\000\031\000\
    \079\000\141\000\255\255\080\000\078\000\255\255\255\255\255\255\
    \031\000\255\255\255\255\031\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\255\255\141\000\
    \255\255\255\255\255\255\255\255\255\255\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\255\255\
    \255\255\255\255\255\255\032\000\255\255\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\033\000\
    \120\000\255\255\255\255\146\000\033\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\255\255\
    \255\255\255\255\027\000\255\255\255\255\029\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \040\000\255\255\255\255\255\255\033\000\255\255\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\048\000\255\255\052\000\255\255\034\000\255\255\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\255\255\141\000\255\255\150\000\
    \047\000\049\000\255\255\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\047\000\049\000\150\000\
    \255\255\045\000\255\255\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\046\000\255\255\255\255\
    \053\000\255\255\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\047\000\049\000\255\255\046\000\053\000\053\000\
    \053\000\146\000\054\000\255\255\054\000\255\255\053\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\056\000\255\255\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\255\255\053\000\053\000\
    \053\000\255\255\255\255\255\255\255\255\255\255\053\000\255\255\
    \056\000\255\255\145\000\255\255\255\255\145\000\255\255\056\000\
    \255\255\255\255\255\255\255\255\061\000\255\255\061\000\046\000\
    \056\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\145\000\255\255\255\255\255\255\255\255\
    \056\000\255\255\255\255\255\255\139\000\139\000\255\255\056\000\
    \139\000\255\255\255\255\255\255\255\255\255\255\255\255\058\000\
    \056\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\139\000\255\255\139\000\255\255\255\255\
    \255\255\255\255\058\000\058\000\058\000\058\000\058\000\058\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\059\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\255\255\058\000\058\000\058\000\058\000\058\000\058\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\255\255\255\255\255\255\150\000\047\000\049\000\
    \255\255\059\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\060\000\255\255\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\060\000\060\000\060\000\060\000\
    \060\000\060\000\255\255\255\255\255\255\255\255\255\255\060\000\
    \255\255\255\255\255\255\060\000\064\000\255\255\064\000\255\255\
    \060\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\046\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\255\255\255\255\255\255\255\255\255\255\060\000\
    \255\255\255\255\255\255\060\000\255\255\255\255\255\255\255\255\
    \060\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\062\000\062\000\062\000\062\000\062\000\062\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\062\000\255\255\255\255\255\255\255\255\255\255\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\145\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\255\255\255\255\
    \255\255\062\000\255\255\066\000\255\255\066\000\255\255\065\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\066\000\255\255\139\000\255\255\255\255\255\255\255\255\
    \065\000\065\000\065\000\065\000\065\000\065\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\065\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\067\000\255\255\067\000\255\255\
    \255\255\255\255\255\255\255\255\067\000\255\255\070\000\255\255\
    \070\000\255\255\255\255\255\255\255\255\255\255\070\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\255\255\255\255\255\255\067\000\255\255\067\000\255\255\
    \255\255\255\255\255\255\255\255\067\000\255\255\070\000\255\255\
    \070\000\255\255\255\255\255\255\255\255\255\255\070\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\072\000\255\255\072\000\255\255\255\255\
    \255\255\255\255\255\255\072\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\074\000\074\000\074\000\
    \074\000\074\000\074\000\072\000\255\255\072\000\255\255\255\255\
    \075\000\255\255\075\000\072\000\074\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\074\000\074\000\074\000\
    \074\000\074\000\074\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\074\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\076\000\255\255\076\000\255\255\255\255\255\255\255\255\
    \255\255\076\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\081\000\255\255\
    \081\000\076\000\255\255\076\000\255\255\084\000\081\000\084\000\
    \255\255\076\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\085\000\081\000\255\255\
    \081\000\255\255\255\255\255\255\255\255\255\255\081\000\255\255\
    \085\000\085\000\085\000\255\255\086\000\255\255\086\000\255\255\
    \085\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\255\255\255\255\255\255\
    \085\000\085\000\085\000\255\255\255\255\255\255\255\255\087\000\
    \085\000\087\000\255\255\255\255\255\255\255\255\255\255\087\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\255\255\255\255\255\255\087\000\
    \255\255\087\000\255\255\255\255\255\255\255\255\089\000\087\000\
    \089\000\255\255\255\255\255\255\255\255\255\255\089\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\255\255\255\255\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\255\255\089\000\255\255\
    \089\000\255\255\255\255\255\255\255\255\255\255\089\000\092\000\
    \092\000\092\000\255\255\093\000\255\255\093\000\255\255\092\000\
    \093\000\093\000\093\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\255\255\255\255\255\255\092\000\
    \092\000\092\000\255\255\255\255\255\255\255\255\094\000\092\000\
    \094\000\255\255\255\255\255\255\255\255\255\255\094\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\123\000\130\000\130\000\255\255\094\000\123\000\
    \094\000\255\255\255\255\255\255\255\255\255\255\094\000\255\255\
    \123\000\123\000\123\000\123\000\123\000\123\000\123\000\123\000\
    \255\255\255\255\130\000\255\255\255\255\255\255\255\255\123\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\130\000\130\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\255\255\255\255\255\255\255\255\
    \123\000\255\255\255\255\255\255\123\000\255\255\255\255\255\255\
    \255\255\123\000\123\000\255\255\255\255\255\255\123\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\123\000\255\255\
    \255\255\255\255\123\000\255\255\123\000\255\255\123\000\255\255\
    \123\000\126\000\126\000\126\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\255\255\255\255\255\255\130\000\255\255\
    \255\255\255\255\126\000\126\000\126\000\126\000\126\000\126\000\
    \127\000\127\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \127\000\127\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\127\000\127\000\127\000\127\000\127\000\127\000\255\255\
    \255\255\255\255\126\000\126\000\126\000\126\000\126\000\126\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\127\000\127\000\127\000\127\000\127\000\127\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\130\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_base_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\007\000\010\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\001\000\001\000\000\000\000\000\000\000\004\000\
    \004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000";
  Lexing.lex_check_code =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\033\000\255\255\255\255\255\255\000\000\
    \033\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_code =
   "\255\001\255\255\002\255\255\000\002\255\000\001\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 3 (-1); __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 284 "src/kernel_internals/parsing/logic_lexer.mll"
           ( token lexbuf )
# 907 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 285 "src/kernel_internals/parsing/logic_lexer.mll"
         ( update_newline_loc lexbuf; token lexbuf )
# 912 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 286 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( update_newline_loc lexbuf; token lexbuf )
# 917 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 287 "src/kernel_internals/parsing/logic_lexer.mll"
                     ( token lexbuf )
# 922 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 288 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "unexpected block-comment closing" )
# 927 "src/kernel_internals/parsing/logic_lexer.ml"

  | 5 ->
# 289 "src/kernel_internals/parsing/logic_lexer.mll"
         ( if !accept_c_comments_into_acsl_spec
           then comment lexbuf
           else lex_error lexbuf "unexpected block-comment opening"
         )
# 935 "src/kernel_internals/parsing/logic_lexer.ml"

  | 6 ->
# 294 "src/kernel_internals/parsing/logic_lexer.mll"
                       ( bs_identifier lexbuf )
# 940 "src/kernel_internals/parsing/logic_lexer.ml"

  | 7 ->
# 295 "src/kernel_internals/parsing/logic_lexer.mll"
                        ( let s = lexeme lexbuf in identifier s )
# 945 "src/kernel_internals/parsing/logic_lexer.ml"

  | 8 ->
# 297 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 950 "src/kernel_internals/parsing/logic_lexer.ml"

  | 9 ->
# 298 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 955 "src/kernel_internals/parsing/logic_lexer.ml"

  | 10 ->
# 299 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 960 "src/kernel_internals/parsing/logic_lexer.ml"

  | 11 ->
# 300 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT10 (lexeme lexbuf) )
# 965 "src/kernel_internals/parsing/logic_lexer.ml"

  | 12 ->
# 301 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 970 "src/kernel_internals/parsing/logic_lexer.ml"

  | 13 ->
let
# 302 "src/kernel_internals/parsing/logic_lexer.mll"
                 prelude
# 976 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 302 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                   content
# 981 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 303 "src/kernel_internals/parsing/logic_lexer.mll"
      (
        let b = Buffer.create 5 in
        Buffer.add_string b prelude;
        let lbf = Lexing.from_string content in
        CONSTANT (IntConstant (chr b lbf ^ "'"))
      )
# 990 "src/kernel_internals/parsing/logic_lexer.ml"

  | 14 ->
# 316 "src/kernel_internals/parsing/logic_lexer.mll"
      ( CONSTANT (FloatConstant (lexeme lexbuf)) )
# 995 "src/kernel_internals/parsing/logic_lexer.ml"

  | 15 ->
let
# 319 "src/kernel_internals/parsing/logic_lexer.mll"
            n
# 1001 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 319 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( lexbuf.lex_curr_pos <- lexbuf.lex_curr_pos - 2;
                              CONSTANT (IntConstant n) )
# 1006 "src/kernel_internals/parsing/logic_lexer.ml"

  | 16 ->
let
# 322 "src/kernel_internals/parsing/logic_lexer.mll"
                prelude
# 1012 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 322 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                content
# 1017 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 323 "src/kernel_internals/parsing/logic_lexer.mll"
      ( STRING_LITERAL (prelude.[0] = 'L',content) )
# 1021 "src/kernel_internals/parsing/logic_lexer.ml"

  | 17 ->
# 324 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( hash lexbuf )
# 1026 "src/kernel_internals/parsing/logic_lexer.ml"

  | 18 ->
# 325 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IMPLIES )
# 1031 "src/kernel_internals/parsing/logic_lexer.ml"

  | 19 ->
# 326 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IFF )
# 1036 "src/kernel_internals/parsing/logic_lexer.ml"

  | 20 ->
# 327 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIMPLIES )
# 1041 "src/kernel_internals/parsing/logic_lexer.ml"

  | 21 ->
# 328 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIFF )
# 1046 "src/kernel_internals/parsing/logic_lexer.ml"

  | 22 ->
# 329 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AND )
# 1051 "src/kernel_internals/parsing/logic_lexer.ml"

  | 23 ->
# 330 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( OR )
# 1056 "src/kernel_internals/parsing/logic_lexer.ml"

  | 24 ->
# 331 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NOT )
# 1061 "src/kernel_internals/parsing/logic_lexer.ml"

  | 25 ->
# 332 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOLLAR )
# 1066 "src/kernel_internals/parsing/logic_lexer.ml"

  | 26 ->
# 333 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COMMA )
# 1071 "src/kernel_internals/parsing/logic_lexer.ml"

  | 27 ->
# 334 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( ARROW )
# 1076 "src/kernel_internals/parsing/logic_lexer.ml"

  | 28 ->
# 335 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Test state_stack; QUESTION )
# 1081 "src/kernel_internals/parsing/logic_lexer.ml"

  | 29 ->
# 336 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SEMICOLON )
# 1086 "src/kernel_internals/parsing/logic_lexer.ml"

  | 30 ->
# 337 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( match get_state() with
                                  Normal  -> COLON
                                | Test -> pop_state(); COLON2
                            )
# 1094 "src/kernel_internals/parsing/logic_lexer.ml"

  | 31 ->
# 341 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONCOLON )
# 1099 "src/kernel_internals/parsing/logic_lexer.ml"

  | 32 ->
# 342 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOT )
# 1104 "src/kernel_internals/parsing/logic_lexer.ml"

  | 33 ->
# 343 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOT )
# 1109 "src/kernel_internals/parsing/logic_lexer.ml"

  | 34 ->
# 344 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOTDOT )
# 1114 "src/kernel_internals/parsing/logic_lexer.ml"

  | 35 ->
# 345 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( MINUS )
# 1119 "src/kernel_internals/parsing/logic_lexer.ml"

  | 36 ->
# 346 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PLUS )
# 1124 "src/kernel_internals/parsing/logic_lexer.ml"

  | 37 ->
# 347 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STAR )
# 1129 "src/kernel_internals/parsing/logic_lexer.ml"

  | 38 ->
# 348 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STARHAT )
# 1134 "src/kernel_internals/parsing/logic_lexer.ml"

  | 39 ->
# 349 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AMP )
# 1139 "src/kernel_internals/parsing/logic_lexer.ml"

  | 40 ->
# 350 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HATHAT )
# 1144 "src/kernel_internals/parsing/logic_lexer.ml"

  | 41 ->
# 351 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HAT )
# 1149 "src/kernel_internals/parsing/logic_lexer.ml"

  | 42 ->
# 352 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PIPE )
# 1154 "src/kernel_internals/parsing/logic_lexer.ml"

  | 43 ->
# 353 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( TILDE )
# 1159 "src/kernel_internals/parsing/logic_lexer.ml"

  | 44 ->
# 354 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SLASH )
# 1164 "src/kernel_internals/parsing/logic_lexer.ml"

  | 45 ->
# 355 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PERCENT )
# 1169 "src/kernel_internals/parsing/logic_lexer.ml"

  | 46 ->
# 356 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LT )
# 1174 "src/kernel_internals/parsing/logic_lexer.ml"

  | 47 ->
# 357 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GT )
# 1179 "src/kernel_internals/parsing/logic_lexer.ml"

  | 48 ->
# 358 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LE )
# 1184 "src/kernel_internals/parsing/logic_lexer.ml"

  | 49 ->
# 359 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GE )
# 1189 "src/kernel_internals/parsing/logic_lexer.ml"

  | 50 ->
# 360 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQ )
# 1194 "src/kernel_internals/parsing/logic_lexer.ml"

  | 51 ->
# 361 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQUAL )
# 1199 "src/kernel_internals/parsing/logic_lexer.ml"

  | 52 ->
# 362 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NE )
# 1204 "src/kernel_internals/parsing/logic_lexer.ml"

  | 53 ->
# 363 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LPAR )
# 1209 "src/kernel_internals/parsing/logic_lexer.ml"

  | 54 ->
# 364 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RPAR )
# 1214 "src/kernel_internals/parsing/logic_lexer.ml"

  | 55 ->
# 365 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LBRACE )
# 1219 "src/kernel_internals/parsing/logic_lexer.ml"

  | 56 ->
# 366 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RBRACE )
# 1224 "src/kernel_internals/parsing/logic_lexer.ml"

  | 57 ->
# 367 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUARE )
# 1229 "src/kernel_internals/parsing/logic_lexer.ml"

  | 58 ->
# 368 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUARE )
# 1234 "src/kernel_internals/parsing/logic_lexer.ml"

  | 59 ->
# 369 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUAREPIPE )
# 1239 "src/kernel_internals/parsing/logic_lexer.ml"

  | 60 ->
# 370 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUAREPIPE )
# 1244 "src/kernel_internals/parsing/logic_lexer.ml"

  | 61 ->
# 371 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTCOLON )
# 1249 "src/kernel_internals/parsing/logic_lexer.ml"

  | 62 ->
# 372 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONGT )
# 1254 "src/kernel_internals/parsing/logic_lexer.ml"

  | 63 ->
# 373 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTLT )
# 1259 "src/kernel_internals/parsing/logic_lexer.ml"

  | 64 ->
# 374 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GTGT )
# 1264 "src/kernel_internals/parsing/logic_lexer.ml"

  | 65 ->
let
# 375 "src/kernel_internals/parsing/logic_lexer.mll"
                 c
# 1270 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 375 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( find_utf8 c )
# 1274 "src/kernel_internals/parsing/logic_lexer.ml"

  | 66 ->
# 376 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EOF )
# 1279 "src/kernel_internals/parsing/logic_lexer.ml"

  | 67 ->
# 377 "src/kernel_internals/parsing/logic_lexer.mll"
        ( lex_error lexbuf ("illegal character " ^ lexeme lexbuf) )
# 1284 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and chr buffer lexbuf =
   __ocaml_lex_chr_rec buffer lexbuf 120
and __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 381 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 2 (String.length s - 2) in
        let rec add_one_char s =
          let l = String.length s in
          if l = 0 then ()
          else
          let h = int_of_digit s.[0] in
          let c,s =
            if l = 1 then (h,"")
            else
              (16*h + int_of_digit s.[1],
               String.sub s 2 (String.length s - 2))
          in
          Buffer.add_char buffer (Char.chr c); add_one_char s
        in add_one_char real_s; chr buffer lexbuf
      )
# 1311 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 398 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 1 (String.length s - 1) in
        let rec value i s =
          if s = "" then i
          else value (8*i+int_of_digit s.[0])
            (String.sub s 1 (String.length s -1))
        in let c = value 0 real_s in
        Buffer.add_char buffer (Char.chr c); chr buffer lexbuf
      )
# 1324 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 408 "src/kernel_internals/parsing/logic_lexer.mll"
      ( Buffer.add_char buffer
          (match (lexeme lexbuf).[1] with
               'a' -> '\007'
             | 'b' -> '\b'
             | 'f' -> '\012'
             | 'n' -> '\n'
             | 'r' -> '\r'
             | 't' -> '\t'
             | 'v' -> '\011' (* no '\v' in OCaml 😞 *)
             | '\'' -> '\''
             | '"' -> '"'
             | '?' -> '?'
             | '\\' -> '\\'
             | _ -> (* escape regex does not allow anything else *) assert false
          ); chr buffer lexbuf)
# 1343 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 423 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Buffer.contents buffer )
# 1348 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 424 "src/kernel_internals/parsing/logic_lexer.mll"
       ( Buffer.add_string buffer (lexeme lexbuf); chr buffer lexbuf )
# 1353 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state

and hash lexbuf =
   __ocaml_lex_hash_rec lexbuf 130
and __ocaml_lex_hash_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 427 "src/kernel_internals/parsing/logic_lexer.mll"
        ( update_newline_loc lexbuf; token lexbuf)
# 1365 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 428 "src/kernel_internals/parsing/logic_lexer.mll"
             ( hash lexbuf)
# 1370 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 429 "src/kernel_internals/parsing/logic_lexer.mll"
              ( (* We are seeing a line number. This is the number for the
                   * next line *)
                 let s = Lexing.lexeme lexbuf in
                 let lineno =
                   try
                     int_of_string s
                   with Failure _ ->
                     (* the int is too big. *)
                     Kernel.warning
                       ~source:(Cil_datatype.Position.of_lexing_pos lexbuf.lex_start_p)
                       "Bad line number in preprocessed file: %s"  s;
                     (-1)
                 in
                 update_line_loc lexbuf (lineno - 1);
                  (* A file name may follow *)
		  file lexbuf )
# 1390 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 445 "src/kernel_internals/parsing/logic_lexer.mll"
                ( hash lexbuf )
# 1395 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 446 "src/kernel_internals/parsing/logic_lexer.mll"
            ( endline lexbuf)
# 1400 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_hash_rec lexbuf __ocaml_lex_state

and file lexbuf =
   __ocaml_lex_file_rec lexbuf 139
and __ocaml_lex_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 449 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( update_newline_loc lexbuf; token lexbuf)
# 1412 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 450 "src/kernel_internals/parsing/logic_lexer.mll"
                  ( file lexbuf)
# 1417 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 452 "src/kernel_internals/parsing/logic_lexer.mll"
            (
              let n = Lexing.lexeme lexbuf in
              let n1 = String.sub n 1
                ((String.length n) - 2) in
              update_file_loc lexbuf n1;
	      endline lexbuf
            )
# 1428 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 460 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1433 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_file_rec lexbuf __ocaml_lex_state

and endline lexbuf =
   __ocaml_lex_endline_rec lexbuf 146
and __ocaml_lex_endline_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 463 "src/kernel_internals/parsing/logic_lexer.mll"
                ( update_newline_loc lexbuf; token lexbuf)
# 1445 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 464 "src/kernel_internals/parsing/logic_lexer.mll"
                                ( EOF )
# 1450 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 465 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1455 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_endline_rec lexbuf __ocaml_lex_state

and comment lexbuf =
   __ocaml_lex_comment_rec lexbuf 150
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 468 "src/kernel_internals/parsing/logic_lexer.mll"
         ( update_newline_loc lexbuf; comment lexbuf)
# 1467 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 469 "src/kernel_internals/parsing/logic_lexer.mll"
         ( token lexbuf)
# 1472 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 470 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "non-terminating block-comment" )
# 1477 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 471 "src/kernel_internals/parsing/logic_lexer.mll"
         ( comment lexbuf)
# 1482 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

;;

# 473 "src/kernel_internals/parsing/logic_lexer.mll"
 
  let set_initial_location dest_lexbuf src_loc =
    Lexing.(
      dest_lexbuf.lex_curr_p <- 
        { src_loc with
          pos_bol = src_loc.pos_bol - src_loc.pos_cnum;
          pos_cnum = 0; };
    )

  let parse_from_location f (loc, s : Filepath.position * string) =
    let finally _ = Logic_utils.exit_kw_c_mode () in
    let output = Kernel.logwith finally ~wkey:Kernel.wkey_annot_error
    in
    let lb = from_string s in
    set_initial_location lb (Cil_datatype.Position.to_lexing_pos loc);
    try
      let res = f token lb in
      Some (Cil_datatype.Position.of_lexing_pos lb.Lexing.lex_curr_p, res)
    with
      | Failure s -> (* raised by the lexer itself, through [f] *)
          output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "lexing error: %s" s; None
      | Parsing.Parse_error ->
        output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "unexpected token '%s'" (Lexing.lexeme lb);
        None
      | Error (_, m) -> output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "%s" m; None
      | Logic_utils.Not_well_formed (loc, m) ->
        output ~source:(fst loc) "%s" m;
        None
      | Log.FeatureRequest(_,msg) ->
        output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "unimplemented ACSL feature: %s" msg; None
      | exn ->
        Kernel.fatal ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "Unknown error (%s)"
          (Printexc.to_string exn)

  let lexpr = parse_from_location Logic_parser.lexpr_eof

  let annot = parse_from_location Logic_parser.annot

  let spec = parse_from_location Logic_parser.spec

  let ext_spec lexbuf = try
      accept_c_comments_into_acsl_spec := true ;
      let r = Logic_parser.ext_spec token lexbuf in
      accept_c_comments_into_acsl_spec := false ;
      r
    with exn ->
      accept_c_comments_into_acsl_spec := false ;
      raise exn

  type 'a parse = Filepath.position * string -> (Filepath.position * 'a) option

  let chr lexbuf =
    let buf = Buffer.create 16 in
    chr buf lexbuf

# 1545 "src/kernel_internals/parsing/logic_lexer.ml"
