type token =
  | SPEC of (Filepath.position * string)
  | DECL of (Logic_ptree.decl list)
  | CODE_ANNOT of (Logic_ptree.code_annot * Cabs.cabsloc)
  | LOOP_ANNOT of (Logic_ptree.code_annot list * Cabs.cabsloc)
  | ATTRIBUTE_ANNOT of (string * Cabs.cabsloc)
  | CUSTOM_ANNOT of (Logic_ptree.custom_tree  * string * Cabs.cabsloc)
  | IDENT of (string)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | BOOL of (Cabs.cabsloc)
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | COLON2
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_EOL
  | LGHOST
  | RGHOST

open Parsing;;
let _ = parse_error;;
# 50 "src/kernel_internals/parsing/cparser.mly"

open Cabs
open Cabshelper
(* This function is used by the parsing engine generated by Ocamlyacc itself,
   and requires a string as argument. *)
let parse_error msg = Errorloc.parse_error "%s" msg

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> { expr_loc = cabslu; expr_node = NOTHING }
  | [expr] -> expr
  | _ ->
      let beg_loc = fst (List.hd lst).expr_loc in
      let end_loc = snd (Extlib.last lst).expr_loc in
      { expr_loc = (beg_loc,end_loc); expr_node = COMMA (lst) }

let merge_string (c1,(b1,_)) (c2,(_,e2)) = c1 @ c2, (b1,e2)

(* To be called only inside a grammar rule. *)
let make_expr e =
  { expr_loc = Cil_datatype.Location.of_lexing_loc (symbol_start_pos (), symbol_end_pos ());
    expr_node = e }

let currentFunctionName = ref "<outside any function>"

exception NoProto

(* Go through all the parameter names and mark them as identifiers *)
let rec findProto = function
    PROTO (d, args, _) when isJUSTBASE d ->
      List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args
  | PROTO (d, _, _) -> findProto d
  | PARENTYPE (_, d, _) -> findProto d
  | PTR (_, d) -> findProto d
  | ARRAY (d, _, _) -> findProto d
  | _ -> raise NoProto

and isJUSTBASE = function
    JUSTBASE -> true
  | PARENTYPE (_, d, _) -> isJUSTBASE d
  | _ -> false

let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body.
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (try findProto decl
   with NoProto ->
     Errorloc.parse_error "Cannot find the prototype in a function definition");
  currentFunctionName := n

let check_funspec_abrupt_clauses fname spec =
  List.iter
    (fun bhv ->
      List.iter
	(function
	| (Cil_types.Normal | Cil_types.Exits),_ -> ()
	| (Cil_types.Breaks | Cil_types.Continues | Cil_types.Returns),
          {Logic_ptree.lexpr_loc = (loc,_)} ->
          Errorloc.parse_error ~source:loc
            "Specification of function %s can only contain ensures or \
                 exits post-conditions" fname)
	bhv.Logic_ptree.b_post_cond)
    spec.Logic_ptree.spec_behavior

let applyPointer (ptspecs: attribute list list) (dt: decl_type)
       : decl_type =
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration logic_spec (loc: cabsloc) (specs: spec_elem list) (nl: init_name list)  =
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      !Lexerhack.push_context ();
      List.iter
        (fun ((_,t,_,_),_) ->
           try findProto t with NoProto -> ())
        nl;
      let logic_spec =
        match logic_spec with
        | None -> None
        | Some (loc, _ as ls) -> begin
            Extlib.opt_map
              (fun (loc', spec) ->
                 let name =
                   match nl with
                   | [ (n,_,_,_),_ ] -> n
                   | _ -> "unknown function"
                 in
                 check_funspec_abrupt_clauses name spec;
                 (spec, (loc, loc')))
              (Logic_lexer.spec ls)
          end
      in
      !Lexerhack.pop_context ();
      DECDEF (logic_spec, (specs, nl), loc)
    end


let doFunctionDef spec (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list)
                  (n: name)
                  (b: block) : definition =
  let fname = (specs, n) in
  let name = match n with (n,_,_,_) -> n in
  Extlib.may (fun (spec, _) -> check_funspec_abrupt_clauses name spec) spec;
  FUNDEF (spec, fname, b, loc, lend)

let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool))
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let int64_to_char value =
  if (Int64.compare value (Int64.of_int 255) > 0) ||
    (Int64.compare value Int64.zero < 0) then
    Errorloc.parse_error "integral literal 0x%Lx too big" value
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let intlist_to_string (str: int64 list):string =
  let buffer = Buffer.create (List.length str) in
  let add_char c =
    Buffer.add_char buffer (int64_to_char c)
  in
  List.iter add_char str ;
  Buffer.contents buffer

let fst3 (result, _, _) = result
let trd3 (_, _, result) = result

let fourth4 (_,_,_,result) = result

(*
   transform:  __builtin_offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let sizeofType () =
  let findSpecifier name =
    let convert_one_specifier s =
      if s = "int" then Cabs.Tint
      else if s = "unsigned" then Cabs.Tunsigned
      else if s = "long" then Cabs.Tlong
      else if s = "short" then Cabs.Tshort
      else if s = "char" then Cabs.Tchar
      else
        Kernel.fatal
          ~current:true
          "initCIL: cannot find the right specifier for type %s" name
    in
    let add_one_specifier s acc =
      (Cabs.SpecType (convert_one_specifier s)) :: acc
    in
    let specs = Str.split (Str.regexp " +") name in
    List.fold_right add_one_specifier specs []
  in
  findSpecifier Cil.theMachine.Cil.theMachine.Cil_types.size_t


let transformOffsetOf (speclist, dtype) member =
  let mk_expr e = { expr_loc = member.expr_loc; expr_node = e } in
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, variadic) ->
	PROTO (addPointer dtype, names, variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = mk_expr (CONSTANT (CONST_INT "0")) in
  let castExpr = mk_expr (CAST (nullType, SINGLE_INIT nullExpr)) in

  let rec replaceBase e =
    let node = match e.expr_node with
      | VARIABLE field ->
	  MEMBEROFPTR (castExpr, field)
      | MEMBEROF (base, field) ->
	  MEMBEROF (replaceBase base, field)
      | INDEX (base, index) ->
	  INDEX (replaceBase base, index)
      | _ ->
	Errorloc.parse_error "malformed offset expression in __builtin_offsetof"
    in { e with expr_node = node }
  in
  let memberExpr = replaceBase member in
  let addrExpr = { memberExpr with expr_node = UNARY (ADDROF, memberExpr)} in
  let sizeofType = sizeofType(), JUSTBASE in
  { addrExpr with expr_node = CAST (sizeofType, SINGLE_INIT addrExpr)}

let no_ghost_stmt s = {stmt_ghost = false ; stmt_node = s}

let no_ghost = List.map no_ghost_stmt

let in_ghost =
  let ghost_me = object
    inherit Cabsvisit.nopCabsVisitor
    method! vstmt s =
      s.stmt_ghost <- true;
      Cil.DoChildren
  end
  in
  List.map
    (fun s -> ignore (Cabsvisit.visitCabsStatement ghost_me s); s)

let in_block l =
  match l with
      [] -> no_ghost_stmt (NOP cabslu)
    | [s] -> s
    | _::_ ->
        no_ghost_stmt (BLOCK ({ blabels = []; battrs = []; bstmts = l},
                              get_statementloc (List.hd l),
                              get_statementloc (Extlib.last l)))

# 380 "src/kernel_internals/parsing/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  296 (* EQ *);
  297 (* PLUS_EQ *);
  298 (* MINUS_EQ *);
  299 (* STAR_EQ *);
  300 (* SLASH_EQ *);
  301 (* PERCENT_EQ *);
  302 (* AND_EQ *);
  303 (* PIPE_EQ *);
  304 (* CIRC_EQ *);
  305 (* INF_INF_EQ *);
  306 (* SUP_SUP_EQ *);
  307 (* ARROW *);
  308 (* DOT *);
  309 (* EQ_EQ *);
  310 (* EXCLAM_EQ *);
  311 (* INF *);
  312 (* SUP *);
  313 (* INF_EQ *);
  314 (* SUP_EQ *);
  318 (* SLASH *);
  319 (* PERCENT *);
  322 (* PIPE *);
  323 (* CIRC *);
  326 (* PIPE_PIPE *);
  327 (* INF_INF *);
  328 (* SUP_SUP *);
  331 (* RPAREN *);
  335 (* LBRACKET *);
  336 (* RBRACKET *);
  337 (* COLON *);
  338 (* COLON2 *);
  340 (* COMMA *);
  341 (* ELLIPSIS *);
  342 (* QUEST *);
  357 (* ELSE *);
  364 (* LABEL__ *);
  366 (* BLOCKATTRIBUTE *);
  374 (* PRAGMA_EOL *);
  375 (* LGHOST *);
  376 (* RGHOST *);
    0|]

let yytransl_block = [|
  257 (* SPEC *);
  258 (* DECL *);
  259 (* CODE_ANNOT *);
  260 (* LOOP_ANNOT *);
  261 (* ATTRIBUTE_ANNOT *);
  262 (* CUSTOM_ANNOT *);
  263 (* IDENT *);
  264 (* CST_CHAR *);
  265 (* CST_WCHAR *);
  266 (* CST_INT *);
  267 (* CST_FLOAT *);
  268 (* NAMED_TYPE *);
  269 (* CST_STRING *);
  270 (* CST_WSTRING *);
  271 (* BOOL *);
  272 (* CHAR *);
  273 (* INT *);
  274 (* DOUBLE *);
  275 (* FLOAT *);
  276 (* VOID *);
  277 (* INT64 *);
  278 (* ENUM *);
  279 (* STRUCT *);
  280 (* TYPEDEF *);
  281 (* UNION *);
  282 (* SIGNED *);
  283 (* UNSIGNED *);
  284 (* LONG *);
  285 (* SHORT *);
  286 (* VOLATILE *);
  287 (* EXTERN *);
  288 (* STATIC *);
  289 (* CONST *);
  290 (* RESTRICT *);
  291 (* AUTO *);
  292 (* REGISTER *);
  293 (* THREAD *);
  294 (* SIZEOF *);
  295 (* ALIGNOF *);
  315 (* PLUS *);
  316 (* MINUS *);
  317 (* STAR *);
  320 (* TILDE *);
  321 (* AND *);
  324 (* EXCLAM *);
  325 (* AND_AND *);
  329 (* PLUS_PLUS *);
  330 (* MINUS_MINUS *);
  332 (* LPAREN *);
  333 (* RBRACE *);
  334 (* LBRACE *);
  339 (* SEMICOLON *);
  343 (* BREAK *);
  344 (* CONTINUE *);
  345 (* GOTO *);
  346 (* RETURN *);
  347 (* SWITCH *);
  348 (* CASE *);
  349 (* DEFAULT *);
  350 (* WHILE *);
  351 (* DO *);
  352 (* FOR *);
  353 (* IF *);
  354 (* TRY *);
  355 (* EXCEPT *);
  356 (* FINALLY *);
  358 (* ATTRIBUTE *);
  359 (* INLINE *);
  360 (* ASM *);
  361 (* TYPEOF *);
  362 (* FUNCTION__ *);
  363 (* PRETTY_FUNCTION__ *);
  365 (* BUILTIN_VA_ARG *);
  367 (* BUILTIN_TYPES_COMPAT *);
  368 (* BUILTIN_OFFSETOF *);
  369 (* DECLSPEC *);
  370 (* MSASM *);
  371 (* MSATTR *);
  372 (* PRAGMA_LINE *);
  373 (* PRAGMA *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\003\000\051\000\051\000\
\051\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\054\000\054\000\055\000\056\000\056\000\
\057\000\057\000\057\000\057\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\058\000\059\000\
\059\000\059\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\062\000\062\000\063\000\063\000\063\000\063\000\064\000\064\000\
\064\000\065\000\065\000\065\000\066\000\066\000\066\000\066\000\
\066\000\067\000\067\000\067\000\068\000\068\000\069\000\069\000\
\070\000\070\000\071\000\071\000\072\000\072\000\073\000\073\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\010\000\008\000\008\000\008\000\
\008\000\008\000\008\000\009\000\017\000\017\000\018\000\018\000\
\018\000\018\000\075\000\075\000\075\000\012\000\012\000\020\000\
\020\000\060\000\060\000\019\000\019\000\019\000\076\000\076\000\
\021\000\021\000\021\000\022\000\022\000\077\000\015\000\015\000\
\011\000\011\000\013\000\013\000\078\000\078\000\014\000\016\000\
\034\000\079\000\080\000\080\000\035\000\035\000\035\000\035\000\
\035\000\082\000\082\000\084\000\084\000\036\000\036\000\037\000\
\037\000\085\000\085\000\083\000\083\000\083\000\083\000\083\000\
\083\000\083\000\083\000\083\000\083\000\083\000\083\000\083\000\
\083\000\083\000\083\000\083\000\083\000\083\000\083\000\083\000\
\083\000\083\000\083\000\083\000\086\000\086\000\091\000\092\000\
\087\000\087\000\030\000\030\000\030\000\030\000\040\000\040\000\
\093\000\093\000\094\000\039\000\039\000\095\000\095\000\095\000\
\095\000\095\000\095\000\095\000\095\000\023\000\023\000\099\000\
\099\000\097\000\097\000\098\000\098\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\025\000\025\000\025\000\025\000\025\000\
\043\000\043\000\042\000\042\000\042\000\029\000\029\000\028\000\
\028\000\041\000\101\000\101\000\101\000\044\000\044\000\044\000\
\044\000\044\000\103\000\104\000\105\000\105\000\105\000\027\000\
\027\000\027\000\027\000\026\000\106\000\038\000\038\000\053\000\
\053\000\053\000\107\000\107\000\048\000\049\000\049\000\033\000\
\033\000\047\000\047\000\045\000\045\000\045\000\045\000\046\000\
\046\000\031\000\031\000\032\000\032\000\032\000\032\000\032\000\
\050\000\050\000\050\000\050\000\005\000\005\000\006\000\006\000\
\006\000\096\000\096\000\096\000\096\000\088\000\088\000\102\000\
\102\000\102\000\102\000\102\000\109\000\109\000\100\000\100\000\
\052\000\052\000\052\000\052\000\111\000\111\000\111\000\111\000\
\111\000\111\000\112\000\112\000\112\000\113\000\113\000\114\000\
\114\000\114\000\115\000\115\000\116\000\116\000\116\000\117\000\
\117\000\117\000\117\000\117\000\117\000\117\000\118\000\118\000\
\118\000\118\000\118\000\118\000\118\000\118\000\118\000\118\000\
\118\000\119\000\120\000\120\000\120\000\120\000\121\000\121\000\
\121\000\122\000\122\000\122\000\123\000\123\000\123\000\123\000\
\123\000\124\000\124\000\124\000\125\000\125\000\126\000\126\000\
\127\000\127\000\128\000\128\000\129\000\129\000\130\000\130\000\
\132\000\132\000\131\000\110\000\133\000\133\000\134\000\134\000\
\081\000\108\000\007\000\007\000\007\000\089\000\089\000\090\000\
\090\000\135\000\135\000\137\000\137\000\138\000\136\000\136\000\
\139\000\139\000\140\000\140\000\140\000\142\000\142\000\141\000\
\141\000\000\000\000\000"

let yylen = "\002\000\
\001\000\002\000\000\000\002\000\003\000\002\000\002\000\002\000\
\001\000\001\000\001\000\001\000\001\000\003\000\005\000\005\000\
\001\000\006\000\004\000\001\000\001\000\001\000\000\000\001\000\
\001\000\001\000\001\000\003\000\001\000\002\000\004\000\006\000\
\006\000\006\000\003\000\003\000\002\000\002\000\006\000\001\000\
\003\000\002\000\001\000\002\000\002\000\002\000\004\000\002\000\
\004\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\001\000\004\000\001\000\003\000\003\000\003\000\001\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\005\000\
\001\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\001\000\002\000\
\002\000\002\000\001\000\001\000\001\000\001\000\003\000\001\000\
\003\000\000\000\001\000\003\000\002\000\001\000\001\000\000\000\
\003\000\004\000\005\000\000\000\001\000\002\000\000\000\001\000\
\000\000\001\000\001\000\003\000\000\000\001\000\003\000\003\000\
\005\000\001\000\000\000\002\000\001\000\003\000\003\000\003\000\
\003\000\000\000\001\000\002\000\004\000\000\000\004\000\001\000\
\003\000\001\000\002\000\001\000\002\000\002\000\001\000\003\000\
\005\000\003\000\004\000\006\000\009\000\004\000\004\000\006\000\
\003\000\002\000\003\000\002\000\002\000\003\000\004\000\008\000\
\007\000\001\000\005\000\004\000\000\000\001\000\001\000\001\000\
\002\000\001\000\003\000\002\000\004\000\003\000\001\000\003\000\
\001\000\003\000\002\000\001\000\003\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\002\000\002\000\
\002\000\000\000\001\000\000\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\002\000\003\000\005\000\004\000\006\000\005\000\002\000\005\000\
\004\000\006\000\005\000\002\000\006\000\005\000\007\000\006\000\
\001\000\004\000\004\000\000\000\003\000\002\000\004\000\002\000\
\001\000\003\000\001\000\004\000\002\000\001\000\003\000\001\000\
\003\000\003\000\002\000\004\000\003\000\001\000\004\000\004\000\
\003\000\004\000\001\000\002\000\000\000\002\000\003\000\002\000\
\002\000\001\000\003\000\002\000\005\000\001\000\003\000\000\000\
\004\000\004\000\001\000\003\000\003\000\000\000\001\000\002\000\
\001\000\003\000\001\000\004\000\004\000\004\000\003\000\001\000\
\000\000\003\000\002\000\002\000\002\000\004\000\005\000\003\000\
\001\000\001\000\001\000\001\000\000\000\002\000\000\000\002\000\
\005\000\004\000\002\000\001\000\001\000\000\000\002\000\001\000\
\001\000\001\000\001\000\001\000\004\000\002\000\001\000\002\000\
\002\000\003\000\004\000\001\000\001\000\001\000\003\000\001\000\
\001\000\003\000\001\000\001\000\001\000\001\000\002\000\001\000\
\002\000\003\000\001\000\001\000\001\000\003\000\001\000\001\000\
\002\000\003\000\002\000\003\000\003\000\004\000\001\000\002\000\
\004\000\002\000\004\000\002\000\002\000\002\000\002\000\002\000\
\002\000\001\000\001\000\003\000\003\000\003\000\001\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\006\000\
\001\000\003\000\000\000\001\000\001\000\003\000\000\000\001\000\
\003\000\003\000\000\000\002\000\002\000\001\000\002\000\000\000\
\003\000\000\000\001\000\001\000\003\000\005\000\000\000\003\000\
\000\000\003\000\000\000\002\000\003\000\001\000\003\000\000\000\
\002\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\010\000\060\001\011\000\000\000\
\249\000\224\000\223\000\226\000\230\000\229\000\222\000\228\000\
\000\000\000\000\206\000\000\000\231\000\232\000\227\000\225\000\
\058\001\000\000\208\000\057\001\059\001\209\000\210\000\069\001\
\000\000\000\000\211\000\000\000\000\000\000\000\068\001\084\001\
\000\000\000\000\186\001\001\000\000\000\000\000\000\000\000\000\
\012\000\013\000\000\000\212\000\017\000\000\000\213\000\187\001\
\000\000\207\000\000\000\000\000\000\000\000\000\020\000\021\000\
\000\000\000\000\000\000\022\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\115\000\116\000\117\000\
\000\000\000\000\109\000\006\000\000\000\000\000\000\000\000\000\
\067\001\000\000\000\000\092\001\000\000\089\001\088\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\081\001\103\001\000\000\000\000\093\001\000\000\104\001\
\000\000\122\001\123\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\156\001\009\000\
\000\000\000\000\000\000\002\000\004\000\000\000\196\000\053\001\
\000\000\000\000\000\000\039\001\000\000\000\000\000\000\215\000\
\221\000\146\000\051\001\000\000\219\000\214\000\000\000\198\000\
\000\000\050\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\006\001\000\000\000\000\078\001\000\000\000\000\
\000\000\080\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\014\000\110\000\000\000\000\000\000\000\025\000\104\000\105\000\
\102\000\103\000\111\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\026\000\106\000\000\000\027\000\000\000\000\000\
\000\000\000\000\029\000\000\000\057\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\089\000\101\000\000\000\000\000\000\000\000\000\112\001\000\000\
\114\001\116\001\117\001\118\001\121\001\119\001\120\001\000\000\
\000\000\000\000\105\001\000\000\082\001\085\001\086\001\100\001\
\000\000\000\000\099\001\107\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\155\001\000\000\007\000\008\000\005\000\076\001\075\001\
\073\001\074\001\000\000\072\001\000\000\000\000\195\000\000\000\
\000\000\000\000\014\001\028\001\217\000\216\000\000\000\000\000\
\056\001\000\000\197\000\000\000\019\000\000\000\000\000\024\001\
\025\001\000\000\000\000\000\000\020\001\054\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\254\000\000\000\000\000\
\000\000\000\000\000\000\000\000\236\000\000\001\000\000\000\000\
\000\000\241\000\000\000\000\000\000\000\000\000\000\000\000\000\
\160\001\000\000\066\001\000\000\000\000\046\000\000\000\048\000\
\050\000\051\000\052\000\055\000\053\000\054\000\056\000\000\000\
\044\000\045\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\250\000\114\000\113\000\112\000\040\001\000\000\251\000\
\000\000\000\000\037\000\038\000\000\000\000\000\030\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\161\001\090\001\
\000\000\000\000\102\001\087\001\106\001\083\001\095\001\000\000\
\108\001\109\001\000\000\124\001\125\001\126\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\154\001\037\001\
\062\001\000\000\200\000\000\000\000\000\000\000\118\000\205\000\
\000\000\000\000\000\000\000\000\010\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\031\001\000\000\000\000\027\001\
\000\000\000\000\000\000\000\000\022\001\000\000\009\001\007\001\
\246\000\077\001\000\000\000\000\000\000\005\001\253\000\000\000\
\000\000\000\000\235\000\238\000\000\000\240\000\243\000\000\000\
\015\000\162\001\016\000\000\000\000\000\000\000\000\000\143\000\
\000\000\028\000\000\000\000\000\000\000\000\000\036\000\035\000\
\136\000\000\000\000\000\090\000\091\000\092\000\093\000\094\000\
\095\000\096\000\097\000\098\000\099\000\100\000\060\000\061\000\
\062\000\059\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\138\000\158\001\000\000\000\000\098\001\110\001\
\000\000\203\000\000\000\071\001\000\000\000\000\000\000\126\000\
\000\000\123\000\000\000\000\000\000\000\000\000\000\000\017\001\
\000\000\000\000\000\000\000\000\000\000\000\000\064\001\000\000\
\000\000\000\000\148\000\000\000\000\000\000\000\000\000\155\000\
\055\001\000\000\000\000\018\000\000\000\000\000\000\000\042\001\
\000\000\000\000\023\001\245\000\248\000\000\000\000\000\002\001\
\255\000\237\000\242\000\000\000\000\000\000\000\140\000\000\000\
\058\000\000\000\000\000\000\000\000\000\031\000\144\000\000\000\
\000\000\202\000\000\000\000\000\000\000\127\000\000\000\134\000\
\119\000\125\000\015\001\000\000\000\000\142\000\011\001\016\001\
\000\000\000\000\018\001\159\000\161\000\156\000\000\000\145\000\
\000\000\192\000\000\000\164\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\186\000\000\000\
\000\000\167\000\000\000\000\000\000\000\000\000\190\000\191\000\
\000\000\000\000\000\000\047\001\000\000\000\000\247\000\004\001\
\000\000\000\000\000\000\040\000\000\000\088\000\152\001\133\000\
\129\000\000\000\000\000\121\000\124\000\029\001\013\001\000\000\
\000\000\000\000\000\000\000\000\162\000\000\000\165\000\180\000\
\181\000\000\000\000\000\178\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\166\000\
\150\000\152\000\000\000\151\000\000\000\000\000\000\000\036\001\
\033\001\034\001\044\001\046\001\045\001\039\000\032\000\033\000\
\000\000\034\000\042\000\130\000\000\000\012\001\065\001\157\000\
\000\000\163\000\000\000\182\000\179\000\170\000\000\000\000\000\
\177\000\000\000\000\000\000\000\164\001\165\001\000\000\000\000\
\000\000\000\000\000\000\000\000\041\000\131\000\183\000\175\000\
\000\000\000\000\000\000\188\000\000\000\000\000\000\000\174\000\
\171\000\000\000\000\000\194\000\000\000\000\000\169\000\187\000\
\000\000\167\001\000\000\000\000\000\000\193\000\000\000\176\000\
\000\000\000\000\000\000\000\000\172\001\000\000\000\000\172\000\
\000\000\000\000\000\000\000\000\169\001\000\000\000\000\185\000\
\000\000\184\000\178\001\000\000\173\001\000\000\000\000\000\000\
\176\001\000\000\173\000\000\000\000\000\180\001\000\000\174\001\
\185\001\000\000\181\001\183\001"

let yydgoto = "\003\000\
\043\000\044\000\045\000\046\000\035\001\205\001\199\002\211\000\
\212\000\107\001\034\002\048\002\144\002\214\000\002\002\127\001\
\215\000\216\000\049\002\050\002\051\002\169\002\172\000\048\000\
\173\000\136\000\160\000\163\000\164\000\049\000\050\000\051\000\
\218\000\146\002\070\002\048\001\208\001\157\000\137\000\138\000\
\088\001\074\001\075\001\218\001\219\001\220\001\155\002\140\000\
\076\001\052\000\131\000\174\000\215\001\108\000\043\001\065\001\
\219\000\220\000\165\002\053\002\221\000\222\000\223\000\224\000\
\225\000\226\000\227\000\228\000\229\000\230\000\231\000\232\000\
\233\000\234\000\083\000\111\002\054\002\119\002\148\000\211\001\
\089\000\071\002\181\002\182\002\183\002\150\002\005\003\194\001\
\255\002\012\003\151\002\152\002\195\001\196\001\054\000\055\000\
\150\000\144\000\145\000\070\000\060\002\037\001\062\000\161\000\
\061\001\044\001\075\002\188\000\071\000\235\000\110\000\111\000\
\002\001\003\001\004\001\112\000\113\000\114\000\115\000\116\000\
\117\000\118\000\119\000\120\000\121\000\122\000\123\000\124\000\
\125\000\126\000\190\001\127\000\236\000\090\001\019\003\029\003\
\020\003\021\003\022\003\041\003\046\003\047\003"

let yysindex = "\222\000\
\001\007\001\007\000\000\229\016\000\000\000\000\000\000\238\254\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\096\255\041\000\000\000\125\000\000\000\000\000\000\000\000\000\
\000\000\115\255\000\000\000\000\000\000\000\000\000\000\000\000\
\001\007\248\254\000\000\020\255\104\255\135\255\000\000\000\000\
\215\012\028\002\000\000\000\000\184\000\001\007\010\255\013\009\
\000\000\000\000\155\255\000\000\000\000\245\018\000\000\000\000\
\207\255\000\000\111\255\155\255\035\255\075\017\000\000\000\000\
\236\255\220\255\135\255\000\000\013\000\229\255\255\255\158\011\
\017\000\014\000\158\011\046\000\118\000\000\000\000\000\000\000\
\060\009\115\255\000\000\000\000\238\255\115\255\180\013\075\028\
\000\000\000\000\001\000\000\000\000\000\000\000\000\000\022\026\
\097\026\075\028\075\028\075\028\075\028\075\028\075\028\075\028\
\030\000\000\000\000\000\052\000\229\254\000\000\239\001\000\000\
\110\000\000\000\000\000\083\001\097\001\029\001\023\002\142\001\
\081\000\093\000\144\000\107\000\051\255\186\000\000\000\000\000\
\028\002\028\002\001\007\000\000\000\000\254\003\000\000\000\000\
\149\000\145\000\209\000\000\000\138\000\013\009\013\009\000\000\
\000\000\000\000\000\000\146\000\000\000\000\000\069\255\000\000\
\175\000\000\000\223\000\187\000\241\000\075\017\007\001\244\000\
\000\001\038\001\000\000\010\001\238\255\000\000\236\255\236\255\
\019\001\000\000\158\011\154\255\026\001\158\011\158\011\158\011\
\035\001\034\001\158\011\158\011\039\001\245\018\001\007\010\255\
\000\000\000\000\075\028\046\001\057\001\000\000\000\000\000\000\
\000\000\000\000\000\000\172\026\247\026\066\027\066\027\066\027\
\066\027\066\027\066\027\099\255\141\027\141\027\071\013\059\001\
\073\001\090\001\000\000\000\000\093\001\000\000\041\255\060\255\
\007\001\095\001\000\000\115\002\000\000\230\002\179\001\149\001\
\155\001\039\002\181\001\114\001\118\001\122\001\121\001\201\255\
\000\000\000\000\115\001\145\001\195\001\071\013\000\000\071\013\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\156\001\
\207\001\035\028\000\000\105\001\000\000\000\000\000\000\000\000\
\033\001\115\255\000\000\000\000\099\255\099\255\075\028\075\028\
\075\028\075\028\075\028\075\028\075\028\075\028\075\028\075\028\
\075\028\075\028\075\028\075\028\075\028\075\028\075\028\075\028\
\075\028\000\000\075\028\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\007\001\000\000\254\003\162\000\000\000\082\024\
\254\003\202\000\000\000\000\000\000\000\000\000\099\255\119\001\
\000\000\169\001\000\000\254\001\000\000\245\018\198\001\000\000\
\000\000\000\000\217\000\196\016\000\000\000\000\066\027\236\255\
\200\001\204\001\010\001\010\001\236\255\000\000\066\027\158\011\
\194\001\208\001\201\001\138\000\000\000\000\000\220\001\245\001\
\158\011\000\000\251\001\011\002\158\011\111\255\015\002\209\000\
\000\000\029\002\000\000\030\002\071\013\000\000\071\013\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\071\013\
\000\000\000\000\040\002\051\002\057\002\067\002\066\027\245\018\
\245\018\000\000\000\000\000\000\000\000\000\000\073\002\000\000\
\099\255\099\255\000\000\000\000\066\027\066\027\000\000\066\027\
\066\027\066\027\066\027\066\027\066\027\066\027\066\027\066\027\
\066\027\066\027\066\027\066\027\066\027\066\027\066\027\066\027\
\066\027\066\027\066\027\066\027\066\027\066\027\066\027\066\027\
\066\027\066\027\066\027\066\027\066\027\075\028\000\000\000\000\
\069\002\076\002\000\000\000\000\000\000\000\000\000\000\033\001\
\000\000\000\000\078\002\000\000\000\000\000\000\083\001\083\001\
\097\001\097\001\029\001\029\001\029\001\029\001\023\002\023\002\
\142\001\081\000\093\000\144\000\107\000\075\028\000\000\000\000\
\000\000\007\001\000\000\079\002\162\000\112\023\000\000\000\000\
\007\001\156\255\093\255\077\002\000\000\068\002\075\017\088\002\
\089\002\135\255\030\255\245\018\000\000\007\001\091\002\000\000\
\254\003\051\012\158\000\099\002\000\000\244\000\000\000\000\000\
\000\000\000\000\102\002\103\002\010\001\000\000\000\000\066\027\
\039\255\158\011\000\000\000\000\108\002\000\000\000\000\113\002\
\000\000\000\000\000\000\118\002\120\002\123\002\066\027\000\000\
\157\024\000\000\140\002\141\002\143\002\254\003\000\000\000\000\
\000\000\153\002\189\002\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\179\001\179\001\149\001\149\001\155\001\155\001\
\155\001\155\001\039\002\039\002\181\001\114\001\118\001\122\001\
\121\001\200\002\000\000\000\000\204\002\204\002\000\000\000\000\
\201\002\000\000\162\000\000\000\000\000\099\255\066\027\000\000\
\202\002\000\000\244\002\206\002\208\002\082\024\216\002\000\000\
\220\002\254\003\066\027\219\002\254\003\115\255\000\000\221\002\
\146\000\099\255\000\000\030\255\030\255\223\002\090\008\000\000\
\000\000\217\002\225\002\000\000\007\001\234\002\235\002\000\000\
\075\017\066\027\000\000\000\000\000\000\227\002\254\003\000\000\
\000\000\000\000\000\000\204\002\204\002\204\002\000\000\112\023\
\000\000\245\018\245\018\099\255\007\001\000\000\000\000\066\027\
\075\028\000\000\023\255\051\000\112\023\000\000\082\024\000\000\
\000\000\000\000\000\000\245\018\066\027\000\000\000\000\000\000\
\023\003\238\002\000\000\000\000\000\000\000\000\195\002\000\000\
\167\005\000\000\000\000\000\000\245\002\246\002\140\000\232\024\
\254\002\066\027\000\003\254\002\155\255\004\000\000\000\047\003\
\030\255\000\000\030\255\002\003\030\255\163\001\000\000\000\000\
\007\001\108\017\057\003\000\000\058\003\055\003\000\000\000\000\
\059\003\063\003\066\003\000\000\040\255\000\000\000\000\000\000\
\000\000\023\255\066\027\000\000\000\000\000\000\000\000\066\027\
\254\003\030\255\142\006\061\003\000\000\055\011\000\000\000\000\
\000\000\066\027\060\003\000\000\062\003\066\027\142\006\129\255\
\142\006\142\006\148\001\003\001\003\001\003\001\068\003\000\000\
\000\000\000\000\162\000\000\000\254\002\142\006\070\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\140\003\000\000\000\000\000\000\072\003\000\000\000\000\000\000\
\162\000\000\000\065\003\000\000\000\000\000\000\142\006\066\027\
\000\000\052\003\254\002\155\255\000\000\000\000\080\003\115\255\
\142\006\142\006\067\003\207\008\000\000\000\000\000\000\000\000\
\076\003\142\006\155\255\000\000\115\255\115\255\079\003\000\000\
\000\000\254\002\082\003\000\000\066\027\142\006\000\000\000\000\
\079\003\000\000\083\003\095\003\088\003\000\000\089\003\000\000\
\099\003\168\003\108\003\092\003\000\000\115\255\107\003\000\000\
\066\027\115\003\111\003\083\003\000\000\083\003\124\003\000\000\
\134\003\000\000\000\000\132\003\000\000\066\027\142\006\007\000\
\000\000\183\003\000\000\099\255\176\003\000\000\180\003\000\000\
\000\000\115\255\000\000\000\000"

let yyrindex = "\000\000\
\006\005\006\005\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\031\016\000\000\000\000\000\000\000\000\000\000\000\000\
\012\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\012\000\062\001\154\009\
\000\000\000\000\000\000\000\000\000\000\086\008\000\000\000\000\
\000\000\000\000\062\001\000\000\210\017\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\033\014\000\000\201\000\186\003\
\135\014\000\000\186\003\237\014\000\000\000\000\000\000\000\000\
\000\000\114\007\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\225\011\137\012\000\000\053\012\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\010\007\000\000\
\104\006\000\000\000\000\006\029\218\017\250\005\069\030\131\011\
\100\000\184\011\117\002\089\001\002\001\138\001\000\000\000\000\
\000\000\000\000\012\000\000\000\000\000\055\001\000\000\000\000\
\181\003\000\000\243\000\000\000\000\000\154\009\154\009\000\000\
\000\000\000\000\000\000\189\004\000\000\000\000\210\017\000\000\
\000\000\000\000\190\003\191\003\000\000\000\000\147\002\195\003\
\000\000\039\000\000\000\197\003\000\000\000\000\000\000\000\000\
\000\000\000\000\186\003\062\001\000\000\186\003\186\003\186\003\
\083\015\000\000\186\003\186\003\000\000\000\000\200\003\062\001\
\000\000\000\000\145\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\137\009\223\009\
\169\000\000\000\000\000\053\010\000\000\094\016\017\018\254\018\
\201\019\254\020\169\021\117\001\205\016\037\002\104\022\182\000\
\000\000\000\000\204\003\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\031\023\104\028\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\010\004\000\000\223\022\102\001\000\000\000\000\
\130\001\041\001\000\000\000\000\000\000\000\000\000\000\050\005\
\000\000\000\000\000\000\000\000\000\000\115\000\000\000\000\000\
\000\000\162\004\203\003\000\000\000\000\000\000\000\000\209\003\
\000\000\000\000\197\003\197\003\000\000\000\000\000\000\186\003\
\154\001\206\003\000\000\000\000\000\000\000\000\000\000\000\000\
\186\003\000\000\000\000\000\000\186\003\062\001\000\000\170\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\024\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\203\003\000\000\
\000\000\000\000\000\000\000\000\217\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\212\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\145\028\
\000\000\000\000\000\000\000\000\000\000\000\000\043\029\080\029\
\117\029\154\029\191\029\228\029\009\030\046\030\093\030\116\030\
\202\012\035\004\006\014\021\011\225\006\000\000\000\000\000\000\
\000\000\062\001\000\000\223\003\028\006\230\003\000\000\000\000\
\062\001\210\017\053\025\000\000\000\000\012\001\000\000\000\000\
\209\255\000\000\229\007\237\003\000\000\062\001\239\003\000\000\
\161\000\228\000\172\000\000\000\000\000\195\003\000\000\000\000\
\000\000\000\000\000\000\000\000\197\003\000\000\000\000\000\000\
\062\001\186\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\234\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\080\018\143\018\075\019\138\019\008\020\071\020\
\134\020\197\020\055\021\112\021\226\021\027\022\084\017\047\022\
\143\022\000\000\000\000\000\000\186\028\225\028\000\000\000\000\
\000\000\000\000\102\001\000\000\195\030\000\000\000\000\000\000\
\231\003\000\000\128\025\000\000\000\000\000\000\000\000\000\000\
\000\000\216\027\245\003\000\000\188\023\000\000\000\000\000\000\
\189\004\000\000\000\000\090\003\207\003\000\000\116\001\000\000\
\000\000\247\003\000\000\000\000\193\000\210\017\210\017\000\000\
\000\000\245\003\000\000\000\000\000\000\000\000\187\001\000\000\
\000\000\000\000\000\000\139\010\225\010\000\000\000\000\230\003\
\000\000\000\000\000\000\000\000\215\000\000\000\000\000\000\000\
\000\000\000\000\007\024\000\000\230\003\000\000\000\000\000\000\
\000\000\000\000\000\000\237\003\000\000\000\000\000\000\000\000\
\203\025\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\192\001\000\000\185\015\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\008\004\000\000\000\000\
\090\003\000\000\090\003\000\000\090\003\000\000\000\000\000\000\
\062\001\115\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\007\024\000\000\000\000\000\000\000\000\000\000\000\000\
\056\003\090\003\192\001\000\000\000\000\192\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\192\001\000\000\
\192\001\192\001\000\000\008\004\008\004\008\004\000\000\000\000\
\000\000\000\000\069\004\000\000\000\000\192\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\028\006\000\000\000\000\000\000\000\000\000\000\192\001\000\000\
\000\000\229\002\000\000\000\000\000\000\000\000\000\000\000\000\
\192\001\192\001\000\000\004\004\000\000\000\000\000\000\000\000\
\000\000\192\001\000\000\000\000\000\000\063\000\013\004\000\000\
\000\000\000\000\000\000\000\000\004\004\192\001\000\000\000\000\
\013\004\000\000\132\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\015\004\078\000\000\000\000\000\000\000\000\000\
\016\004\000\000\000\000\132\255\000\000\119\255\000\000\000\000\
\000\000\000\000\000\000\017\004\000\000\000\000\192\001\018\004\
\000\000\000\000\000\000\000\000\199\000\000\000\018\004\000\000\
\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\093\005\034\000\000\000\136\255\146\003\194\000\000\000\
\240\255\044\000\216\254\231\254\157\000\154\254\000\000\188\002\
\053\000\000\000\000\000\000\000\185\253\184\002\048\001\247\255\
\194\255\000\000\126\255\039\004\120\255\216\255\170\000\095\005\
\066\255\248\255\071\254\041\003\225\253\110\255\171\003\211\255\
\213\255\000\000\135\003\229\004\000\000\000\000\174\255\108\255\
\243\255\000\000\152\002\005\000\065\254\239\255\027\000\212\254\
\000\000\000\000\000\000\073\254\177\000\065\002\152\001\180\001\
\193\001\205\001\220\003\225\003\222\003\224\003\226\003\000\000\
\020\003\119\003\183\255\000\000\000\000\043\003\000\000\000\000\
\197\255\228\253\212\253\123\254\190\000\000\000\000\000\077\254\
\163\000\122\002\000\000\000\000\084\003\000\000\033\000\159\255\
\000\000\251\002\000\000\087\000\000\000\243\254\240\254\079\254\
\166\003\000\000\239\002\226\004\000\000\018\000\000\000\167\255\
\138\004\228\003\000\000\000\000\000\000\000\000\219\255\104\002\
\142\002\093\002\149\002\120\004\122\004\125\004\126\004\124\004\
\000\000\249\254\000\000\000\000\088\255\000\000\126\002\000\000\
\000\000\121\002\000\000\000\000\124\002\105\002"

let yytablesize = 8217
let yytable = "\068\000\
\068\000\129\000\068\000\139\000\050\001\053\000\053\000\166\000\
\186\000\081\000\058\001\003\000\178\000\153\000\200\001\139\000\
\109\001\044\002\089\001\191\001\073\002\001\001\227\001\228\001\
\107\000\207\001\149\002\055\001\206\001\064\002\067\001\068\001\
\068\002\141\000\125\002\168\002\036\001\053\000\142\000\126\002\
\185\000\155\000\147\000\069\000\073\000\141\000\076\000\161\001\
\251\000\162\001\053\000\154\000\068\000\078\000\115\001\252\000\
\068\000\061\000\109\000\068\000\242\000\243\000\244\000\245\000\
\246\000\247\000\084\000\085\000\058\001\189\000\134\000\107\000\
\078\000\116\001\046\002\155\000\057\001\072\002\082\000\133\000\
\143\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\129\000\129\000\253\000\217\002\135\000\082\000\000\001\086\000\
\169\000\031\001\168\002\134\000\177\000\047\002\063\000\181\000\
\074\000\063\000\077\000\064\000\070\001\156\000\064\000\078\001\
\079\001\080\001\218\002\056\001\083\001\084\001\126\001\071\001\
\025\001\248\000\032\001\068\000\058\002\033\001\034\001\078\000\
\073\001\032\000\213\000\177\001\142\000\142\000\118\001\053\000\
\026\001\226\002\082\000\127\002\082\000\186\000\117\001\049\001\
\177\001\059\001\079\000\080\000\069\002\224\002\082\000\082\000\
\082\000\082\000\082\000\082\000\082\000\170\000\244\001\157\002\
\245\001\213\001\155\000\082\000\030\001\079\000\080\000\001\001\
\161\002\246\001\107\000\134\000\193\001\065\000\143\000\143\000\
\201\001\252\001\253\001\087\000\174\002\172\002\041\002\132\000\
\086\002\222\001\103\001\053\000\229\001\061\002\072\002\072\002\
\206\001\152\000\034\000\036\001\197\001\066\000\110\001\036\001\
\036\001\207\001\081\002\119\001\206\001\038\000\170\001\039\000\
\067\000\231\002\088\000\130\000\170\001\232\002\134\000\201\002\
\087\001\202\002\210\002\204\002\079\000\080\000\001\000\002\000\
\177\001\177\001\172\001\173\001\174\001\110\001\056\002\110\001\
\146\000\107\000\071\001\063\000\072\001\177\001\177\001\082\000\
\064\000\168\001\162\000\068\000\068\000\036\002\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\231\001\107\000\072\002\049\003\072\002\156\001\072\002\
\239\000\241\000\237\001\078\000\063\000\192\001\240\001\241\002\
\171\001\064\000\151\000\160\000\114\002\209\001\157\001\169\001\
\170\001\196\002\191\002\160\000\197\002\194\002\061\001\165\000\
\153\000\068\000\130\000\130\000\072\002\241\002\082\000\063\000\
\047\000\047\000\168\000\059\000\064\000\061\001\082\000\057\002\
\061\001\187\000\068\000\082\000\082\000\082\000\082\000\082\000\
\082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
\082\000\082\000\082\000\082\000\082\000\082\000\001\001\082\000\
\047\000\237\000\059\002\199\001\110\001\173\002\110\001\044\003\
\003\000\047\000\167\000\176\000\198\002\047\000\175\000\110\001\
\077\002\167\002\080\002\197\001\066\000\149\000\242\002\068\000\
\068\000\036\001\223\001\108\001\036\001\159\000\249\000\067\000\
\079\000\080\000\230\001\008\001\094\001\096\001\072\000\036\001\
\036\001\036\001\008\001\179\000\063\000\105\001\106\001\250\000\
\184\000\064\000\170\002\063\000\251\002\101\002\217\000\171\002\
\064\000\166\001\108\001\143\001\108\001\107\000\066\000\166\001\
\063\000\021\001\063\000\255\001\000\002\064\000\067\002\064\000\
\171\001\067\000\251\001\013\003\036\001\055\002\171\001\022\001\
\005\001\006\001\031\001\162\002\163\002\143\001\143\001\061\001\
\143\001\143\001\074\002\089\002\061\001\107\000\143\001\024\001\
\047\000\047\000\047\000\143\001\068\000\143\001\143\001\143\001\
\058\001\143\001\087\000\032\001\007\001\073\001\033\001\034\001\
\032\001\117\002\032\000\180\000\121\002\032\001\032\000\038\001\
\186\002\197\001\075\000\003\003\038\001\159\000\031\001\079\001\
\058\001\023\001\082\000\087\000\079\001\041\001\087\000\087\000\
\036\001\143\001\087\000\036\001\015\003\061\001\160\002\063\000\
\052\002\027\001\066\000\039\001\064\000\086\001\047\000\032\001\
\038\001\079\002\033\001\034\001\061\001\067\000\032\000\061\001\
\033\003\199\001\082\000\041\001\038\001\036\001\061\001\038\001\
\040\001\108\001\048\001\108\001\041\001\047\001\217\000\061\001\
\087\000\051\001\087\000\034\000\108\001\087\000\087\000\034\000\
\087\000\087\000\087\000\063\001\038\001\053\001\038\000\038\001\
\039\000\182\001\038\000\087\002\039\000\202\001\079\001\182\001\
\203\001\001\002\003\002\087\000\068\000\217\000\145\002\217\000\
\196\002\055\002\038\001\197\002\217\001\038\001\087\000\254\000\
\087\000\151\001\091\000\092\000\255\000\122\002\063\001\034\000\
\209\001\204\001\052\001\063\001\063\001\148\002\063\001\063\001\
\223\002\035\002\038\000\054\001\039\000\061\001\094\000\059\001\
\052\001\095\000\061\001\134\000\038\001\204\000\204\000\060\001\
\107\002\038\001\062\001\147\002\151\001\063\001\068\000\036\001\
\063\001\151\001\068\000\151\001\151\001\151\001\063\001\119\001\
\107\000\063\001\108\002\068\000\063\001\064\001\063\001\063\001\
\069\001\199\001\139\000\013\001\014\001\214\001\077\001\139\000\
\139\000\197\001\139\000\159\000\070\001\074\002\082\001\180\002\
\081\001\070\001\082\000\061\001\085\001\187\002\063\001\151\001\
\091\001\079\000\052\002\063\001\063\001\105\000\164\002\197\001\
\149\001\061\001\061\001\092\001\195\002\061\001\111\001\052\002\
\061\001\038\001\061\001\199\001\217\000\061\001\217\000\008\001\
\009\001\010\001\079\000\095\002\112\001\079\000\079\000\217\000\
\199\001\079\000\199\001\011\001\012\001\082\000\149\001\217\000\
\217\000\180\002\070\001\149\001\180\002\113\001\254\002\114\001\
\149\001\120\001\149\001\149\001\149\001\180\002\149\001\180\002\
\180\002\070\001\152\001\254\002\254\002\192\002\079\000\079\000\
\153\001\079\000\079\000\154\001\180\002\155\001\061\001\079\000\
\149\000\079\000\019\001\020\001\079\000\079\000\158\001\079\000\
\079\000\079\000\079\000\004\003\160\001\061\001\149\001\142\001\
\143\001\189\000\189\000\189\000\153\001\180\002\221\002\118\002\
\164\001\153\001\079\000\159\001\153\001\153\001\166\001\180\002\
\180\002\144\001\145\001\252\002\210\001\079\000\163\001\079\000\
\180\002\150\001\151\001\149\000\003\001\003\001\118\002\139\001\
\140\001\141\001\008\003\212\001\180\002\254\000\235\002\236\002\
\091\000\092\000\255\000\078\000\204\000\204\000\159\000\153\001\
\205\002\206\002\207\002\214\001\155\000\031\003\097\001\098\001\
\099\001\100\001\101\001\102\001\094\000\061\001\061\001\095\000\
\216\001\175\002\232\001\249\002\225\001\180\002\226\001\045\003\
\028\001\029\001\209\001\234\001\004\000\189\000\189\000\189\000\
\006\000\045\003\057\000\233\001\189\002\019\002\020\002\009\000\
\235\001\083\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\236\001\083\000\021\002\022\002\083\000\083\000\238\001\
\031\001\083\000\082\000\105\000\222\002\015\001\016\001\017\001\
\018\001\042\003\023\002\024\002\025\002\026\002\227\002\239\001\
\079\000\080\000\108\001\241\001\082\000\146\001\147\001\148\001\
\149\001\032\001\027\002\028\002\033\001\034\001\082\000\242\001\
\032\000\083\000\083\000\179\001\180\001\181\001\182\001\083\000\
\243\001\083\000\175\001\176\001\083\000\083\000\184\000\083\000\
\083\000\083\000\083\000\247\001\230\002\248\001\233\002\234\002\
\159\000\034\000\035\000\249\001\037\000\237\002\238\002\239\002\
\045\001\046\001\083\000\243\002\038\000\250\001\039\000\037\002\
\035\002\217\000\217\000\128\000\254\001\083\000\038\002\083\000\
\062\002\038\001\177\001\178\001\147\001\040\002\038\001\009\003\
\010\003\035\002\043\002\214\001\248\002\121\001\122\001\183\001\
\184\001\034\000\065\002\204\001\066\002\076\002\000\003\001\003\
\086\001\082\002\084\002\085\002\038\000\035\002\039\000\007\003\
\090\002\147\001\147\001\123\001\124\001\091\002\125\001\147\001\
\092\002\126\001\093\002\016\003\147\001\094\002\147\001\147\001\
\147\001\214\001\147\001\015\002\016\002\017\002\018\002\018\002\
\018\002\018\002\018\002\018\002\018\002\018\002\018\002\018\002\
\018\002\018\002\018\002\018\002\018\002\026\001\038\001\098\002\
\099\002\038\001\100\002\102\002\043\003\168\000\026\001\168\000\
\168\000\168\000\147\001\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\103\002\128\001\129\001\130\001\
\131\001\132\001\133\001\134\001\135\001\136\001\137\001\138\001\
\104\002\096\002\105\002\110\002\113\002\109\002\112\002\168\000\
\168\000\168\000\115\002\184\000\168\000\168\000\116\002\123\002\
\168\000\168\000\120\002\128\002\153\002\168\000\168\000\159\002\
\168\000\168\000\168\000\154\002\056\002\156\002\176\002\168\000\
\177\002\097\002\178\002\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\184\002\
\185\002\190\002\168\000\168\000\168\000\168\000\168\000\168\000\
\193\002\168\000\203\002\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\154\000\168\000\168\000\154\000\154\000\061\001\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\200\002\061\001\211\002\212\002\061\001\213\002\214\002\
\061\001\215\002\061\001\061\001\216\002\225\002\228\002\240\002\
\229\002\244\002\245\002\247\002\154\000\154\000\154\000\246\002\
\250\002\154\000\154\000\253\002\006\003\154\000\154\000\011\003\
\002\003\018\003\154\000\154\000\014\003\154\000\154\000\154\000\
\018\002\023\003\024\003\025\003\154\000\026\003\027\003\030\003\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\028\003\032\003\035\003\154\000\
\154\000\154\000\154\000\154\000\154\000\034\003\154\000\038\003\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\039\003\154\000\154\000\154\000\040\003\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\004\002\005\002\
\006\002\007\002\008\002\009\002\010\002\011\002\012\002\013\002\
\014\002\048\003\031\001\050\003\044\003\003\000\252\000\199\000\
\030\001\154\000\154\000\154\000\056\001\021\001\154\000\154\000\
\038\001\023\000\154\000\154\000\003\000\038\001\157\001\154\000\
\154\000\049\001\154\000\032\001\154\000\024\000\033\001\034\001\
\001\001\154\000\032\000\135\000\137\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\201\000\122\000\120\000\154\000\154\000\154\000\154\000\
\154\000\154\000\032\001\154\000\055\001\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\141\000\070\001\154\000\070\001\
\070\001\035\001\144\001\070\001\070\001\070\001\070\001\070\001\
\070\001\070\001\070\001\163\001\038\001\038\001\137\000\168\001\
\038\001\175\001\137\000\179\001\184\001\038\001\056\000\063\002\
\219\002\220\002\060\000\034\000\144\001\144\001\224\001\144\001\
\144\001\124\002\070\001\070\001\042\002\144\001\038\000\088\002\
\039\000\042\001\144\001\029\002\144\001\144\001\144\001\031\002\
\144\001\030\002\032\002\166\002\158\002\033\002\106\002\070\001\
\070\001\070\001\017\003\083\002\070\001\070\001\066\001\208\002\
\070\001\070\001\167\001\039\002\185\001\070\001\070\001\186\001\
\070\001\153\000\070\001\187\001\189\001\188\001\037\003\070\001\
\144\001\036\003\052\003\070\001\070\001\070\001\070\001\070\001\
\070\001\070\001\070\001\070\001\070\001\070\001\070\001\000\000\
\039\001\000\000\051\003\000\000\070\001\039\001\070\001\070\001\
\000\000\070\001\000\000\070\001\070\001\000\000\070\001\000\000\
\000\000\000\000\000\000\070\001\153\000\158\000\000\000\158\000\
\158\000\158\000\000\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\043\001\039\001\000\000\000\000\
\039\001\000\000\000\000\000\000\000\000\043\001\000\000\158\000\
\158\000\158\000\000\000\000\000\158\000\158\000\000\000\000\000\
\158\000\158\000\000\000\000\000\000\000\158\000\158\000\000\000\
\158\000\158\000\158\000\000\000\000\000\000\000\000\000\158\000\
\000\000\000\000\000\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\000\000\
\000\000\000\000\158\000\158\000\158\000\158\000\158\000\158\000\
\000\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\147\000\158\000\147\000\147\000\147\000\000\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\147\000\147\000\147\000\000\000\
\000\000\147\000\147\000\000\000\000\000\147\000\147\000\000\000\
\000\000\000\000\147\000\147\000\000\000\147\000\147\000\147\000\
\000\000\000\000\000\000\000\000\147\000\000\000\000\000\000\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\000\000\000\000\000\000\147\000\
\147\000\147\000\147\000\147\000\147\000\000\000\147\000\000\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\179\002\
\147\000\068\002\130\002\006\000\000\000\045\002\191\000\192\000\
\193\000\194\000\131\002\078\000\195\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\196\000\197\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\203\000\204\000\000\000\000\000\000\000\205\000\
\206\000\000\000\207\000\000\000\146\000\000\000\000\000\000\000\
\000\000\132\002\000\000\000\000\000\000\133\002\134\002\135\002\
\136\002\137\002\138\002\139\002\000\000\000\000\000\000\140\002\
\141\002\000\000\000\000\000\000\034\000\035\000\142\002\037\000\
\079\000\080\000\000\000\208\000\000\000\209\000\210\000\038\000\
\143\002\039\000\000\000\000\000\070\001\069\002\070\001\070\001\
\000\000\133\001\070\001\070\001\070\001\070\001\070\001\070\001\
\070\001\070\001\000\000\000\000\000\000\000\000\133\001\133\001\
\133\001\133\001\133\001\133\001\000\000\000\000\000\000\000\000\
\000\000\000\000\133\001\133\001\133\001\000\000\133\001\133\001\
\000\000\070\001\070\001\000\000\133\001\000\000\000\000\000\000\
\000\000\133\001\000\000\133\001\133\001\133\001\000\000\133\001\
\000\000\000\000\000\000\000\000\000\000\000\000\070\001\070\001\
\070\001\000\000\000\000\070\001\070\001\000\000\000\000\070\001\
\070\001\000\000\000\000\000\000\070\001\070\001\000\000\070\001\
\000\000\070\001\000\000\000\000\000\000\000\000\070\001\133\001\
\000\000\000\000\070\001\070\001\070\001\070\001\070\001\070\001\
\070\001\070\001\070\001\070\001\070\001\070\001\000\000\000\000\
\000\000\000\000\000\000\070\001\000\000\070\001\070\001\000\000\
\070\001\000\000\070\001\070\001\000\000\070\001\179\002\111\001\
\068\002\130\002\070\001\000\000\045\002\191\000\192\000\193\000\
\194\000\064\000\078\000\195\000\111\001\111\001\111\001\111\001\
\111\001\111\001\111\001\111\001\111\001\111\001\111\001\000\000\
\111\001\111\001\111\001\000\000\111\001\111\001\111\001\111\001\
\000\000\000\000\111\001\196\000\197\000\000\000\000\000\111\001\
\000\000\111\001\111\001\111\001\000\000\111\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\198\000\199\000\200\000\000\000\000\000\201\000\202\000\000\000\
\000\000\203\000\204\000\000\000\000\000\000\000\205\000\206\000\
\000\000\207\000\000\000\146\000\000\000\111\001\000\000\000\000\
\132\002\000\000\000\000\000\000\133\002\134\002\135\002\136\002\
\137\002\138\002\139\002\000\000\000\000\000\000\140\002\141\002\
\000\000\000\000\000\000\000\000\000\000\142\002\000\000\079\000\
\080\000\000\000\208\000\000\000\209\000\210\000\000\000\143\002\
\000\000\004\000\005\000\000\000\069\002\006\000\007\000\008\000\
\150\001\000\000\000\000\000\000\009\000\000\000\000\000\010\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\025\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\150\001\000\000\
\000\000\000\000\000\000\150\001\000\000\000\000\000\000\000\000\
\150\001\101\001\150\001\150\001\150\001\000\000\150\001\000\000\
\000\000\000\000\000\000\000\000\101\001\101\001\101\001\101\001\
\101\001\101\001\101\001\101\001\101\001\101\001\101\001\101\001\
\101\001\000\000\101\001\101\001\101\001\000\000\101\001\101\001\
\101\001\101\001\000\000\033\000\101\001\000\000\150\001\000\000\
\101\001\101\001\000\000\101\001\101\001\101\001\000\000\101\001\
\000\000\000\000\000\000\000\000\000\000\000\000\034\000\035\000\
\036\000\037\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\038\000\108\000\039\000\040\000\041\000\108\000\042\000\
\108\000\000\000\000\000\108\000\108\000\108\000\000\000\101\001\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\000\000\
\000\000\108\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\000\000\108\000\108\000\108\000\000\000\108\000\108\000\
\108\000\108\000\000\000\000\000\108\000\108\000\000\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\000\000\108\000\
\000\000\000\000\000\000\000\000\000\000\000\000\108\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\108\000\
\108\000\000\000\108\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\108\000\000\000\108\000\154\000\000\000\108\000\
\154\000\154\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\154\000\
\154\000\154\000\000\000\000\000\154\000\154\000\000\000\000\000\
\154\000\154\000\000\000\000\000\000\000\154\000\154\000\000\000\
\154\000\154\000\154\000\000\000\000\000\000\000\000\000\154\000\
\000\000\000\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\000\000\
\000\000\000\000\154\000\154\000\154\000\154\000\154\000\154\000\
\000\000\154\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\129\002\000\000\218\000\130\002\006\000\000\000\
\045\002\191\000\192\000\193\000\194\000\131\002\078\000\195\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\058\000\027\000\028\000\029\000\030\000\031\000\032\000\196\000\
\197\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\218\000\000\000\198\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\203\000\204\000\000\000\
\218\000\218\000\205\000\206\000\218\000\207\000\218\000\146\000\
\218\000\218\000\000\000\000\000\132\002\000\000\000\000\000\000\
\133\002\134\002\135\002\136\002\137\002\138\002\139\002\000\000\
\000\000\000\000\140\002\141\002\000\000\000\000\000\000\034\000\
\035\000\142\002\037\000\079\000\080\000\000\000\208\000\000\000\
\209\000\210\000\038\000\143\002\039\000\040\000\041\000\182\000\
\000\000\000\000\000\000\006\000\000\000\190\000\191\000\192\000\
\193\000\194\000\009\000\078\000\195\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\196\000\197\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\006\000\203\000\204\000\000\000\000\000\000\000\205\000\
\206\000\000\000\207\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\000\000\034\000\035\000\000\000\037\000\
\079\000\080\000\000\000\208\000\182\000\209\000\210\000\038\000\
\006\000\039\000\000\000\000\000\000\000\000\000\000\000\009\000\
\000\000\000\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\038\000\000\000\039\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\183\000\000\000\000\000\000\000\108\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\220\000\034\000\035\000\000\000\037\000\220\000\108\000\000\000\
\000\000\108\000\108\000\000\000\038\000\108\000\039\000\000\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\000\000\108\000\108\000\108\000\000\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\220\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\000\000\
\000\000\000\000\000\000\107\000\220\000\220\000\000\000\000\000\
\220\000\000\000\220\000\000\000\220\000\220\000\108\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\108\000\000\000\108\000\107\000\000\000\108\000\107\000\
\107\000\000\000\000\000\107\000\000\000\000\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\000\000\107\000\
\107\000\107\000\000\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\000\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\000\000\000\000\000\000\
\000\000\043\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\107\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\107\000\
\000\000\107\000\043\000\000\000\107\000\043\000\043\000\000\000\
\000\000\043\000\000\000\000\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\000\000\
\000\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\000\000\043\000\043\000\043\000\
\000\000\043\000\043\000\043\000\043\000\000\000\000\000\043\000\
\000\000\043\000\000\000\000\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\000\000\000\000\000\000\000\000\047\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\043\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\043\000\000\000\043\000\
\047\000\000\000\043\000\047\000\047\000\000\000\000\000\047\000\
\000\000\000\000\047\000\047\000\047\000\047\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\000\000\000\000\047\000\
\047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
\047\000\047\000\000\000\047\000\047\000\047\000\000\000\047\000\
\047\000\047\000\047\000\000\000\000\000\047\000\000\000\047\000\
\000\000\000\000\047\000\047\000\047\000\047\000\047\000\047\000\
\047\000\000\000\000\000\000\000\000\000\049\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\047\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\047\000\000\000\047\000\049\000\000\000\
\047\000\049\000\049\000\000\000\000\000\049\000\000\000\000\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
\049\000\049\000\049\000\000\000\000\000\049\000\049\000\049\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
\000\000\049\000\049\000\049\000\000\000\049\000\049\000\049\000\
\049\000\000\000\000\000\049\000\000\000\049\000\000\000\000\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\179\002\
\000\000\000\000\130\002\000\000\148\001\045\002\191\000\192\000\
\193\000\194\000\064\000\078\000\195\000\000\000\049\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\049\000\000\000\049\000\000\000\000\000\049\000\000\000\
\000\000\148\001\148\001\000\000\196\000\197\000\000\000\148\001\
\000\000\000\000\000\000\000\000\148\001\000\000\148\001\148\001\
\148\001\000\000\148\001\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\203\000\204\000\000\000\000\000\000\000\205\000\
\206\000\000\000\207\000\000\000\146\000\000\000\000\000\000\000\
\000\000\132\002\148\001\000\000\000\000\133\002\134\002\135\002\
\136\002\137\002\138\002\139\002\000\000\000\000\000\000\140\002\
\141\002\000\000\000\000\000\000\000\000\000\000\142\002\000\000\
\079\000\080\000\006\000\208\000\000\000\209\000\210\000\000\000\
\143\002\009\000\141\001\000\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\025\000\058\000\027\000\028\000\029\000\
\030\000\031\000\032\000\141\001\141\001\141\001\000\000\141\001\
\141\001\000\000\000\000\000\000\000\000\141\001\000\000\000\000\
\000\000\000\000\141\001\000\000\141\001\141\001\141\001\000\000\
\141\001\000\000\000\000\000\000\000\000\000\000\000\000\145\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\085\001\
\000\000\000\000\085\001\085\001\085\001\085\001\000\000\000\000\
\171\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\141\001\145\001\000\000\000\000\145\001\145\001\085\001\000\000\
\000\000\085\001\145\001\034\000\035\000\000\000\037\000\145\001\
\085\001\145\001\145\001\145\001\000\000\145\001\038\000\000\000\
\039\000\040\000\041\000\085\001\085\001\085\001\085\001\085\001\
\085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
\000\000\085\001\085\001\085\001\000\000\085\001\085\001\085\001\
\085\001\000\000\000\000\085\001\020\000\145\001\000\000\085\001\
\085\001\000\000\085\001\085\001\085\001\000\000\085\001\031\001\
\000\000\000\000\000\000\086\001\000\000\085\001\086\001\086\001\
\086\001\086\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\085\001\085\001\000\000\000\000\000\000\000\000\
\032\001\000\000\086\001\033\001\034\001\086\001\085\001\032\000\
\000\000\000\000\000\000\000\000\086\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\086\001\
\086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
\086\001\086\001\086\001\086\001\000\000\086\001\086\001\086\001\
\000\000\086\001\086\001\086\001\086\001\000\000\078\002\086\001\
\021\000\203\001\000\000\086\001\086\001\000\000\086\001\086\001\
\086\001\000\000\086\001\000\000\000\000\000\000\000\000\091\001\
\000\000\086\001\091\001\091\001\091\001\091\001\000\000\000\000\
\034\000\000\000\204\001\000\000\000\000\000\000\086\001\086\001\
\000\000\000\000\000\000\038\000\000\000\039\000\091\001\000\000\
\000\000\091\001\086\001\000\000\000\000\000\000\000\000\000\000\
\091\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\091\001\091\001\091\001\091\001\091\001\
\091\001\091\001\091\001\091\001\091\001\091\001\091\001\091\001\
\000\000\091\001\091\001\091\001\000\000\091\001\091\001\091\001\
\091\001\000\000\000\000\091\001\000\000\000\000\000\000\091\001\
\091\001\000\000\091\001\091\001\091\001\090\000\091\001\000\000\
\091\000\092\000\093\000\078\000\000\000\091\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\142\001\091\001\091\001\094\000\000\000\000\000\095\000\
\000\000\000\000\000\000\000\000\096\000\097\000\091\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\142\001\142\001\142\001\000\000\142\001\142\001\
\000\000\098\000\099\000\100\000\142\001\000\000\101\000\102\000\
\000\000\142\001\103\000\142\001\142\001\142\001\000\000\142\001\
\000\000\000\000\104\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\105\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\142\001\
\079\000\080\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\006\000\106\000\190\000\191\000\192\000\
\193\000\194\000\009\000\078\000\195\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\196\000\197\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\203\000\204\000\000\000\000\000\000\000\205\000\
\206\000\000\000\207\000\000\000\146\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\034\000\035\000\000\000\037\000\
\079\000\080\000\000\000\208\000\000\000\209\000\210\000\038\000\
\006\000\039\000\190\000\191\000\192\000\193\000\194\000\009\000\
\078\000\195\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\196\000\197\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\198\000\199\000\
\200\000\000\000\000\000\201\000\202\000\000\000\000\000\203\000\
\204\000\000\000\000\000\000\000\205\000\206\000\000\000\207\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\079\000\080\000\000\000\
\208\000\000\000\209\000\210\000\038\000\244\000\039\000\244\000\
\000\000\000\000\000\000\000\000\244\000\146\001\000\000\244\000\
\244\000\244\000\244\000\244\000\244\000\244\000\244\000\244\000\
\244\000\244\000\244\000\244\000\244\000\244\000\244\000\244\000\
\244\000\244\000\244\000\244\000\244\000\244\000\000\000\146\001\
\000\000\000\000\146\001\146\001\000\000\000\000\000\000\000\000\
\146\001\000\000\000\000\000\000\000\000\146\001\000\000\146\001\
\146\001\146\001\000\000\146\001\000\000\244\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\244\000\244\000\000\000\000\000\244\000\
\000\000\244\000\000\000\244\000\244\000\000\000\000\000\000\000\
\000\000\000\000\000\000\146\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\244\000\244\000\
\000\000\244\000\000\000\233\000\000\000\233\000\000\000\000\000\
\000\000\244\000\233\000\244\000\000\000\233\000\233\000\233\000\
\233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
\233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
\233\000\233\000\233\000\233\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\233\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\233\000\233\000\000\000\000\000\233\000\000\000\233\000\
\000\000\233\000\233\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\233\000\233\000\000\000\233\000\
\000\000\239\000\000\000\239\000\000\000\000\000\000\000\233\000\
\239\000\233\000\000\000\239\000\239\000\239\000\239\000\239\000\
\239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
\239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
\239\000\239\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\239\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\239\000\
\239\000\000\000\000\000\239\000\000\000\239\000\000\000\239\000\
\239\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\239\000\239\000\000\000\239\000\000\000\234\000\
\000\000\234\000\000\000\000\000\000\000\239\000\234\000\239\000\
\000\000\234\000\234\000\234\000\234\000\234\000\234\000\234\000\
\234\000\234\000\234\000\234\000\234\000\234\000\234\000\234\000\
\234\000\234\000\234\000\234\000\234\000\234\000\234\000\234\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\234\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\234\000\234\000\000\000\
\000\000\234\000\000\000\234\000\000\000\234\000\234\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\234\000\234\000\000\000\234\000\000\000\249\000\000\000\249\000\
\000\000\000\000\000\000\234\000\249\000\234\000\000\000\249\000\
\249\000\249\000\249\000\249\000\249\000\249\000\249\000\249\000\
\249\000\249\000\249\000\249\000\249\000\249\000\249\000\249\000\
\249\000\249\000\249\000\249\000\249\000\249\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\249\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\249\000\000\000\000\000\000\000\
\000\000\021\000\000\000\249\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\249\000\249\000\
\000\000\249\000\000\000\207\000\000\000\207\000\000\000\000\000\
\000\000\249\000\207\000\249\000\000\000\207\000\207\000\207\000\
\207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
\207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
\207\000\207\000\207\000\207\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\207\000\000\000\000\000\000\000\000\000\
\000\000\000\000\059\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\207\000\000\000\000\000\000\000\000\000\000\000\
\000\000\207\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\000\000\000\000\000\059\000\059\000\
\000\000\000\000\059\000\000\000\207\000\207\000\000\000\207\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\207\000\
\000\000\207\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\059\000\059\000\059\000\059\000\000\000\059\000\059\000\
\059\000\000\000\059\000\059\000\059\000\059\000\000\000\000\000\
\059\000\000\000\059\000\000\000\000\000\059\000\059\000\000\000\
\059\000\059\000\059\000\059\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\000\000\000\000\000\000\000\000\000\
\006\000\000\000\000\000\000\000\000\000\000\000\059\000\009\000\
\059\000\081\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\006\000\081\000\057\000\000\000\081\000\081\000\000\000\
\009\000\081\000\000\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\000\000\000\000\000\000\081\000\158\000\
\000\000\081\000\081\000\000\000\000\000\000\000\000\000\081\000\
\221\001\081\000\000\000\000\000\081\000\081\000\000\000\081\000\
\081\000\081\000\081\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\000\000\000\000\000\000\
\000\000\000\000\081\000\000\000\038\000\000\000\039\000\000\000\
\000\000\000\000\000\000\000\000\000\000\081\000\000\000\081\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\006\000\
\000\000\000\000\000\000\000\000\000\000\038\000\009\000\039\000\
\082\000\010\000\011\000\012\000\013\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\021\000\022\000\023\000\024\000\
\025\000\058\000\027\000\028\000\029\000\030\000\031\000\032\000\
\006\000\082\000\000\000\000\000\082\000\082\000\000\000\009\000\
\082\000\000\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\000\000\000\000\000\000\000\000\082\000\158\000\000\000\
\082\000\082\000\000\000\000\000\000\000\000\000\082\000\000\000\
\082\000\000\000\000\000\082\000\082\000\000\000\082\000\082\000\
\082\000\082\000\000\000\000\000\000\000\000\000\000\000\000\000\
\034\000\035\000\000\000\037\000\000\000\000\000\000\000\000\000\
\000\000\082\000\000\000\038\000\000\000\039\000\000\000\000\000\
\209\002\000\000\000\000\000\000\082\000\000\000\082\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\000\000\019\001\000\000\
\000\000\000\000\000\000\000\000\038\000\019\001\039\000\000\000\
\019\001\019\001\019\001\019\001\019\001\019\001\019\001\019\001\
\019\001\019\001\019\001\019\001\019\001\019\001\019\001\019\001\
\019\001\019\001\019\001\019\001\019\001\019\001\019\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\130\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\130\001\130\001\
\130\001\130\001\130\001\130\001\000\000\063\000\000\000\000\000\
\000\000\000\000\130\001\130\001\130\001\019\001\130\001\130\001\
\130\001\130\001\000\000\000\000\130\001\000\000\000\000\000\000\
\000\000\130\001\000\000\130\001\130\001\130\001\063\000\130\001\
\000\000\063\000\063\000\000\000\000\000\063\000\000\000\019\001\
\019\001\000\000\019\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\019\001\000\000\019\001\063\000\063\000\063\000\
\063\000\063\000\063\000\063\000\063\000\000\000\000\000\130\001\
\000\000\063\000\063\000\063\000\064\000\063\000\063\000\063\000\
\063\000\000\000\000\000\063\000\000\000\063\000\000\000\000\000\
\063\000\063\000\000\000\063\000\063\000\063\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\064\000\000\000\000\000\
\064\000\064\000\000\000\000\000\064\000\000\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\063\000\000\000\063\000\064\000\064\000\064\000\064\000\
\064\000\064\000\064\000\064\000\000\000\000\000\000\000\000\000\
\064\000\064\000\064\000\065\000\064\000\064\000\064\000\064\000\
\000\000\000\000\064\000\000\000\064\000\000\000\000\000\064\000\
\064\000\000\000\064\000\064\000\064\000\064\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\000\000\000\000\065\000\
\065\000\000\000\000\000\065\000\000\000\064\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\064\000\000\000\064\000\065\000\065\000\065\000\065\000\065\000\
\065\000\065\000\065\000\000\000\000\000\000\000\000\000\065\000\
\065\000\065\000\000\000\065\000\065\000\065\000\065\000\000\000\
\000\000\065\000\000\000\065\000\000\000\000\000\065\000\065\000\
\000\000\065\000\065\000\065\000\065\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\000\000\000\000\000\000\
\000\000\006\000\000\000\000\000\000\000\000\000\000\000\065\000\
\009\000\065\000\066\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\066\000\000\000\000\000\066\000\066\000\
\000\000\000\000\066\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\066\000\066\000\066\000\066\000\066\000\066\000\
\000\000\000\000\000\000\000\000\000\000\000\000\066\000\066\000\
\066\000\000\000\066\000\066\000\066\000\066\000\000\000\000\000\
\066\000\000\000\066\000\000\000\000\000\066\000\066\000\067\000\
\066\000\066\000\066\000\066\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\000\000\
\000\000\000\000\000\000\066\000\000\000\038\000\000\000\039\000\
\067\000\000\000\000\000\067\000\067\000\000\000\066\000\067\000\
\066\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\067\000\
\067\000\067\000\067\000\067\000\067\000\000\000\000\000\000\000\
\000\000\000\000\000\000\067\000\067\000\067\000\068\000\067\000\
\067\000\067\000\067\000\000\000\000\000\067\000\000\000\067\000\
\000\000\000\000\067\000\067\000\000\000\067\000\067\000\067\000\
\067\000\000\000\000\000\000\000\000\000\000\000\000\000\068\000\
\000\000\000\000\068\000\068\000\000\000\000\000\068\000\000\000\
\067\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\067\000\000\000\067\000\068\000\068\000\
\068\000\068\000\068\000\068\000\000\000\000\000\000\000\000\000\
\000\000\000\000\068\000\068\000\068\000\069\000\068\000\068\000\
\068\000\068\000\000\000\000\000\068\000\000\000\068\000\000\000\
\000\000\068\000\068\000\000\000\068\000\068\000\068\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
\000\000\069\000\069\000\000\000\000\000\069\000\000\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\068\000\000\000\068\000\069\000\069\000\069\000\
\069\000\069\000\069\000\000\000\000\000\000\000\000\000\000\000\
\000\000\069\000\069\000\069\000\070\000\069\000\069\000\000\000\
\000\000\000\000\000\000\069\000\000\000\069\000\000\000\000\000\
\069\000\069\000\000\000\069\000\069\000\069\000\069\000\000\000\
\000\000\000\000\000\000\000\000\000\000\070\000\000\000\000\000\
\070\000\070\000\000\000\000\000\070\000\000\000\069\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\069\000\000\000\069\000\070\000\070\000\070\000\070\000\
\070\000\070\000\000\000\000\000\000\000\000\000\000\000\000\000\
\070\000\070\000\070\000\071\000\070\000\070\000\000\000\000\000\
\000\000\000\000\070\000\000\000\070\000\000\000\000\000\070\000\
\070\000\000\000\070\000\070\000\070\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\071\000\000\000\000\000\071\000\
\071\000\000\000\000\000\071\000\000\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\070\000\000\000\070\000\071\000\071\000\071\000\071\000\071\000\
\071\000\000\000\000\000\000\000\000\000\000\000\000\000\071\000\
\071\000\071\000\072\000\071\000\071\000\000\000\000\000\000\000\
\000\000\071\000\000\000\071\000\000\000\000\000\071\000\071\000\
\000\000\071\000\071\000\071\000\071\000\000\000\000\000\000\000\
\000\000\000\000\000\000\072\000\000\000\000\000\072\000\072\000\
\000\000\000\000\072\000\000\000\071\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\071\000\
\000\000\071\000\072\000\072\000\072\000\072\000\072\000\072\000\
\000\000\000\000\000\000\000\000\000\000\000\000\072\000\072\000\
\072\000\073\000\072\000\072\000\000\000\000\000\000\000\000\000\
\072\000\000\000\072\000\000\000\000\000\072\000\072\000\000\000\
\072\000\072\000\072\000\072\000\000\000\000\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\073\000\073\000\000\000\
\000\000\073\000\000\000\072\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\072\000\000\000\
\072\000\073\000\073\000\073\000\073\000\073\000\073\000\000\000\
\000\000\000\000\074\000\000\000\000\000\073\000\073\000\073\000\
\000\000\073\000\073\000\000\000\000\000\000\000\000\000\073\000\
\000\000\073\000\000\000\000\000\073\000\073\000\000\000\073\000\
\073\000\073\000\073\000\074\000\000\000\000\000\074\000\074\000\
\000\000\000\000\074\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\074\000\074\000\000\000\073\000\000\000\073\000\
\000\000\000\000\000\000\075\000\000\000\000\000\074\000\074\000\
\074\000\000\000\074\000\074\000\000\000\000\000\000\000\000\000\
\074\000\000\000\074\000\000\000\000\000\074\000\074\000\000\000\
\074\000\074\000\074\000\074\000\075\000\000\000\000\000\075\000\
\075\000\000\000\000\000\075\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\074\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\075\000\075\000\000\000\074\000\000\000\
\074\000\000\000\000\000\000\000\076\000\000\000\000\000\075\000\
\075\000\075\000\000\000\075\000\075\000\000\000\000\000\000\000\
\000\000\075\000\000\000\075\000\000\000\000\000\075\000\075\000\
\000\000\075\000\075\000\075\000\075\000\076\000\000\000\000\000\
\076\000\076\000\000\000\000\000\076\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\075\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\076\000\076\000\000\000\075\000\
\000\000\075\000\000\000\000\000\000\000\077\000\000\000\000\000\
\076\000\076\000\076\000\000\000\076\000\076\000\000\000\000\000\
\000\000\000\000\076\000\000\000\076\000\000\000\000\000\076\000\
\076\000\000\000\076\000\076\000\076\000\076\000\077\000\000\000\
\000\000\077\000\077\000\000\000\000\000\077\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\076\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\000\000\000\076\000\000\000\000\000\000\000\078\000\000\000\
\000\000\077\000\077\000\077\000\000\000\077\000\077\000\000\000\
\000\000\000\000\000\000\077\000\000\000\077\000\000\000\000\000\
\077\000\077\000\000\000\077\000\077\000\077\000\077\000\078\000\
\000\000\000\000\078\000\078\000\000\000\000\000\078\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\077\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\077\000\000\000\077\000\000\000\000\000\000\000\080\000\
\000\000\000\000\078\000\078\000\078\000\000\000\078\000\078\000\
\000\000\000\000\000\000\000\000\078\000\000\000\078\000\000\000\
\000\000\078\000\078\000\084\000\078\000\078\000\078\000\078\000\
\080\000\000\000\000\000\080\000\080\000\000\000\000\000\080\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\078\000\
\000\000\000\000\000\000\000\000\084\000\000\000\000\000\084\000\
\084\000\000\000\078\000\084\000\078\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\080\000\080\000\000\000\080\000\
\080\000\000\000\000\000\000\000\000\000\080\000\000\000\080\000\
\000\000\000\000\080\000\080\000\085\000\080\000\080\000\080\000\
\080\000\000\000\000\000\084\000\084\000\000\000\000\000\000\000\
\000\000\084\000\000\000\084\000\000\000\000\000\084\000\084\000\
\080\000\084\000\084\000\084\000\084\000\085\000\000\000\000\000\
\085\000\085\000\000\000\080\000\085\000\080\000\000\000\000\000\
\000\000\000\000\000\000\086\000\084\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\084\000\
\000\000\084\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\086\000\085\000\000\000\086\000\
\086\000\000\000\085\000\086\000\085\000\000\000\000\000\085\000\
\085\000\000\000\085\000\085\000\085\000\085\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\085\000\000\000\000\000\
\000\000\000\000\000\000\000\000\086\000\000\000\000\000\000\000\
\085\000\086\000\085\000\086\000\000\000\000\000\086\000\086\000\
\000\000\086\000\086\000\086\000\086\000\061\001\061\001\061\001\
\061\001\061\001\061\001\061\001\061\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\086\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\061\001\086\000\
\000\000\086\000\000\000\000\000\061\001\061\001\061\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\061\001\061\001\061\001\000\000\000\000\061\001\061\001\
\000\000\000\000\061\001\061\001\000\000\000\000\000\000\061\001\
\061\001\061\001\061\001\094\001\061\001\061\001\061\001\061\001\
\000\000\061\001\061\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\094\001\000\000\
\061\001\061\001\000\000\061\001\000\000\061\001\061\001\000\000\
\000\000\094\001\094\001\094\001\094\001\094\001\094\001\094\001\
\094\001\094\001\094\001\094\001\094\001\094\001\000\000\094\001\
\094\001\094\001\000\000\094\001\094\001\094\001\094\001\000\000\
\000\000\094\001\000\000\000\000\000\000\094\001\094\001\000\000\
\094\001\094\001\094\001\000\000\094\001\000\000\045\002\191\000\
\192\000\193\000\194\000\064\000\078\000\195\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\094\001\094\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\094\001\196\000\197\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\046\002\000\000\000\000\000\000\000\000\
\000\000\000\000\198\000\199\000\200\000\000\000\000\000\201\000\
\202\000\000\000\000\000\203\000\204\000\000\000\000\000\000\000\
\205\000\206\000\000\000\207\000\000\000\198\001\047\002\000\000\
\000\000\000\000\061\001\061\001\061\001\061\001\061\001\000\000\
\061\001\061\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\079\000\080\000\061\001\208\000\000\000\209\000\210\000\
\000\000\061\001\061\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\061\001\061\001\
\061\001\000\000\000\000\061\001\061\001\000\000\000\000\061\001\
\061\001\000\000\000\000\000\000\061\001\061\001\000\000\061\001\
\000\000\000\000\000\000\061\001\000\000\132\000\132\000\132\000\
\132\000\132\000\000\000\132\000\132\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\061\001\061\001\000\000\
\061\001\000\000\061\001\061\001\132\000\132\000\132\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\132\000\132\000\132\000\000\000\000\000\132\000\132\000\
\000\000\000\000\132\000\132\000\000\000\000\000\000\000\132\000\
\132\000\000\000\132\000\000\000\132\000\000\000\000\000\000\000\
\190\000\191\000\192\000\193\000\194\000\000\000\078\000\195\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\132\000\132\000\000\000\132\000\000\000\132\000\132\000\196\000\
\197\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\198\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\203\000\204\000\000\000\
\000\000\000\000\205\000\206\000\000\000\207\000\000\000\198\001\
\000\000\000\000\000\000\190\000\191\000\192\000\193\000\194\000\
\000\000\078\000\195\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\079\000\080\000\000\000\208\000\000\000\
\209\000\210\000\196\000\197\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\198\000\
\199\000\200\000\000\000\000\000\201\000\202\000\000\000\000\000\
\203\000\204\000\000\000\000\000\000\000\205\000\206\000\000\000\
\207\000\000\000\096\002\000\000\000\000\000\000\190\000\191\000\
\192\000\193\000\194\000\000\000\078\000\195\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\079\000\080\000\
\000\000\208\000\000\000\209\000\210\000\196\000\197\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\198\000\199\000\200\000\000\000\000\000\201\000\
\202\000\000\000\000\000\203\000\204\000\000\000\000\000\000\000\
\205\000\206\000\000\000\207\000\000\000\000\000\000\000\000\000\
\000\000\000\000\188\002\061\001\061\001\061\001\061\001\061\001\
\000\000\061\001\061\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\079\000\080\000\000\000\208\000\000\000\209\000\210\000\
\000\000\000\000\061\001\061\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\061\001\
\061\001\061\001\000\000\000\000\061\001\061\001\000\000\000\000\
\061\001\061\001\000\000\000\000\000\000\061\001\061\001\000\000\
\061\001\000\000\000\000\000\000\061\001\000\000\128\000\128\000\
\128\000\128\000\128\000\000\000\128\000\128\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\061\001\061\001\
\000\000\061\001\000\000\061\001\061\001\128\000\128\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\128\000\128\000\128\000\000\000\000\000\128\000\
\128\000\000\000\000\000\128\000\128\000\000\000\000\000\000\000\
\128\000\128\000\000\000\128\000\000\000\128\000\000\000\000\000\
\000\000\062\001\062\001\062\001\062\001\062\001\000\000\062\001\
\062\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\128\000\128\000\000\000\128\000\000\000\128\000\128\000\
\062\001\062\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\062\001\062\001\062\001\
\000\000\000\000\062\001\062\001\000\000\000\000\062\001\062\001\
\000\000\000\000\000\000\062\001\062\001\000\000\062\001\000\000\
\000\000\000\000\062\001\000\000\190\000\191\000\192\000\193\000\
\194\000\000\000\078\000\195\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\062\001\062\001\000\000\062\001\
\000\000\062\001\062\001\196\000\197\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\198\000\199\000\200\000\000\000\000\000\201\000\202\000\000\000\
\000\000\203\000\204\000\000\000\000\000\000\000\205\000\206\000\
\000\000\238\000\000\000\000\000\000\000\000\000\000\000\190\000\
\191\000\192\000\193\000\194\000\000\000\078\000\195\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\079\000\
\080\000\000\000\208\000\000\000\209\000\210\000\196\000\197\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\198\000\199\000\200\000\000\000\000\000\
\201\000\202\000\000\000\000\000\203\000\204\000\000\000\000\000\
\000\000\205\000\206\000\000\000\240\000\000\000\000\000\000\000\
\000\000\000\000\190\000\191\000\192\000\193\000\194\000\000\000\
\078\000\195\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\079\000\080\000\000\000\208\000\000\000\209\000\
\210\000\196\000\197\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\198\000\199\000\
\200\000\000\000\000\000\201\000\202\000\000\000\000\000\203\000\
\204\000\000\000\000\000\000\000\205\000\206\000\000\000\093\001\
\000\000\000\000\000\000\000\000\000\000\190\000\191\000\192\000\
\193\000\194\000\000\000\078\000\195\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\079\000\080\000\000\000\
\208\000\000\000\209\000\210\000\196\000\197\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\203\000\204\000\000\000\000\000\000\000\205\000\
\206\000\000\000\095\001\000\000\000\000\000\000\000\000\000\000\
\190\000\191\000\192\000\193\000\194\000\000\000\078\000\195\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\079\000\080\000\000\000\208\000\000\000\209\000\210\000\196\000\
\197\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\198\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\203\000\204\000\000\000\
\000\000\000\000\205\000\206\000\000\000\207\000\000\000\000\000\
\000\000\000\000\000\000\190\000\191\000\192\000\193\000\194\000\
\000\000\078\000\195\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\079\000\080\000\000\000\208\000\000\000\
\209\000\210\000\196\000\197\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\198\000\
\199\000\200\000\000\000\000\000\201\000\202\000\000\000\000\000\
\203\000\204\000\000\000\000\000\000\000\205\000\206\000\000\000\
\104\001\000\000\000\000\000\000\000\000\000\000\061\001\061\001\
\061\001\061\001\061\001\000\000\061\001\061\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\079\000\080\000\
\000\000\208\000\000\000\209\000\210\000\061\001\061\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\061\001\061\001\061\001\000\000\000\000\061\001\
\061\001\000\000\000\000\061\001\061\001\000\000\000\000\000\000\
\061\001\061\001\000\000\061\001\000\000\000\000\000\000\000\000\
\000\000\090\000\000\000\000\000\091\000\092\000\093\000\078\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\094\000\061\001\061\001\095\000\061\001\000\000\061\001\061\001\
\096\000\097\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\090\000\000\000\000\000\091\000\092\000\093\000\078\000\
\000\000\000\000\000\000\000\000\000\000\098\000\099\000\100\000\
\000\000\000\000\101\000\102\000\000\000\000\000\103\000\000\000\
\094\000\000\000\000\000\095\000\000\000\165\001\104\000\000\000\
\096\000\097\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\105\000\
\000\000\000\000\000\000\000\000\000\000\098\000\099\000\100\000\
\000\000\000\000\101\000\102\000\079\000\080\000\103\000\096\001\
\000\000\000\000\000\000\000\000\000\000\000\000\104\000\000\000\
\000\000\000\000\096\001\096\001\096\001\096\001\096\001\096\001\
\096\001\096\001\096\001\096\001\096\001\096\001\096\001\105\000\
\096\001\096\001\096\001\000\000\096\001\096\001\096\001\096\001\
\000\000\000\000\096\001\000\000\079\000\080\000\096\001\096\001\
\097\001\096\001\096\001\096\001\000\000\096\001\000\000\000\000\
\000\000\000\000\000\000\097\001\097\001\097\001\097\001\097\001\
\097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
\000\000\097\001\097\001\097\001\000\000\097\001\097\001\097\001\
\097\001\000\000\000\000\097\001\000\000\096\001\000\000\097\001\
\097\001\113\001\097\001\097\001\097\001\000\000\097\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\113\001\113\001\
\113\001\113\001\113\001\113\001\113\001\113\001\113\001\113\001\
\113\001\000\000\113\001\113\001\113\001\000\000\113\001\113\001\
\113\001\113\001\000\000\000\000\113\001\000\000\097\001\000\000\
\115\001\113\001\000\000\113\001\113\001\113\001\000\000\113\001\
\000\000\000\000\000\000\000\000\000\000\115\001\115\001\115\001\
\115\001\115\001\115\001\115\001\115\001\115\001\115\001\115\001\
\000\000\115\001\115\001\115\001\000\000\115\001\115\001\115\001\
\115\001\000\000\000\000\115\001\000\000\127\001\000\000\113\001\
\115\001\000\000\115\001\115\001\115\001\000\000\115\001\000\000\
\000\000\000\000\127\001\127\001\127\001\127\001\127\001\127\001\
\127\001\127\001\000\000\000\000\000\000\000\000\127\001\127\001\
\127\001\000\000\127\001\127\001\127\001\127\001\000\000\000\000\
\127\001\000\000\128\001\000\000\000\000\127\001\115\001\127\001\
\127\001\127\001\000\000\127\001\000\000\000\000\000\000\128\001\
\128\001\128\001\128\001\128\001\128\001\128\001\128\001\000\000\
\000\000\000\000\000\000\128\001\128\001\128\001\000\000\128\001\
\128\001\128\001\128\001\000\000\000\000\128\001\000\000\129\001\
\000\000\000\000\128\001\127\001\128\001\128\001\128\001\000\000\
\128\001\000\000\000\000\000\000\129\001\129\001\129\001\129\001\
\129\001\129\001\129\001\129\001\000\000\000\000\000\000\000\000\
\129\001\129\001\129\001\000\000\129\001\129\001\129\001\129\001\
\000\000\000\000\129\001\000\000\131\001\000\000\000\000\129\001\
\128\001\129\001\129\001\129\001\000\000\129\001\000\000\000\000\
\000\000\131\001\131\001\131\001\131\001\131\001\131\001\000\000\
\000\000\000\000\000\000\000\000\000\000\131\001\131\001\131\001\
\000\000\131\001\131\001\131\001\131\001\000\000\000\000\131\001\
\000\000\132\001\000\000\000\000\131\001\129\001\131\001\131\001\
\131\001\000\000\131\001\000\000\000\000\000\000\132\001\132\001\
\132\001\132\001\132\001\132\001\000\000\000\000\000\000\000\000\
\000\000\000\000\132\001\132\001\132\001\000\000\132\001\132\001\
\132\001\132\001\000\000\000\000\132\001\000\000\134\001\000\000\
\000\000\132\001\131\001\132\001\132\001\132\001\000\000\132\001\
\000\000\000\000\000\000\134\001\134\001\134\001\134\001\134\001\
\134\001\000\000\000\000\000\000\000\000\000\000\000\000\134\001\
\134\001\134\001\000\000\134\001\134\001\000\000\000\000\000\000\
\000\000\134\001\000\000\135\001\000\000\000\000\134\001\132\001\
\134\001\134\001\134\001\000\000\134\001\000\000\000\000\000\000\
\135\001\135\001\135\001\135\001\135\001\135\001\000\000\000\000\
\000\000\000\000\000\000\000\000\135\001\135\001\135\001\000\000\
\135\001\135\001\000\000\000\000\000\000\000\000\135\001\000\000\
\136\001\000\000\000\000\135\001\134\001\135\001\135\001\135\001\
\000\000\135\001\000\000\000\000\000\000\136\001\136\001\136\001\
\136\001\136\001\136\001\000\000\000\000\000\000\000\000\000\000\
\000\000\136\001\136\001\136\001\000\000\136\001\136\001\000\000\
\000\000\000\000\000\000\136\001\000\000\137\001\000\000\000\000\
\136\001\135\001\136\001\136\001\136\001\000\000\136\001\000\000\
\000\000\000\000\137\001\137\001\137\001\137\001\137\001\137\001\
\000\000\000\000\000\000\000\000\138\001\000\000\137\001\137\001\
\137\001\000\000\137\001\137\001\000\000\000\000\000\000\000\000\
\137\001\138\001\138\001\000\000\000\000\137\001\136\001\137\001\
\137\001\137\001\000\000\137\001\139\001\138\001\138\001\138\001\
\000\000\138\001\138\001\000\000\000\000\000\000\000\000\138\001\
\000\000\139\001\139\001\000\000\138\001\000\000\138\001\138\001\
\138\001\000\000\138\001\140\001\000\000\139\001\139\001\139\001\
\000\000\139\001\139\001\137\001\000\000\000\000\000\000\139\001\
\140\001\140\001\000\000\000\000\139\001\000\000\139\001\139\001\
\139\001\000\000\139\001\000\000\140\001\140\001\140\001\000\000\
\140\001\140\001\138\001\000\000\000\000\000\000\140\001\000\000\
\000\000\000\000\000\000\140\001\000\000\140\001\140\001\140\001\
\000\000\140\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\139\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\140\001\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\000\000\025\000\025\000\025\000\000\000\025\000\
\025\000\025\000\025\000\025\000\025\000\000\000\025\000\025\000\
\000\000\025\000\000\000\020\000\000\000\025\000\025\000\000\000\
\025\000"

let yycheck = "\017\000\
\018\000\042\000\020\000\047\000\151\000\001\000\002\000\067\000\
\082\000\026\000\159\000\000\000\075\000\059\000\040\001\059\000\
\207\000\197\001\187\000\027\001\212\001\111\000\067\001\068\001\
\041\000\042\001\071\002\158\000\042\001\207\001\167\000\168\000\
\003\001\047\000\066\002\107\002\134\000\033\000\048\000\068\002\
\081\000\007\001\051\000\017\000\018\000\059\000\020\000\238\000\
\108\000\240\000\046\000\060\000\070\000\013\001\014\001\083\001\
\074\000\076\001\041\000\077\000\098\000\099\000\100\000\101\000\
\102\000\103\000\033\000\076\001\217\000\086\000\061\001\088\000\
\013\001\014\001\052\001\007\001\159\000\211\001\026\000\046\000\
\048\000\098\000\099\000\100\000\101\000\102\000\103\000\104\000\
\129\000\130\000\118\001\052\001\083\001\041\000\111\000\076\001\
\070\000\005\001\170\002\061\001\074\000\079\001\007\001\077\000\
\018\000\007\001\020\000\012\001\171\000\075\001\012\001\174\000\
\175\000\176\000\075\001\159\000\179\000\180\000\079\001\081\001\
\070\001\104\000\030\001\141\000\032\001\033\001\034\001\013\001\
\172\000\037\001\087\000\013\001\142\000\143\000\217\000\131\000\
\086\001\182\002\086\000\069\002\088\000\215\000\216\000\075\001\
\013\001\159\000\106\001\107\001\119\001\178\002\098\000\099\000\
\100\000\101\000\102\000\103\000\104\000\071\000\093\001\081\002\
\095\001\052\001\007\001\111\000\131\000\106\001\107\001\001\001\
\096\002\104\001\187\000\061\001\037\001\078\001\142\000\143\000\
\041\001\112\001\113\001\076\001\116\002\109\002\190\001\000\000\
\229\001\060\001\204\000\183\000\069\001\203\001\068\002\069\002\
\206\001\083\001\102\001\037\001\038\001\102\001\207\000\041\001\
\042\001\218\001\219\001\217\000\218\001\113\001\075\001\115\001\
\113\001\081\001\076\001\042\000\081\001\085\001\061\001\145\002\
\183\000\147\002\154\002\149\002\106\001\107\001\001\000\002\000\
\106\001\107\001\008\001\009\001\010\001\238\000\075\001\240\000\
\078\001\250\000\081\001\007\001\083\001\106\001\107\001\187\000\
\012\001\002\001\007\001\005\001\006\001\158\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\072\001\027\001\145\002\044\003\147\002\070\001\149\002\
\096\000\097\000\081\001\013\001\007\001\035\001\085\001\203\002\
\007\001\012\001\076\001\075\001\054\002\047\001\086\001\005\001\
\006\001\030\001\137\002\083\001\033\001\140\002\061\001\076\001\
\086\001\059\001\129\000\130\000\178\002\225\002\250\000\007\001\
\001\000\002\000\078\001\004\000\012\001\076\001\002\001\202\001\
\079\001\076\001\076\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\168\001\027\001\
\033\000\081\001\203\001\040\001\093\001\111\002\095\001\081\001\
\077\001\042\000\078\001\078\001\089\001\046\000\078\001\104\001\
\217\001\105\002\219\001\197\001\102\001\054\000\205\002\121\001\
\122\001\203\001\063\001\207\000\206\001\062\000\081\001\113\001\
\106\001\107\001\071\001\077\001\196\000\197\000\078\001\217\001\
\218\001\219\001\084\001\078\001\007\001\205\000\206\000\076\001\
\081\000\012\001\080\001\007\001\235\002\254\001\087\000\085\001\
\012\001\075\001\238\000\040\001\240\000\158\001\102\001\081\001\
\007\001\065\001\007\001\121\001\122\001\012\001\210\001\012\001\
\075\001\113\001\111\001\002\003\254\001\201\001\081\001\067\001\
\051\001\052\001\005\001\098\002\099\002\066\001\067\001\007\001\
\069\001\070\001\214\001\234\001\012\001\190\001\075\001\069\001\
\129\000\130\000\131\000\080\001\198\001\082\001\083\001\084\001\
\077\002\086\001\005\001\030\001\079\001\233\001\033\001\034\001\
\078\001\058\002\037\001\078\001\061\002\083\001\037\001\007\001\
\061\001\043\002\078\001\244\002\012\001\158\000\005\001\007\001\
\101\002\066\001\158\001\030\001\012\001\076\001\033\001\034\001\
\058\002\118\001\037\001\061\002\005\003\061\001\087\002\007\001\
\198\001\040\001\102\001\083\001\012\001\182\000\183\000\030\001\
\084\001\076\001\033\001\034\001\076\001\113\001\037\001\079\001\
\025\003\198\001\190\001\075\001\076\001\087\002\075\001\079\001\
\040\001\093\001\079\001\095\001\084\001\108\001\207\000\084\001\
\075\001\083\001\077\001\102\001\104\001\080\001\081\001\102\001\
\083\001\084\001\085\001\040\001\076\001\083\001\113\001\079\001\
\115\001\075\001\113\001\232\001\115\001\076\001\078\001\081\001\
\079\001\125\001\126\001\102\001\046\002\238\000\071\002\240\000\
\030\001\077\002\076\001\033\001\076\001\079\001\113\001\007\001\
\115\001\040\001\010\001\011\001\012\001\062\002\075\001\102\001\
\066\002\104\001\084\001\040\001\081\001\071\002\083\001\084\001\
\177\002\157\001\113\001\075\001\115\001\007\001\030\001\077\002\
\078\001\033\001\012\001\061\001\007\001\083\001\084\001\084\001\
\046\002\012\001\075\001\071\002\075\001\040\001\096\002\177\002\
\040\001\080\001\100\002\082\001\083\001\084\001\075\001\101\002\
\105\002\078\001\047\002\109\002\081\001\084\001\083\001\084\001\
\078\001\054\002\075\001\071\001\072\001\054\001\077\001\080\001\
\081\001\203\002\083\001\060\001\007\001\153\002\077\001\129\002\
\078\001\012\001\062\002\061\001\078\001\135\002\078\001\118\001\
\075\001\005\001\096\002\083\001\084\001\093\001\100\002\225\002\
\040\001\075\001\076\001\075\001\141\002\079\001\076\001\109\002\
\007\001\076\001\084\001\096\002\093\001\012\001\095\001\061\001\
\062\001\063\001\030\001\247\001\076\001\033\001\034\001\104\001\
\109\002\037\001\111\002\059\001\060\001\105\002\070\001\112\001\
\113\001\179\002\061\001\075\001\182\002\076\001\240\002\075\001\
\080\001\075\001\082\001\083\001\084\001\191\002\086\001\193\002\
\194\002\076\001\065\001\253\002\254\002\138\002\066\001\067\001\
\067\001\069\001\070\001\066\001\206\002\069\001\061\001\075\001\
\077\001\077\001\053\001\054\001\080\001\081\001\084\001\083\001\
\084\001\085\001\086\001\244\002\010\001\076\001\118\001\059\001\
\060\001\094\001\095\001\096\001\075\001\231\002\171\002\059\002\
\010\001\080\001\102\001\075\001\083\001\084\001\118\001\241\002\
\242\002\071\001\072\001\236\002\110\001\113\001\075\001\115\001\
\250\002\053\001\054\001\120\001\083\001\084\001\082\002\061\001\
\062\001\063\001\251\002\075\001\006\003\007\001\099\001\100\001\
\010\001\011\001\012\001\013\001\083\001\084\001\207\001\118\001\
\094\001\095\001\096\001\212\001\007\001\022\003\198\000\199\000\
\200\000\201\000\202\000\203\000\030\001\083\001\084\001\033\001\
\075\001\117\002\081\001\232\002\077\001\039\003\075\001\040\003\
\129\000\130\000\044\003\083\001\001\001\094\001\095\001\096\001\
\005\001\050\003\007\001\084\001\136\002\142\001\143\001\012\001\
\077\001\005\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\077\001\030\001\144\001\145\001\033\001\034\001\077\001\
\005\001\037\001\022\003\093\001\176\002\055\001\056\001\057\001\
\058\001\038\003\146\001\147\001\148\001\149\001\186\002\077\001\
\106\001\107\001\190\002\077\001\040\003\055\001\056\001\057\001\
\058\001\030\001\150\001\151\001\033\001\034\001\050\003\075\001\
\037\001\069\001\070\001\015\001\016\001\017\001\018\001\075\001\
\083\001\077\001\011\001\012\001\080\001\081\001\071\002\083\001\
\084\001\085\001\086\001\084\001\191\002\075\001\193\002\194\002\
\081\002\102\001\103\001\075\001\105\001\196\002\197\002\198\002\
\142\000\143\000\102\001\206\002\113\001\075\001\115\001\075\001\
\244\002\098\002\099\002\120\001\076\001\113\001\075\001\115\001\
\076\001\007\001\013\001\014\001\040\001\080\001\012\001\253\002\
\254\002\005\003\084\001\116\002\231\002\051\001\052\001\019\001\
\020\001\102\001\083\001\104\001\084\001\083\001\241\002\242\002\
\129\002\079\001\077\001\077\001\113\001\025\003\115\001\250\002\
\077\001\069\001\070\001\073\001\074\001\077\001\076\001\075\001\
\075\001\079\001\075\001\006\003\080\001\075\001\082\001\083\001\
\084\001\154\002\086\001\139\001\140\001\141\001\142\001\143\001\
\144\001\145\001\146\001\147\001\148\001\149\001\150\001\151\001\
\152\001\153\001\154\001\155\001\156\001\075\001\076\001\084\001\
\084\001\079\001\084\001\075\001\039\003\001\001\084\001\003\001\
\004\001\005\001\118\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\080\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\081\001\078\001\082\001\040\001\077\001\084\001\081\001\059\001\
\060\001\061\001\075\001\244\002\064\001\065\001\075\001\075\001\
\068\001\069\001\080\001\077\001\084\001\073\001\074\001\077\001\
\076\001\077\001\078\001\083\001\075\001\075\001\032\001\083\001\
\075\001\249\001\120\001\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\083\001\
\083\001\076\001\102\001\103\001\104\001\105\001\106\001\107\001\
\081\001\109\001\081\001\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\119\001\120\001\004\001\005\001\040\001\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\083\001\075\001\075\001\075\001\078\001\080\001\077\001\
\081\001\075\001\083\001\084\001\075\001\081\001\083\001\076\001\
\083\001\076\001\007\001\083\001\059\001\060\001\061\001\080\001\
\101\001\064\001\065\001\076\001\081\001\068\001\069\001\081\001\
\094\001\079\001\073\001\074\001\083\001\076\001\077\001\078\001\
\104\002\075\001\083\001\083\001\083\001\075\001\007\001\084\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\081\001\083\001\080\001\102\001\
\103\001\104\001\105\001\106\001\107\001\083\001\109\001\076\001\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\001\001\
\075\001\120\001\004\001\005\001\081\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\128\001\129\001\
\130\001\131\001\132\001\133\001\134\001\135\001\136\001\137\001\
\138\001\075\001\005\001\084\001\081\001\000\000\077\001\083\001\
\075\001\059\001\060\001\061\001\078\001\075\001\064\001\065\001\
\007\001\077\001\068\001\069\001\077\001\012\001\075\001\073\001\
\074\001\079\001\076\001\030\001\078\001\077\001\033\001\034\001\
\083\001\083\001\037\001\075\001\081\001\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\083\001\077\001\077\001\102\001\103\001\104\001\105\001\
\106\001\107\001\078\001\109\001\078\001\111\001\112\001\113\001\
\114\001\115\001\116\001\117\001\080\001\001\001\120\001\003\001\
\004\001\083\001\040\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\076\001\075\001\076\001\083\001\075\001\
\079\001\075\001\075\001\075\001\075\001\084\001\002\000\206\001\
\165\002\170\002\004\000\102\001\066\001\067\001\064\001\069\001\
\070\001\065\002\038\001\039\001\194\001\075\001\113\001\233\001\
\115\001\141\000\080\001\152\001\082\001\083\001\084\001\154\001\
\086\001\153\001\155\001\104\002\082\002\156\001\043\002\059\001\
\060\001\061\001\009\003\222\001\064\001\065\001\165\000\153\002\
\068\001\069\001\001\001\168\001\021\001\073\001\074\001\022\001\
\076\001\077\001\078\001\023\001\025\001\024\001\030\003\083\001\
\118\001\028\003\050\003\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\007\001\255\255\047\003\255\255\104\001\012\001\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\255\255\114\001\255\255\
\255\255\255\255\255\255\119\001\120\001\001\001\255\255\003\001\
\004\001\005\001\255\255\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\075\001\076\001\255\255\255\255\
\079\001\255\255\255\255\255\255\255\255\084\001\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\083\001\
\255\255\255\255\255\255\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\255\255\102\001\103\001\104\001\105\001\106\001\107\001\
\255\255\109\001\110\001\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\119\001\003\001\004\001\005\001\255\255\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\077\001\078\001\
\255\255\255\255\255\255\255\255\083\001\255\255\255\255\255\255\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\255\255\255\255\255\255\102\001\
\103\001\104\001\105\001\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\001\001\
\119\001\003\001\004\001\005\001\255\255\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\255\255\083\001\255\255\255\255\255\255\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\255\255\255\255\255\255\097\001\
\098\001\255\255\255\255\255\255\102\001\103\001\104\001\105\001\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\113\001\
\114\001\115\001\255\255\255\255\001\001\119\001\003\001\004\001\
\255\255\040\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\255\255\255\255\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\038\001\039\001\255\255\075\001\255\255\255\255\255\255\
\255\255\080\001\255\255\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\078\001\255\255\255\255\255\255\255\255\083\001\118\001\
\255\255\255\255\087\001\088\001\089\001\090\001\091\001\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\255\255\255\255\255\255\104\001\255\255\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\255\255\114\001\001\001\040\001\
\003\001\004\001\119\001\255\255\007\001\008\001\009\001\010\001\
\011\001\012\001\013\001\014\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\038\001\039\001\255\255\255\255\080\001\
\255\255\082\001\083\001\084\001\255\255\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\078\001\255\255\118\001\255\255\255\255\
\083\001\255\255\255\255\255\255\087\001\088\001\089\001\090\001\
\091\001\092\001\093\001\255\255\255\255\255\255\097\001\098\001\
\255\255\255\255\255\255\255\255\255\255\104\001\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\255\255\114\001\
\255\255\001\001\002\001\255\255\119\001\005\001\006\001\007\001\
\040\001\255\255\255\255\255\255\012\001\255\255\255\255\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\255\255\255\255\255\255\
\080\001\040\001\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\255\255\255\255\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\255\255\083\001\075\001\255\255\118\001\255\255\
\079\001\080\001\255\255\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\104\001\105\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\001\001\115\001\116\001\117\001\005\001\119\001\
\007\001\255\255\255\255\010\001\011\001\012\001\255\255\118\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\255\255\
\255\255\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\076\001\255\255\078\001\
\079\001\080\001\081\001\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\093\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\102\001\
\103\001\255\255\105\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\001\001\255\255\118\001\
\004\001\005\001\255\255\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\083\001\
\255\255\255\255\255\255\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\255\255\102\001\103\001\104\001\105\001\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\255\255\007\001\004\001\005\001\255\255\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\075\001\076\001\073\001\074\001\079\001\076\001\081\001\078\001\
\083\001\084\001\255\255\255\255\083\001\255\255\255\255\255\255\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\255\255\
\255\255\255\255\097\001\098\001\255\255\255\255\255\255\102\001\
\103\001\104\001\105\001\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\001\001\
\255\255\255\255\255\255\005\001\255\255\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\005\001\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\255\255\102\001\103\001\255\255\105\001\
\106\001\107\001\255\255\109\001\001\001\111\001\112\001\113\001\
\005\001\115\001\255\255\255\255\255\255\255\255\255\255\012\001\
\255\255\255\255\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\078\001\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\007\001\102\001\103\001\255\255\105\001\012\001\030\001\255\255\
\255\255\033\001\034\001\255\255\113\001\037\001\115\001\255\255\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\073\001\074\001\075\001\076\001\077\001\061\001\079\001\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\005\001\075\001\076\001\255\255\255\255\
\079\001\255\255\081\001\255\255\083\001\084\001\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\030\001\255\255\118\001\033\001\
\034\001\255\255\255\255\037\001\255\255\255\255\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\073\001\
\074\001\075\001\076\001\077\001\255\255\079\001\080\001\081\001\
\082\001\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\030\001\255\255\118\001\033\001\034\001\255\255\
\255\255\037\001\255\255\255\255\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\050\001\255\255\
\255\255\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\255\255\255\255\075\001\
\255\255\077\001\255\255\255\255\080\001\081\001\082\001\083\001\
\084\001\085\001\086\001\255\255\255\255\255\255\255\255\005\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\030\001\255\255\118\001\033\001\034\001\255\255\255\255\037\001\
\255\255\255\255\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\255\255\255\255\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\255\255\077\001\
\255\255\255\255\080\001\081\001\082\001\083\001\084\001\085\001\
\086\001\255\255\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\030\001\255\255\
\118\001\033\001\034\001\255\255\255\255\037\001\255\255\255\255\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\255\255\255\255\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\001\001\
\255\255\255\255\004\001\255\255\040\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\255\255\255\255\118\001\255\255\
\255\255\069\001\070\001\255\255\038\001\039\001\255\255\075\001\
\255\255\255\255\255\255\255\255\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\255\255\083\001\118\001\255\255\255\255\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\255\255\255\255\255\255\097\001\
\098\001\255\255\255\255\255\255\255\255\255\255\104\001\255\255\
\106\001\107\001\005\001\109\001\255\255\111\001\112\001\255\255\
\114\001\012\001\040\001\255\255\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\065\001\066\001\067\001\255\255\069\001\
\070\001\255\255\255\255\255\255\255\255\075\001\255\255\255\255\
\255\255\255\255\080\001\255\255\082\001\083\001\084\001\255\255\
\086\001\255\255\255\255\255\255\255\255\255\255\255\255\040\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\007\001\
\255\255\255\255\010\001\011\001\012\001\013\001\255\255\255\255\
\083\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\118\001\066\001\255\255\255\255\069\001\070\001\030\001\255\255\
\255\255\033\001\075\001\102\001\103\001\255\255\105\001\080\001\
\040\001\082\001\083\001\084\001\255\255\086\001\113\001\255\255\
\115\001\116\001\117\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\076\001\118\001\255\255\079\001\
\080\001\255\255\082\001\083\001\084\001\255\255\086\001\005\001\
\255\255\255\255\255\255\007\001\255\255\093\001\010\001\011\001\
\012\001\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\106\001\107\001\255\255\255\255\255\255\255\255\
\030\001\255\255\030\001\033\001\034\001\033\001\118\001\037\001\
\255\255\255\255\255\255\255\255\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\051\001\
\052\001\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\255\255\076\001\075\001\
\076\001\079\001\255\255\079\001\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\255\255\255\255\255\255\255\255\007\001\
\255\255\093\001\010\001\011\001\012\001\013\001\255\255\255\255\
\102\001\255\255\104\001\255\255\255\255\255\255\106\001\107\001\
\255\255\255\255\255\255\113\001\255\255\115\001\030\001\255\255\
\255\255\033\001\118\001\255\255\255\255\255\255\255\255\255\255\
\040\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\255\255\255\255\079\001\
\080\001\255\255\082\001\083\001\084\001\007\001\086\001\255\255\
\010\001\011\001\012\001\013\001\255\255\093\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\040\001\106\001\107\001\030\001\255\255\255\255\033\001\
\255\255\255\255\255\255\255\255\038\001\039\001\118\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\059\001\060\001\061\001\075\001\255\255\064\001\065\001\
\255\255\080\001\068\001\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\076\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\093\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\118\001\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\005\001\118\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\103\001\255\255\105\001\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\113\001\
\005\001\115\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\113\001\005\001\115\001\007\001\
\255\255\255\255\255\255\255\255\012\001\040\001\255\255\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\255\255\066\001\
\255\255\255\255\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\255\255\255\255\255\255\080\001\255\255\082\001\
\083\001\084\001\255\255\086\001\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\075\001\076\001\255\255\255\255\079\001\
\255\255\081\001\255\255\083\001\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\118\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\255\255\105\001\255\255\005\001\255\255\007\001\255\255\255\255\
\255\255\113\001\012\001\115\001\255\255\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\061\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\075\001\076\001\255\255\255\255\079\001\255\255\081\001\
\255\255\083\001\084\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\103\001\255\255\105\001\
\255\255\005\001\255\255\007\001\255\255\255\255\255\255\113\001\
\012\001\115\001\255\255\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\075\001\
\076\001\255\255\255\255\079\001\255\255\081\001\255\255\083\001\
\084\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\005\001\
\255\255\007\001\255\255\255\255\255\255\113\001\012\001\115\001\
\255\255\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\061\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\075\001\076\001\255\255\
\255\255\079\001\255\255\081\001\255\255\083\001\084\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\103\001\255\255\105\001\255\255\005\001\255\255\007\001\
\255\255\255\255\255\255\113\001\012\001\115\001\255\255\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\076\001\255\255\255\255\255\255\
\255\255\081\001\255\255\083\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\255\255\105\001\255\255\005\001\255\255\007\001\255\255\255\255\
\255\255\113\001\012\001\115\001\255\255\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\061\001\255\255\255\255\255\255\255\255\
\255\255\255\255\005\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\076\001\255\255\255\255\255\255\255\255\255\255\
\255\255\083\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\102\001\103\001\255\255\105\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\063\001\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\255\255\255\255\255\255\
\005\001\255\255\255\255\255\255\255\255\255\255\113\001\012\001\
\115\001\005\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\005\001\030\001\007\001\255\255\033\001\034\001\255\255\
\012\001\037\001\255\255\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\255\255\255\255\255\255\066\001\076\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\085\001\077\001\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\086\001\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\255\255\255\255\255\255\
\255\255\255\255\102\001\255\255\113\001\255\255\115\001\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\005\001\
\255\255\255\255\255\255\255\255\255\255\113\001\012\001\115\001\
\005\001\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\005\001\030\001\255\255\255\255\033\001\034\001\255\255\012\001\
\037\001\255\255\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\255\255\255\255\255\255\255\255\066\001\076\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\255\255\
\077\001\255\255\255\255\080\001\081\001\255\255\083\001\084\001\
\085\001\086\001\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\103\001\255\255\105\001\255\255\255\255\255\255\255\255\
\255\255\102\001\255\255\113\001\255\255\115\001\255\255\255\255\
\085\001\255\255\255\255\255\255\113\001\255\255\115\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\255\255\005\001\255\255\
\255\255\255\255\255\255\255\255\113\001\012\001\115\001\255\255\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\005\001\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\076\001\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\255\255\255\255\255\255\
\255\255\080\001\255\255\082\001\083\001\084\001\030\001\086\001\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\102\001\
\103\001\255\255\105\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\255\255\255\255\118\001\
\255\255\065\001\066\001\067\001\005\001\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\005\001\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\113\001\
\012\001\115\001\005\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\005\001\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\113\001\255\255\115\001\
\030\001\255\255\255\255\033\001\034\001\255\255\113\001\037\001\
\115\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\053\001\
\054\001\055\001\056\001\057\001\058\001\255\255\255\255\255\255\
\255\255\255\255\255\255\065\001\066\001\067\001\005\001\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\255\255\077\001\
\255\255\255\255\080\001\081\001\255\255\083\001\084\001\085\001\
\086\001\255\255\255\255\255\255\255\255\255\255\255\255\030\001\
\255\255\255\255\033\001\034\001\255\255\255\255\037\001\255\255\
\102\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\005\001\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\255\255\077\001\255\255\
\255\255\080\001\081\001\255\255\083\001\084\001\085\001\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\102\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\053\001\054\001\055\001\
\056\001\057\001\058\001\255\255\255\255\255\255\255\255\255\255\
\255\255\065\001\066\001\067\001\005\001\069\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\053\001\054\001\055\001\056\001\
\057\001\058\001\255\255\255\255\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\005\001\069\001\070\001\255\255\255\255\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\053\001\054\001\055\001\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\005\001\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\255\255\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\005\001\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\030\001\255\255\255\255\033\001\034\001\255\255\
\255\255\037\001\255\255\102\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\113\001\255\255\
\115\001\053\001\054\001\055\001\056\001\057\001\058\001\255\255\
\255\255\255\255\005\001\255\255\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\255\255\077\001\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\086\001\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\054\001\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\005\001\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\053\001\054\001\255\255\113\001\255\255\
\115\001\255\255\255\255\255\255\005\001\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\255\255\113\001\
\255\255\115\001\255\255\255\255\255\255\005\001\255\255\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\255\255\255\255\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\255\255\255\255\255\255\005\001\255\255\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\030\001\
\255\255\255\255\033\001\034\001\255\255\255\255\037\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\255\255\255\255\255\255\005\001\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\255\255\255\255\255\255\075\001\255\255\077\001\255\255\
\255\255\080\001\081\001\005\001\083\001\084\001\085\001\086\001\
\030\001\255\255\255\255\033\001\034\001\255\255\255\255\037\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\102\001\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\034\001\255\255\113\001\037\001\115\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\066\001\067\001\255\255\069\001\
\070\001\255\255\255\255\255\255\255\255\075\001\255\255\077\001\
\255\255\255\255\080\001\081\001\005\001\083\001\084\001\085\001\
\086\001\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\102\001\083\001\084\001\085\001\086\001\030\001\255\255\255\255\
\033\001\034\001\255\255\113\001\037\001\115\001\255\255\255\255\
\255\255\255\255\255\255\005\001\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\070\001\255\255\033\001\
\034\001\255\255\075\001\037\001\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\070\001\255\255\255\255\255\255\
\113\001\075\001\115\001\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\032\001\113\001\
\255\255\115\001\255\255\255\255\038\001\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\075\001\076\001\013\001\078\001\079\001\080\001\081\001\
\255\255\083\001\084\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\040\001\255\255\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\255\255\
\255\255\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\255\255\
\255\255\075\001\255\255\255\255\255\255\079\001\080\001\255\255\
\082\001\083\001\084\001\255\255\086\001\255\255\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\118\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\052\001\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\078\001\079\001\255\255\
\255\255\255\255\007\001\008\001\009\001\010\001\011\001\255\255\
\013\001\014\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\032\001\109\001\255\255\111\001\112\001\
\255\255\038\001\039\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\255\255\255\255\080\001\255\255\007\001\008\001\009\001\
\010\001\011\001\255\255\013\001\014\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\038\001\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\007\001\008\001\009\001\010\001\011\001\255\255\013\001\014\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\255\255\078\001\
\255\255\255\255\255\255\007\001\008\001\009\001\010\001\011\001\
\255\255\013\001\014\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\255\255\078\001\255\255\255\255\255\255\007\001\008\001\
\009\001\010\001\011\001\255\255\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\255\255\255\255\255\255\
\255\255\255\255\083\001\007\001\008\001\009\001\010\001\011\001\
\255\255\013\001\014\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\255\255\111\001\112\001\
\255\255\255\255\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\255\255\255\255\255\255\080\001\255\255\007\001\008\001\
\009\001\010\001\011\001\255\255\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\078\001\255\255\255\255\
\255\255\007\001\008\001\009\001\010\001\011\001\255\255\013\001\
\014\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\255\255\111\001\112\001\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\255\255\255\255\068\001\069\001\
\255\255\255\255\255\255\073\001\074\001\255\255\076\001\255\255\
\255\255\255\255\080\001\255\255\007\001\008\001\009\001\010\001\
\011\001\255\255\013\001\014\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\106\001\107\001\255\255\109\001\
\255\255\111\001\112\001\038\001\039\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\255\255\255\255\255\255\255\255\007\001\
\008\001\009\001\010\001\011\001\255\255\013\001\014\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\038\001\039\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\255\255\
\064\001\065\001\255\255\255\255\068\001\069\001\255\255\255\255\
\255\255\073\001\074\001\255\255\076\001\255\255\255\255\255\255\
\255\255\255\255\007\001\008\001\009\001\010\001\011\001\255\255\
\013\001\014\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\106\001\107\001\255\255\109\001\255\255\111\001\
\112\001\038\001\039\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\255\255\255\255\255\255\255\255\007\001\008\001\009\001\
\010\001\011\001\255\255\013\001\014\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\255\255\255\255\255\255\255\255\
\007\001\008\001\009\001\010\001\011\001\255\255\013\001\014\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\255\255\255\255\
\255\255\255\255\255\255\007\001\008\001\009\001\010\001\011\001\
\255\255\013\001\014\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\255\255\255\255\255\255\255\255\255\255\007\001\008\001\
\009\001\010\001\011\001\255\255\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\255\255\255\255\255\255\
\255\255\007\001\255\255\255\255\010\001\011\001\012\001\013\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\030\001\106\001\107\001\033\001\109\001\255\255\111\001\112\001\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\007\001\255\255\255\255\010\001\011\001\012\001\013\001\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\255\255\255\255\068\001\255\255\
\030\001\255\255\255\255\033\001\255\255\075\001\076\001\255\255\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\093\001\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\106\001\107\001\068\001\040\001\
\255\255\255\255\255\255\255\255\255\255\255\255\076\001\255\255\
\255\255\255\255\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\093\001\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\255\255\106\001\107\001\079\001\080\001\
\040\001\082\001\083\001\084\001\255\255\086\001\255\255\255\255\
\255\255\255\255\255\255\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\118\001\255\255\079\001\
\080\001\040\001\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\255\255\118\001\255\255\
\040\001\080\001\255\255\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\040\001\255\255\118\001\
\080\001\255\255\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\040\001\255\255\255\255\080\001\118\001\082\001\
\083\001\084\001\255\255\086\001\255\255\255\255\255\255\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\255\255\
\255\255\255\255\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\255\255\040\001\
\255\255\255\255\080\001\118\001\082\001\083\001\084\001\255\255\
\086\001\255\255\255\255\255\255\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\255\255\040\001\255\255\255\255\080\001\
\118\001\082\001\083\001\084\001\255\255\086\001\255\255\255\255\
\255\255\053\001\054\001\055\001\056\001\057\001\058\001\255\255\
\255\255\255\255\255\255\255\255\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\255\255\255\255\075\001\
\255\255\040\001\255\255\255\255\080\001\118\001\082\001\083\001\
\084\001\255\255\086\001\255\255\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\255\255\040\001\255\255\
\255\255\080\001\118\001\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\053\001\054\001\055\001\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\040\001\255\255\255\255\080\001\118\001\
\082\001\083\001\084\001\255\255\086\001\255\255\255\255\255\255\
\053\001\054\001\055\001\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\255\255\065\001\066\001\067\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\255\255\
\040\001\255\255\255\255\080\001\118\001\082\001\083\001\084\001\
\255\255\086\001\255\255\255\255\255\255\053\001\054\001\055\001\
\056\001\057\001\058\001\255\255\255\255\255\255\255\255\255\255\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\040\001\255\255\255\255\
\080\001\118\001\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\040\001\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\053\001\054\001\255\255\255\255\080\001\118\001\082\001\
\083\001\084\001\255\255\086\001\040\001\065\001\066\001\067\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\255\255\053\001\054\001\255\255\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\040\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\118\001\255\255\255\255\255\255\075\001\
\053\001\054\001\255\255\255\255\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\255\255\065\001\066\001\067\001\255\255\
\069\001\070\001\118\001\255\255\255\255\255\255\075\001\255\255\
\255\255\255\255\255\255\080\001\255\255\082\001\083\001\084\001\
\255\255\086\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\118\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\118\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\073\001\074\001\255\255\076\001\077\001\
\255\255\079\001\255\255\081\001\255\255\083\001\084\001\255\255\
\086\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COLON2\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  LGHOST\000\
  RGHOST\000\
  "

let yynames_block = "\
  SPEC\000\
  DECL\000\
  CODE_ANNOT\000\
  LOOP_ANNOT\000\
  ATTRIBUTE_ANNOT\000\
  CUSTOM_ANNOT\000\
  IDENT\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  BOOL\000\
  CHAR\000\
  INT\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  THREAD\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA_LINE\000\
  PRAGMA\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 436 "src/kernel_internals/parsing/cparser.mly"
                ( _1 )
# 3174 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    Obj.repr(
# 438 "src/kernel_internals/parsing/cparser.mly"
                    (_1)
# 3181 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 441 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 3187 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 442 "src/kernel_internals/parsing/cparser.mly"
                                        ( (false,_1) :: _2 )
# 3195 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'ghost_globals) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 443 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2 @ _3 )
# 3203 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 444 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2 )
# 3211 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 449 "src/kernel_internals/parsing/cparser.mly"
                                                      ( (true,_1)::_2 )
# 3219 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 450 "src/kernel_internals/parsing/cparser.mly"
                                                      ( (true,_1)::_2 )
# 3227 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    Obj.repr(
# 451 "src/kernel_internals/parsing/cparser.mly"
                                                      ( [] )
# 3233 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.decl list) in
    Obj.repr(
# 456 "src/kernel_internals/parsing/cparser.mly"
                   ( GLOBANNOT _1 )
# 3240 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.custom_tree  * string * Cabs.cabsloc) in
    Obj.repr(
# 457 "src/kernel_internals/parsing/cparser.mly"
                   ( let (x,y,z) = _1 in CUSTOM(x,y,z) )
# 3247 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 458 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3254 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 459 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3261 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 464 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2), [ _3 ]) )
# 3270 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 466 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2),
                 List.map
                   (fun (x,y) ->
                      if x then
                        Errorloc.parse_error "invalid ghost in extern linkage \
                                              specification"
		      else y)
                   _4)  )
# 3288 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 475 "src/kernel_internals/parsing/cparser.mly"
                                        ( GLOBASM (fst _3, (*handleLoc*) _1) )
# 3298 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'pragma) in
    Obj.repr(
# 476 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 3305 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'old_pardef_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 481 "src/kernel_internals/parsing/cparser.mly"
    (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      (* Make the function declarator *)
      doDeclaration None loc []
        [((_1, PROTO(JUSTBASE, pardecl,isva), 
           ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
    )
# 3324 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 490 "src/kernel_internals/parsing/cparser.mly"
                                (
  let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
  doDeclaration None loc []
    [((_1, PROTO(JUSTBASE,[],false),
       ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
)
# 3338 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 499 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 3345 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 500 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3352 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 504 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 3359 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    Obj.repr(
# 508 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3365 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    Obj.repr(
# 509 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3371 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 515 "src/kernel_internals/parsing/cparser.mly"
         ( make_expr (VARIABLE _1) )
# 3378 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 516 "src/kernel_internals/parsing/cparser.mly"
                   (
  let (v,expr_loc) = _1 in { expr_loc; expr_node = CONSTANT v } )
# 3386 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 519 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (PAREN (smooth_expression _1)) )
# 3393 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 520 "src/kernel_internals/parsing/cparser.mly"
                       ( make_expr (GNU_BODY (fst3 _2)) )
# 3401 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 524 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 3408 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 526 "src/kernel_internals/parsing/cparser.mly"
      (make_expr (INDEX (_1, smooth_expression _2)))
# 3416 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 527 "src/kernel_internals/parsing/cparser.mly"
                                             (make_expr (CALL (_1, _3)))
# 3425 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 529 "src/kernel_internals/parsing/cparser.mly"
      ( let b, d = _5 in
        let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5) in
        let loc_f = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        make_expr
          (CALL
             ({ expr_loc = loc_f;
                expr_node = VARIABLE "__builtin_va_arg"},
              [_3; { expr_loc = loc;
                     expr_node = TYPE_SIZEOF (b, d)}]))
      )
# 3444 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 540 "src/kernel_internals/parsing/cparser.mly"
      ( let b1,d1 = _3 in
        let b2,d2 = _5 in
        let loc_f = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        let loc1 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3) in
        let loc2 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5) in
        make_expr
          (CALL
             ({expr_loc = loc_f;
               expr_node = VARIABLE "__builtin_types_compatible_p"},
              [ { expr_loc = loc1; expr_node = TYPE_SIZEOF(b1,d1)};
                { expr_loc = loc2; expr_node = TYPE_SIZEOF(b2,d2)}]))
      )
# 3465 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 553 "src/kernel_internals/parsing/cparser.mly"
      ( transformOffsetOf _3 _5 )
# 3475 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 554 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)))
# 3483 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 555 "src/kernel_internals/parsing/cparser.mly"
                                          ( make_expr (MEMBEROFPTR (_1, _3)) )
# 3491 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 556 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (UNARY (POSINCR, _1)) )
# 3499 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 557 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (POSDECR, _1)) )
# 3507 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 560 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, COMPOUND_INIT _5)) )
# 3518 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 564 "src/kernel_internals/parsing/cparser.mly"
                  ( make_expr (VARIABLE _1) )
# 3525 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'offsetof_member_designator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 566 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (MEMBEROF (_1, _3)) )
# 3533 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 568 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (INDEX (_1, smooth_expression _2)) )
# 3541 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 573 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3548 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 575 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREINCR, _2)))
# 3556 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 577 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREDECR, _2)))
# 3564 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 579 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (EXPR_SIZEOF _2))
# 3572 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 581 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_SIZEOF (b, d)) )
# 3581 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 583 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (EXPR_ALIGNOF _2) )
# 3589 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 585 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_ALIGNOF (b, d)) )
# 3598 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 587 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (PLUS, _2)) )
# 3606 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 589 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (MINUS, _2)) )
# 3614 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 591 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (MEMOF, _2)) )
# 3622 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 593 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (ADDROF, _2)))
# 3630 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 595 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (NOT, _2)) )
# 3638 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 597 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (BNOT, _2)) )
# 3646 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 599 "src/kernel_internals/parsing/cparser.mly"
                                             ( make_expr (LABELADDR _2) )
# 3654 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 603 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3661 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 605 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, SINGLE_INIT _4)) )
# 3670 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 609 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3677 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 611 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MUL, _1, _3)) )
# 3686 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 613 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(DIV, _1, _3)) )
# 3694 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 615 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MOD, _1, _3)) )
# 3702 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 619 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 3709 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 621 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD, _1, _3)) )
# 3718 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 623 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB, _1, _3)) )
# 3727 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 627 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3734 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 629 "src/kernel_internals/parsing/cparser.mly"
   (make_expr (BINARY(SHL, _1, _3)) )
# 3742 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 631 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR, _1, _3)) )
# 3750 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 636 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 3757 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 638 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LT, _1, _3)) )
# 3765 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 640 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GT, _1, _3)) )
# 3773 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 642 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LE, _1, _3)) )
# 3781 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 644 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GE, _1, _3)) )
# 3789 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 648 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3796 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 650 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(EQ, _1, _3)) )
# 3804 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 652 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(NE, _1, _3)) )
# 3812 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 656 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3819 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 658 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND, _1, _3)) )
# 3828 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 662 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3835 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 664 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR, _1, _3)) )
# 3843 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 668 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3850 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 670 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR, _1, _3)) )
# 3858 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 674 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 3865 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 676 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(AND, _1, _3)) )
# 3874 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 680 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3881 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 682 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(OR, _1, _3)) )
# 3889 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 686 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3896 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 688 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (QUESTION (_1, _3, _5)) )
# 3905 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 695 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3912 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 697 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ASSIGN, _1, _3)) )
# 3920 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 699 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD_ASSIGN, _1, _3)) )
# 3928 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 701 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB_ASSIGN, _1, _3)) )
# 3936 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 703 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MUL_ASSIGN, _1, _3)) )
# 3944 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 705 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(DIV_ASSIGN, _1, _3)) )
# 3952 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 707 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MOD_ASSIGN, _1, _3)) )
# 3960 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 709 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND_ASSIGN, _1, _3)) )
# 3968 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 711 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR_ASSIGN, _1, _3)) )
# 3976 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 713 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR_ASSIGN, _1, _3)) )
# 3984 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 715 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHL_ASSIGN, _1, _3)) )
# 3992 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 717 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR_ASSIGN, _1, _3)))
# 4000 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 721 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 4007 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 726 "src/kernel_internals/parsing/cparser.mly"
               (CONST_INT (fst _1), snd _1)
# 4014 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 727 "src/kernel_internals/parsing/cparser.mly"
                 (CONST_FLOAT (fst _1), snd _1)
# 4021 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 728 "src/kernel_internals/parsing/cparser.mly"
                (CONST_CHAR (fst _1), snd _1)
# 4028 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 729 "src/kernel_internals/parsing/cparser.mly"
                 (CONST_WCHAR (fst _1), snd _1)
# 4035 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 730 "src/kernel_internals/parsing/cparser.mly"
                             (CONST_STRING (fst _1), snd _1)
# 4042 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 731 "src/kernel_internals/parsing/cparser.mly"
                   (CONST_WSTRING (fst _1), snd _1)
# 4049 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 737 "src/kernel_internals/parsing/cparser.mly"
                                        ( intlist_to_string (fst _1), snd _1 )
# 4056 "src/kernel_internals/parsing/cparser.ml"
               : string * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 741 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1, snd _1 )
# 4063 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 742 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4071 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 746 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 4078 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 747 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4086 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 748 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4094 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 749 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4102 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 753 "src/kernel_internals/parsing/cparser.mly"
                  (_1)
# 4109 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 754 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 4117 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 756 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 4125 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 761 "src/kernel_internals/parsing/cparser.mly"
                        ( SINGLE_INIT _1 )
# 4132 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 763 "src/kernel_internals/parsing/cparser.mly"
   ( COMPOUND_INIT _2)
# 4141 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 766 "src/kernel_internals/parsing/cparser.mly"
                                                   ( [_1] )
# 4148 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 767 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _1 :: _3 )
# 4156 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 770 "src/kernel_internals/parsing/cparser.mly"
                                            ( [] )
# 4162 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 771 "src/kernel_internals/parsing/cparser.mly"
                                            ( _1 )
# 4169 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'eq_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 774 "src/kernel_internals/parsing/cparser.mly"
                                            ( (_1, _3) )
# 4178 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gcc_init_designators) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 775 "src/kernel_internals/parsing/cparser.mly"
                                         ( (_1, _2) )
# 4186 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 776 "src/kernel_internals/parsing/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 4193 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 779 "src/kernel_internals/parsing/cparser.mly"
                             ( () )
# 4199 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 781 "src/kernel_internals/parsing/cparser.mly"
                                 ( () )
# 4205 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 784 "src/kernel_internals/parsing/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 4213 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 785 "src/kernel_internals/parsing/cparser.mly"
                                                       ( ATINDEX_INIT(_2, _4) )
# 4221 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 787 "src/kernel_internals/parsing/cparser.mly"
        ( ATINDEXRANGE_INIT(_2, _4) )
# 4229 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    Obj.repr(
# 790 "src/kernel_internals/parsing/cparser.mly"
                                        ( NEXT_INIT )
# 4235 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 791 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 4242 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 795 "src/kernel_internals/parsing/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 4249 "src/kernel_internals/parsing/cparser.ml"
               : 'gcc_init_designators))
; (fun __caml_parser_env ->
    Obj.repr(
# 799 "src/kernel_internals/parsing/cparser.mly"
                                    ( [] )
# 4255 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 800 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 4262 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 804 "src/kernel_internals/parsing/cparser.mly"
                     (make_expr NOTHING)
# 4268 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 805 "src/kernel_internals/parsing/cparser.mly"
                           (smooth_expression _1 )
# 4275 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 809 "src/kernel_internals/parsing/cparser.mly"
                                           ( [_1] )
# 4282 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 810 "src/kernel_internals/parsing/cparser.mly"
                                                  ( _1 :: _3 )
# 4290 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 814 "src/kernel_internals/parsing/cparser.mly"
                                    ( make_expr NOTHING )
# 4296 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 815 "src/kernel_internals/parsing/cparser.mly"
                                    ( smooth_expression _1 )
# 4303 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 819 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _2 )
# 4311 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 823 "src/kernel_internals/parsing/cparser.mly"
                                                       ( _2 )
# 4318 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'block_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'block_attrs) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 830 "src/kernel_internals/parsing/cparser.mly"
      (!Lexerhack.pop_context();
       { blabels = _2;
         battrs = _3;
         bstmts = _4 },
       _1, _5
      )
# 4334 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 838 "src/kernel_internals/parsing/cparser.mly"
            ( !Lexerhack.push_context (); _1 )
# 4341 "src/kernel_internals/parsing/cparser.ml"
               : 'block_begin))
; (fun __caml_parser_env ->
    Obj.repr(
# 842 "src/kernel_internals/parsing/cparser.mly"
                                                            ( [] )
# 4347 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 844 "src/kernel_internals/parsing/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 4354 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 849 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 )
# 4361 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 851 "src/kernel_internals/parsing/cparser.mly"
        ( _1 @ no_ghost_stmt (DEFINITION(_2)) :: _3 )
# 4370 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'statement) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 853 "src/kernel_internals/parsing/cparser.mly"
            ( _1 @ _2 @ _3 )
# 4379 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 854 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 @ _3 )
# 4388 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    Obj.repr(
# 857 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.rhs_end_pos 3) in
      _1 @ no_ghost [LABEL (_2, no_ghost_stmt (NOP loc), loc)] )
# 4397 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    Obj.repr(
# 862 "src/kernel_internals/parsing/cparser.mly"
                    ( [] )
# 4403 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list) in
    Obj.repr(
# 863 "src/kernel_internals/parsing/cparser.mly"
                    ( _1 )
# 4410 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Logic_ptree.code_annot * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 867 "src/kernel_internals/parsing/cparser.mly"
                             ( no_ghost [Cabs.CODE_ANNOT _1] @ _2)
# 4418 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.statement list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 869 "src/kernel_internals/parsing/cparser.mly"
       ( (in_ghost _2) @ _4 )
# 4426 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 873 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [] )
# 4432 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 874 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _2 @ _4 )
# 4441 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 877 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [ _1 ] )
# 4448 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 878 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _1 :: _3 )
# 4456 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 883 "src/kernel_internals/parsing/cparser.mly"
              ( _1 )
# 4463 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'annot_list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 884 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 @ _2 )
# 4471 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 888 "src/kernel_internals/parsing/cparser.mly"
               ( no_ghost [NOP _1] )
# 4478 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 890 "src/kernel_internals/parsing/cparser.mly"
      (
        let bs = _2 in
        match Logic_lexer.spec _1 with
        | Some (loc',spec) ->
          let spec = no_ghost [Cabs.CODE_SPEC (spec, (fst _1, loc'))] in
          spec @ _2
        | None -> bs
      )
# 4493 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 899 "src/kernel_internals/parsing/cparser.mly"
   ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
            no_ghost [COMPUTATION (smooth_expression _1,loc)])
# 4502 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 901 "src/kernel_internals/parsing/cparser.mly"
          ( let (x,y,z) = _1 in no_ghost [BLOCK (x, y, z)])
# 4509 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 903 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
          no_ghost [IF (smooth_expression _2,
                       in_block _3, no_ghost_stmt (NOP loc), loc)])
# 4520 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'annotated_statement) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 907 "src/kernel_internals/parsing/cparser.mly"
 ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
          no_ghost
            [IF (smooth_expression _2, in_block _3, in_block _5, loc)])
# 4532 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 911 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
          no_ghost [SWITCH (smooth_expression _2, in_block _3, loc)])
# 4542 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 915 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [WHILE (_1, smooth_expression _3, in_block _4, loc)] )
# 4553 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'annotated_statement) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 919 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [DOWHILE (_1, smooth_expression _5, in_block _3, loc)])
# 4566 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'for_clause) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 924 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [FOR (_1, _4, _5, _7, in_block _9, loc)])
# 4581 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 927 "src/kernel_internals/parsing/cparser.mly"
 ((* The only attribute that should appear here
            is "unused". For now, we drop this on the
            floor, since unused labels are usually
            removed anyways by Rmtmps. *)
          let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 2) in
          match _4 with
          | [] -> (* should not happen if grammar is written correctly *)
            parse_error "empty statement after label"
          | s :: others -> no_ghost [LABEL(_1,s,loc)] @ others )
# 4598 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 938 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.rhs_end_pos 3) in
              no_ghost [CASE (_2, in_block _4, loc)])
# 4608 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 941 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.rhs_end_pos 5) in
              no_ghost [CASERANGE (_2, _4, in_block _6, loc)])
# 4619 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 944 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos(), Parsing.symbol_end_pos ()) in
              no_ghost [DEFAULT (in_block _3, loc)])
# 4628 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 946 "src/kernel_internals/parsing/cparser.mly"
                     (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [RETURN ({ expr_loc = loc; expr_node = NOTHING}, loc)]
    )
# 4639 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 950 "src/kernel_internals/parsing/cparser.mly"
                                      (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [RETURN (smooth_expression _2, loc)]
    )
# 4651 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 954 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [BREAK loc]
    )
# 4662 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 958 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [CONTINUE loc]
    )
# 4673 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 962 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [GOTO (_2, loc)]
    )
# 4685 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 966 "src/kernel_internals/parsing/cparser.mly"
                                         (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [COMPGOTO (smooth_expression _3, loc) ]
    )
# 4698 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 970 "src/kernel_internals/parsing/cparser.mly"
                                                                    (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [ASM (_3, _5, _6, loc)]
    )
# 4714 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 974 "src/kernel_internals/parsing/cparser.mly"
                                                               (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [ASM (_2, _4, _5, loc)]
    )
# 4729 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 978 "src/kernel_internals/parsing/cparser.mly"
            ( no_ghost [ASM ([], [fst _1], None, snd _1)])
# 4736 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 979 "src/kernel_internals/parsing/cparser.mly"
                                                  (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      let loc_e = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 4, Parsing.rhs_end_pos 4) in
      let b, _, _ = _2 in
      let h, _, _ = _5 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/except in GCC code";
      no_ghost
        [TRY_EXCEPT (b, {expr_loc = loc_e; expr_node = COMMA _4}, h, loc)]
    )
# 4756 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 989 "src/kernel_internals/parsing/cparser.mly"
                            (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      let b, _, _ = _2 in
      let h, _, _ = _4 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/finally in GCC code";
      no_ghost [TRY_FINALLY (b, h, loc)]
    )
# 4773 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    Obj.repr(
# 1000 "src/kernel_internals/parsing/cparser.mly"
                ( [] )
# 4779 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotations) in
    Obj.repr(
# 1001 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 4786 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotation) in
    Obj.repr(
# 1005 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 4793 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.code_annot list * Cabs.cabsloc) in
    Obj.repr(
# 1017 "src/kernel_internals/parsing/cparser.mly"
               ( fst _1 )
# 4800 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1021 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_EXP _1 )
# 4808 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 1022 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_DECL _1 )
# 4815 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1027 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) _2 )
# 4824 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1029 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) [] )
# 4832 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1031 "src/kernel_internals/parsing/cparser.mly"
          ( doDeclaration (Some _1) ((snd _2)) (fst _2) _3 )
# 4842 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1033 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration (Some _1) ((snd _2)) (fst _2) [] )
# 4851 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 1037 "src/kernel_internals/parsing/cparser.mly"
                                                 ( [_1] )
# 4858 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.init_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr_list) in
    Obj.repr(
# 1038 "src/kernel_internals/parsing/cparser.mly"
                                                      ( _1 :: _3 )
# 4866 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr) in
    Obj.repr(
# 1043 "src/kernel_internals/parsing/cparser.mly"
                       ( [ _1 ] )
# 4873 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'init_declarator_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr_list) in
    Obj.repr(
# 1044 "src/kernel_internals/parsing/cparser.mly"
                                                       ( _1 :: _3 )
# 4881 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 1048 "src/kernel_internals/parsing/cparser.mly"
                                      (
    let ((name, decl, attrs, loc), init) = _2 in
    ((name, PARENTYPE (_1,decl,[]), attrs, loc), init)
  )
# 4892 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1055 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, NO_INIT) )
# 4899 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 1057 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, _3) )
# 4907 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1062 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecTypedef, _1  )
# 4914 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1063 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage EXTERN, _1 )
# 4921 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1064 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage STATIC, _1 )
# 4928 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1065 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage AUTO, _1 )
# 4935 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1066 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage REGISTER, _1)
# 4942 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1068 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecInline, _1 )
# 4949 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.spec_elem * cabsloc) in
    Obj.repr(
# 1069 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 4956 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1070 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecAttr (fst _1), snd _1 )
# 4963 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 1074 "src/kernel_internals/parsing/cparser.mly"
                                       ( fst _1 :: _2, snd _1 )
# 4971 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1075 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 4979 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1078 "src/kernel_internals/parsing/cparser.mly"
                                                ( fst _1 :: _2, snd _1 )
# 4987 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1079 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 4995 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    Obj.repr(
# 1084 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5001 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1085 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 )
# 5008 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 1092 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5014 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_no_named) in
    Obj.repr(
# 1093 "src/kernel_internals/parsing/cparser.mly"
                                                 ( fst _1 )
# 5021 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1096 "src/kernel_internals/parsing/cparser.mly"
                    ( Tvoid, _1)
# 5028 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1097 "src/kernel_internals/parsing/cparser.mly"
                    ( Tchar, _1 )
# 5035 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1098 "src/kernel_internals/parsing/cparser.mly"
                    ( Tbool, _1 )
# 5042 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1099 "src/kernel_internals/parsing/cparser.mly"
                    ( Tshort, _1 )
# 5049 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1100 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint, _1 )
# 5056 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1101 "src/kernel_internals/parsing/cparser.mly"
                    ( Tlong, _1 )
# 5063 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1102 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint64, _1 )
# 5070 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1103 "src/kernel_internals/parsing/cparser.mly"
                    ( Tfloat, _1 )
# 5077 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1104 "src/kernel_internals/parsing/cparser.mly"
                    ( Tdouble, _1 )
# 5084 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1105 "src/kernel_internals/parsing/cparser.mly"
                    ( Tsigned, _1 )
# 5091 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1106 "src/kernel_internals/parsing/cparser.mly"
                    ( Tunsigned, _1 )
# 5098 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1108 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 5106 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1110 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, None,    _2), _1 )
# 5115 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1112 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 5126 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1114 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 5136 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1116 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 5148 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1118 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 5159 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1120 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 5167 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1122 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 5178 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1124 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 5188 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1126 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 5200 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1128 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 5211 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1130 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 5219 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1132 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 5231 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1134 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 5242 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1136 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 5255 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1138 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 5267 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1139 "src/kernel_internals/parsing/cparser.mly"
                    (
      (Tnamed _1, Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos()))
      )
# 5276 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1142 "src/kernel_internals/parsing/cparser.mly"
                                        ( TtypeofE _3, _1 )
# 5285 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1143 "src/kernel_internals/parsing/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 5295 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1149 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 5301 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1151 "src/kernel_internals/parsing/cparser.mly"
                                         ( FIELD (fst _1,
                                            [(missingFieldDecl, None)]) :: _3 )
# 5311 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1155 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 5319 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1157 "src/kernel_internals/parsing/cparser.mly"
                                          ( FIELD (fst _1, _2)
                                            :: _4 )
# 5330 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1160 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5338 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1164 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 5345 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name * expression option) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1165 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 5353 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1168 "src/kernel_internals/parsing/cparser.mly"
                                    ( (_1, None) )
# 5360 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1170 "src/kernel_internals/parsing/cparser.mly"
                                    ( let (n,decl,al,loc) = _1 in
                                      let al' = al @ _4 in
                                     ((n,decl,al',loc), Some _3) )
# 5371 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1173 "src/kernel_internals/parsing/cparser.mly"
                                    ( (missingFieldDecl, Some _2) )
# 5378 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1177 "src/kernel_internals/parsing/cparser.mly"
                  ([_1])
# 5385 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1178 "src/kernel_internals/parsing/cparser.mly"
                                       (_1 @ [_3])
# 5393 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1181 "src/kernel_internals/parsing/cparser.mly"
            (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos()) in
      (_1, { expr_node = NOTHING; expr_loc = loc }, loc)
    )
# 5403 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1185 "src/kernel_internals/parsing/cparser.mly"
                         (
      (_1, _3, Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (),Parsing.symbol_end_pos()))
    )
# 5413 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1192 "src/kernel_internals/parsing/cparser.mly"
                                               (
     let (n, decl) = _2 in (n, applyPointer (fst _1) decl, _3, (snd _1))
   )
# 5424 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'comma_expression_opt) in
    Obj.repr(
# 1199 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1,_2 )
# 5432 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1200 "src/kernel_internals/parsing/cparser.mly"
                                               (
    fst _1::_2  @ ["static",[]], smooth_expression _4
  )
# 5444 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1203 "src/kernel_internals/parsing/cparser.mly"
                                     (
    ("static",[]) :: _2, smooth_expression _3
  )
# 5455 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1211 "src/kernel_internals/parsing/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 5462 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.name) in
    Obj.repr(
# 1214 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n,decl,al,_) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 5472 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attributes_or_static) in
    Obj.repr(
# 1218 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (attrs, size) = _3 in
                                     (n, ARRAY(decl, attrs, size)) )
# 5482 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1221 "src/kernel_internals/parsing/cparser.mly"
                              (
   let (n,decl) = _1 in (n, PROTO(decl,[],false))
  )
# 5492 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1225 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, isva))
                                   )
# 5505 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1232 "src/kernel_internals/parsing/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 5512 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_list_startscope))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1235 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _2 in
                                     (_1 :: params, isva)
                                   )
# 5522 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1240 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], false) )
# 5528 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    Obj.repr(
# 1241 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], true) )
# 5534 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1242 "src/kernel_internals/parsing/cparser.mly"
                                        ( let (params, isva) = _3 in
                                          (_2 :: params, isva)
                                        )
# 5544 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1249 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, _2) )
# 5552 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1250 "src/kernel_internals/parsing/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, (*CEA*) cabslu)) )
# 5561 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1252 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], (*CEA*) cabslu)) )
# 5568 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1253 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5576 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1258 "src/kernel_internals/parsing/cparser.mly"
                                      ( let (n, decl, a) = _2 in
                                        (n, applyPointer (fst _1) decl,
                                         a, snd _1)
                                      )
# 5587 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1266 "src/kernel_internals/parsing/cparser.mly"
                                                                  (
    let par_decl, isva = doOldParDecl _3 _5 in
    let n, decl = _1 in
    (n, PROTO(decl, par_decl, isva), ["FC_OLDSTYLEPROTO",[]])
  )
# 5601 "src/kernel_internals/parsing/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1282 "src/kernel_internals/parsing/cparser.mly"
                                               ( [_1] )
# 5608 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1283 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1::_3 )
# 5616 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1287 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([], false) )
# 5622 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1289 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 5631 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1291 "src/kernel_internals/parsing/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva)
                                          )
# 5643 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1297 "src/kernel_internals/parsing/cparser.mly"
                                          ( [_1] )
# 5650 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1298 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 :: _3 )
# 5658 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1303 "src/kernel_internals/parsing/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 5667 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1306 "src/kernel_internals/parsing/cparser.mly"
                                 ( let l = Errorloc.currentLoc () in
                                   ([], l) )
# 5674 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1308 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 5681 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1312 "src/kernel_internals/parsing/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then
                                   Errorloc.parse_error
                                     "attributes in type name";
                                 (fst _1, d)
                               )
# 5694 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1318 "src/kernel_internals/parsing/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 5701 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1321 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 5710 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1322 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 5717 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1329 "src/kernel_internals/parsing/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 5728 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1334 "src/kernel_internals/parsing/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 5736 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1337 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params, isva)
                                   )
# 5748 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1341 "src/kernel_internals/parsing/cparser.mly"
                                ( PROTO (_1, [], false) )
# 5756 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1345 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 5763 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1346 "src/kernel_internals/parsing/cparser.mly"
                                    ( JUSTBASE )
# 5769 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1350 "src/kernel_internals/parsing/cparser.mly"
          (
            let (loc, specs, decl) = _2 in
            let spec_loc =
              let loc = fst _1 in
              Extlib.opt_map
                (fun (loc', spec) -> spec, (loc, loc'))
                (Logic_lexer.spec _1)
            in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            doFunctionDef spec_loc loc (trd3 _3) specs decl (fst3 _3)
          )
# 5790 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1364 "src/kernel_internals/parsing/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            (*OCAMLYACC BUG??? Format.printf "%a@." d_cabsloc (trd3 $2);*)
            doFunctionDef None ((*handleLoc*) loc) (trd3 _2) specs decl (fst3 _2)
          )
# 5804 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1375 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (fourth4 _2, fst _1, _2)
                            )
# 5814 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1381 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 5824 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1386 "src/kernel_internals/parsing/cparser.mly"
    ( let (params, isva) = _3 in
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      let fdec =
        (_1, PROTO(JUSTBASE, params, isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      let defSpec = [SpecType Tint] in (loc, defSpec, fdec)
    )
# 5840 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1397 "src/kernel_internals/parsing/cparser.mly"
    ( (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      (* Make the function declarator *)
      let fdec = (_1, PROTO(JUSTBASE, pardecl,isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      (loc, [SpecType Tint], fdec)
    )
# 5858 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1407 "src/kernel_internals/parsing/cparser.mly"
  (
    let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_start_pos 1) in
    let fdec = (_1, PROTO(JUSTBASE,[],false),[],loc) in
    announceFunctionName fdec;
    (loc, [SpecType Tint], fdec)
  )
# 5871 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1417 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_CONST), _1 )
# 5878 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1418 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_VOLATILE), _1 )
# 5885 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1419 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_RESTRICT), _1 )
# 5892 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1420 "src/kernel_internals/parsing/cparser.mly"
                             ( let annot, loc = _1 in
			       SpecCV(CV_ATTRIBUTE_ANNOT annot), loc )
# 5900 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1426 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 5906 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1427 "src/kernel_internals/parsing/cparser.mly"
                                 ( fst _1 :: _2 )
# 5914 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1433 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5920 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1434 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 5928 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1435 "src/kernel_internals/parsing/cparser.mly"
                                                 (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3) in
      ("__asm__",
       [{ expr_node = CONSTANT(CONST_STRING (fst _3)); expr_loc = loc}])
      :: _5
    )
# 5943 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1446 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 5952 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1447 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 5960 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1448 "src/kernel_internals/parsing/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 5967 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1450 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__thread",[]), _1 )
# 5974 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    Obj.repr(
# 1454 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 5980 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv_list) in
    Obj.repr(
# 1455 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 5988 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1460 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 5995 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1461 "src/kernel_internals/parsing/cparser.mly"
                          ( ("const", []), _1 )
# 6002 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1462 "src/kernel_internals/parsing/cparser.mly"
                          ( ("restrict",[]), _1 )
# 6009 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1463 "src/kernel_internals/parsing/cparser.mly"
                          ( ("volatile",[]), _1 )
# 6016 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1464 "src/kernel_internals/parsing/cparser.mly"
                          ( let annot, loc = _1 in
			    ("$annot:" ^ annot, []), loc )
# 6024 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1473 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3) )
# 6033 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1474 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2) )
# 6041 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1480 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 6048 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'just_attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1481 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 :: _2 )
# 6056 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1486 "src/kernel_internals/parsing/cparser.mly"
                             (
    PRAGMA (make_expr (VARIABLE ("")), _1)
  )
# 6065 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1489 "src/kernel_internals/parsing/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 6073 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1490 "src/kernel_internals/parsing/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 6082 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1491 "src/kernel_internals/parsing/cparser.mly"
                                        (
    PRAGMA (make_expr (VARIABLE (fst _1)), snd _1)
  )
# 6091 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1499 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE _1) )
# 6098 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1500 "src/kernel_internals/parsing/cparser.mly"
               ( make_expr (VARIABLE _1) )
# 6105 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1501 "src/kernel_internals/parsing/cparser.mly"
                          ( make_expr (VARIABLE ("default:" ^ fst _3)) )
# 6113 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1503 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE "aconst") )
# 6120 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1505 "src/kernel_internals/parsing/cparser.mly"
             ( make_expr (VARIABLE ("__noreturn__")) )
# 6127 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1506 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (VARIABLE (fst _1 ^ ":" ^ fst _3)) )
# 6135 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1510 "src/kernel_internals/parsing/cparser.mly"
            ( make_expr (CONSTANT(CONST_INT (fst _1))) )
# 6142 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1511 "src/kernel_internals/parsing/cparser.mly"
              ( make_expr (CONSTANT(CONST_FLOAT(fst _1))) )
# 6149 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'var_attr) in
    Obj.repr(
# 1512 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 6156 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1515 "src/kernel_internals/parsing/cparser.mly"
                  ( [_1] )
# 6163 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1516 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1::_2 )
# 6171 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1520 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 )
# 6178 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1521 "src/kernel_internals/parsing/cparser.mly"
                                       (
      _1 @ [make_expr (CONSTANT(CONST_STRING (fst _2)))]
    )
# 6188 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1524 "src/kernel_internals/parsing/cparser.mly"
                                                              (
      _1 @ ([make_expr (CONSTANT(CONST_STRING (fst _2)))] @ _3)
    )
# 6199 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1529 "src/kernel_internals/parsing/cparser.mly"
                           ( _1 )
# 6206 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1530 "src/kernel_internals/parsing/cparser.mly"
                    ( [make_expr (CONSTANT(CONST_STRING (fst _1)))] )
# 6213 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1533 "src/kernel_internals/parsing/cparser.mly"
               ( _1 )
# 6220 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1534 "src/kernel_internals/parsing/cparser.mly"
                       ( _2 )
# 6228 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1535 "src/kernel_internals/parsing/cparser.mly"
                    ( make_expr (CONSTANT(CONST_STRING (fst _1))) )
# 6235 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1538 "src/kernel_internals/parsing/cparser.mly"
                 ( _1 )
# 6242 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1539 "src/kernel_internals/parsing/cparser.mly"
                                            (
        let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        make_expr (CALL({ expr_loc = loc; expr_node = VARIABLE _1}, _2)) )
# 6252 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1543 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc1 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      let loc2 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.rhs_end_pos 3) in
      let f = { expr_node = VARIABLE _1; expr_loc = loc1 } in
      let arg = { expr_node = VARIABLE ""; expr_loc = loc2 } in
      make_expr (CALL(f, [arg]))
    )
# 6266 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'param_attr_list_ne) in
    Obj.repr(
# 1552 "src/kernel_internals/parsing/cparser.mly"
                                   (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      make_expr (CALL({ expr_node = VARIABLE ""; expr_loc = loc}, _1::_2)) )
# 6276 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1556 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROFPTR (_1, _3)))
# 6284 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1557 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)) )
# 6292 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1558 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (INDEX (_1, _3)) )
# 6300 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1565 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6307 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1566 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (EXPR_SIZEOF _2) )
# 6315 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1568 "src/kernel_internals/parsing/cparser.mly"
                          (let b, d = _3 in
                                         make_expr (TYPE_SIZEOF (b, d)) )
# 6325 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1571 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (EXPR_ALIGNOF _2) )
# 6333 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1572 "src/kernel_internals/parsing/cparser.mly"
                                        (let b, d = _3 in
                                         make_expr (TYPE_ALIGNOF (b, d)) )
# 6343 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1574 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (PLUS, _2)))
# 6351 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1575 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (MINUS, _2)) )
# 6359 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1576 "src/kernel_internals/parsing/cparser.mly"
                            (make_expr (UNARY (MEMOF, _2)) )
# 6367 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1578 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (ADDROF, _2)) )
# 6375 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1579 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (NOT, _2)) )
# 6383 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1580 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (UNARY (BNOT, _2)) )
# 6391 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1584 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6398 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1588 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6405 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1589 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(MUL ,_1 , _3)))
# 6414 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1590 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(DIV ,_1 , _3)))
# 6422 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1591 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(MOD ,_1 , _3)))
# 6430 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1596 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6437 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1597 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(ADD ,_1 , _3)))
# 6446 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1598 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(SUB ,_1 , _3)))
# 6455 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1602 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6462 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1603 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHL ,_1 , _3)))
# 6470 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1604 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHR ,_1 , _3)))
# 6478 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1608 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6485 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1609 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(LT ,_1 , _3)))
# 6493 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1610 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(GT ,_1 , _3)))
# 6501 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1611 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(LE ,_1 , _3)))
# 6509 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1612 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(GE ,_1 , _3)))
# 6517 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1616 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6524 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1617 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(EQ ,_1 , _3)))
# 6532 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1618 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(NE ,_1 , _3)))
# 6540 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1623 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6547 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1624 "src/kernel_internals/parsing/cparser.mly"
                                       (make_expr (BINARY(BAND ,_1 , _3)))
# 6556 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1628 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6563 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1629 "src/kernel_internals/parsing/cparser.mly"
                                           (make_expr (BINARY(XOR ,_1 , _3)))
# 6571 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1633 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 6578 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1634 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(BOR ,_1 , _3)))
# 6586 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1638 "src/kernel_internals/parsing/cparser.mly"
                                                ( _1 )
# 6593 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1640 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(AND ,_1 , _3)))
# 6602 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1644 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1 )
# 6609 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1646 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(OR ,_1 , _3)))
# 6617 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1650 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6624 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'attr_test) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1652 "src/kernel_internals/parsing/cparser.mly"
    ( make_expr (QUESTION(_1, _4, _6)) )
# 6634 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1655 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 )
# 6641 "src/kernel_internals/parsing/cparser.ml"
               : 'assign_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1656 "src/kernel_internals/parsing/cparser.mly"
                                         ( make_expr (BINARY(ASSIGN,_1,_3)) )
# 6649 "src/kernel_internals/parsing/cparser.ml"
               : 'assign_attr))
; (fun __caml_parser_env ->
    Obj.repr(
# 1660 "src/kernel_internals/parsing/cparser.mly"
              ( Cabshelper.push_attr_test () )
# 6655 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_test))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assign_attr) in
    Obj.repr(
# 1662 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6662 "src/kernel_internals/parsing/cparser.ml"
               : 'attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr) in
    Obj.repr(
# 1666 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 6669 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1667 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 6677 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1671 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 6683 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1672 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 )
# 6690 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1675 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 6698 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list) in
    Obj.repr(
# 1678 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 6706 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1682 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 6712 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1683 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 6720 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1684 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("const", []) :: _2 )
# 6728 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 1687 "src/kernel_internals/parsing/cparser.mly"
                                       ( [intlist_to_string (fst _1)] )
# 6735 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1688 "src/kernel_internals/parsing/cparser.mly"
                                       ( intlist_to_string (fst _1) :: _2 )
# 6743 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    Obj.repr(
# 1691 "src/kernel_internals/parsing/cparser.mly"
                        ( None )
# 6749 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asminputs) in
    Obj.repr(
# 1693 "src/kernel_internals/parsing/cparser.mly"
                        ( let (ins, (clobs,labels)) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs;
				alabels = labels } )
# 6759 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1698 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 6765 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1699 "src/kernel_internals/parsing/cparser.mly"
                                        ( List.rev _1 )
# 6772 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1702 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 6779 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'asmoperandsne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1703 "src/kernel_internals/parsing/cparser.mly"
                                        ( _3 :: _1 )
# 6787 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'asmopname) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1706 "src/kernel_internals/parsing/cparser.mly"
                                                           ( (_1, fst _2, _4) )
# 6797 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    Obj.repr(
# 1709 "src/kernel_internals/parsing/cparser.mly"
                        ( ([], ([],[])) )
# 6803 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1711 "src/kernel_internals/parsing/cparser.mly"
                        ( (_2, _3) )
# 6811 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1714 "src/kernel_internals/parsing/cparser.mly"
                                        ( None )
# 6817 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 1715 "src/kernel_internals/parsing/cparser.mly"
                                        ( Some _2 )
# 6824 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    Obj.repr(
# 1719 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],[] )
# 6830 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1720 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],_2 )
# 6837 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmcloberlst_ne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1721 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2,_3 )
# 6845 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1724 "src/kernel_internals/parsing/cparser.mly"
                                    ( [fst _1] )
# 6852 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1725 "src/kernel_internals/parsing/cparser.mly"
                                             ( fst _1 :: _3 )
# 6860 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1728 "src/kernel_internals/parsing/cparser.mly"
                                       ( [] )
# 6866 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1729 "src/kernel_internals/parsing/cparser.mly"
                                       ( _2 )
# 6873 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
(* Entry interpret *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : (bool*Cabs.definition) list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 2 lexfun lexbuf : (bool*Cabs.definition) list)
;;
